@@ -38,30 +38,30 @@ void cdfDefVarDeflate(int ncid, int ncvarid, int deflate_level)
 #endif
 }
 
-
-int cdfDefDatatype(int datatype, int filetype)
+int cdfDefDatatype(int datatype, stream_t *streamptr)
 {
   int xtype = NC_FLOAT;
 
-  if ( datatype == CDI_DATATYPE_CPX32 || datatype == CDI_DATATYPE_CPX64 )
-    Error("CDI/NetCDF library does not support complex numbers!");
-
-  if ( filetype == CDI_FILETYPE_NC4 )
+  if ( streamptr->filetype == CDI_FILETYPE_NC4 )
     {
       if      ( datatype == CDI_DATATYPE_INT8   ) xtype = NC_BYTE;
       else if ( datatype == CDI_DATATYPE_INT16  ) xtype = NC_SHORT;
       else if ( datatype == CDI_DATATYPE_INT32  ) xtype = NC_INT;
-#if  defined  (HAVE_NETCDF4)
+#ifdef  HAVE_NETCDF4
       else if ( datatype == CDI_DATATYPE_UINT8  ) xtype = NC_UBYTE;
       else if ( datatype == CDI_DATATYPE_UINT16 ) xtype = NC_USHORT;
       else if ( datatype == CDI_DATATYPE_UINT32 ) xtype = NC_UINT;
+      else if ( datatype == CDI_DATATYPE_CPX32 || datatype == CDI_DATATYPE_CPX64 )
+        Error("CDI library does not support complex numbers with NetCDF4/HDF5!");
 #else
       else if ( datatype == CDI_DATATYPE_UINT8  ) xtype = NC_SHORT;
       else if ( datatype == CDI_DATATYPE_UINT16 ) xtype = NC_INT;
       else if ( datatype == CDI_DATATYPE_UINT32 ) xtype = NC_INT;
+      else if ( datatype == CDI_DATATYPE_CPX32 || datatype == CDI_DATATYPE_CPX64 )
+        Error("CDI library does not support complex numbers with NetCDF4 classic!");
 #endif
       else if ( datatype == CDI_DATATYPE_FLT64  ) xtype = NC_DOUBLE;
-      else                                        xtype = NC_FLOAT;
+      else if ( datatype == CDI_DATATYPE_FLT32  ) xtype = NC_FLOAT;
     }
   else
     {
@@ -72,7 +72,9 @@ int cdfDefDatatype(int datatype, int filetype)
       else if ( datatype == CDI_DATATYPE_UINT16 ) xtype = NC_INT;
       else if ( datatype == CDI_DATATYPE_UINT32 ) xtype = NC_INT;
       else if ( datatype == CDI_DATATYPE_FLT64  ) xtype = NC_DOUBLE;
-      else                                        xtype = NC_FLOAT;
+      else if ( datatype == CDI_DATATYPE_FLT32  ) xtype = NC_FLOAT;
+      else if ( datatype == CDI_DATATYPE_CPX32 || datatype == CDI_DATATYPE_CPX64 )
+        Error("CDI library does not support complex numbers with NetCDF classic!");
     }
 
   return xtype;
@@ -90,7 +92,7 @@ void cdfDefVarMissval(stream_t *streamptr, int varID, int dtype, int lcheck)
 
       if ( lcheck && streamptr->ncmode == 2 ) cdf_redef(fileID);
 
-      int xtype = cdfDefDatatype(dtype, streamptr->filetype);
+      int xtype = cdfDefDatatype(dtype, streamptr);
 
       if ( xtype == NC_BYTE && missval > 127 && missval < 256 ) xtype = NC_INT;
 
@@ -332,7 +334,6 @@ int cdfDefVar(stream_t *streamptr, int varID)
   int dimorder[3];
   size_t iax = 0;
   char axis[5];
-  int ensID, ensCount, forecast_type;
 
   int fileID  = streamptr->fileID;
 
@@ -515,7 +516,7 @@ int cdfDefVar(stream_t *streamptr, int varID)
   /* if ( streamptr->ncmode == 2 ) cdf_redef(fileID); */
 
   int dtype = vlistInqVarDatatype(vlistID, varID);
-  int xtype = cdfDefDatatype(dtype, streamptr->filetype);
+  int xtype = cdfDefDatatype(dtype, streamptr);
 
   cdf_def_var(fileID, name, (nc_type) xtype, ndims, dims, &ncvarid);
 
@@ -594,7 +595,7 @@ int cdfDefVar(stream_t *streamptr, int varID)
 
   if ( gridtype == GRID_TRAJECTORY )
     {
-      cdf_put_att_text(fileID, ncvarid, "coordinates", 9, "lon lat" );
+      cdf_put_att_text(fileID, ncvarid, "coordinates", 9, "tlon tlat" );
     }
   else if ( gridtype == GRID_LONLAT && xid == CDI_UNDEFID && yid == CDI_UNDEFID && gridsize == 1 )
     {
@@ -750,15 +751,13 @@ int cdfDefVar(stream_t *streamptr, int varID)
         }
     }
 
-  if ( vlistInqVarEnsemble( vlistID,  varID, &ensID, &ensCount, &forecast_type ) )
-    {
-      /* void cdf_put_att_int(  int ncid, int varid, const char *name, nc_type xtype,
-	                        size_t len, const int *ip )
-       */
-	cdf_put_att_int(fileID, ncvarid, "realization", NC_INT, 1, &ensID);
-	cdf_put_att_int(fileID, ncvarid, "ensemble_members", NC_INT, 1, &ensCount);
-	cdf_put_att_int(fileID, ncvarid, "forecast_init_type", NC_INT, 1, &forecast_type);
-    }
+  int perturbationNumber, numberOfForecastsInEnsemble, typeOfEnsembleForecast;
+  if ( cdiInqKeyInt(vlistID, varID, CDI_KEY_PERTURBATIONNUMBER, &perturbationNumber) == 0 )
+    cdf_put_att_int(fileID, ncvarid, "realization", NC_INT, 1, &perturbationNumber);
+  if ( cdiInqKeyInt(vlistID, varID, CDI_KEY_NUMBEROFFORECASTSINENSEMBLE, &numberOfForecastsInEnsemble) == 0 )
+    cdf_put_att_int(fileID, ncvarid, "ensemble_members", NC_INT, 1, &numberOfForecastsInEnsemble);
+  if ( cdiInqKeyInt(vlistID, varID, CDI_KEY_TYPEOFENSEMBLEFORECAST, &typeOfEnsembleForecast) == 0 )
+    cdf_put_att_int(fileID, ncvarid, "forecast_init_type", NC_INT, 1, &typeOfEnsembleForecast);
 
   /* Attributes */
   cdfDefineAttributes(vlistID, varID, fileID, ncvarid);
