@@ -1,5 +1,5 @@
-#if defined (HAVE_CONFIG_H)
-#  include "config.h"
+#ifdef  HAVE_CONFIG_H
+#include "config.h"
 #endif
 
 #include <stdio.h>
@@ -27,18 +27,22 @@ void SysError_(const char *caller, const char *fmt, ...)
 void SysError_(const char *caller, const char *fmt, ...)
 {
   va_list args;
+  int saved_errno = errno;
 
   va_start(args, fmt);
 
   printf("\n");
-   fprintf(stderr, "Error (%s) : ", caller);
+   fprintf(stderr, "Error (%s): ", caller);
   vfprintf(stderr, fmt, args);
    fprintf(stderr, "\n");
 
   va_end(args);
 
-  if ( errno )
-    perror("System error message ");
+  if ( saved_errno )
+    {
+      errno = saved_errno;
+      perror("System error message");
+    }
 
   exit(EXIT_FAILURE);
 }
@@ -51,7 +55,7 @@ void Error_(const char *caller, const char *fmt, ...)
   va_start(args, fmt);
 
   printf("\n");
-   fprintf(stderr, "Error (%s) : ", caller);
+   fprintf(stderr, "Error (%s): ", caller);
   vfprintf(stderr, fmt, args);
    fprintf(stderr, "\n");
 
@@ -114,7 +118,7 @@ void Warning_(const char *caller, const char *fmt, ...)
 
 void cdiWarning(const char *caller, const char *fmt, va_list ap)
 {
-  fprintf(stderr, "Warning (%s) : ", caller);
+  fprintf(stderr, "Warning (%s): ", caller);
   vfprintf(stderr, fmt, ap);
   fputc('\n', stderr);
 }
@@ -126,7 +130,7 @@ void Message_(const char *caller, const char *fmt, ...)
 
   va_start(args, fmt);
 
-   fprintf(stdout, "%-18s : ", caller);
+   fprintf(stdout, "%-18s: ", caller);
   vfprintf(stdout, fmt, args);
    fprintf(stdout, "\n");
 
