@@ -34,7 +34,7 @@ static int srvDefaultDprec = 0;
 #define LIBVERSION      1.4.0
 #define XSTRING(x)	#x
 #define STRING(x)	XSTRING(x)
-static const char srv_libvers[] = STRING(LIBVERSION) " of " __DATE__" " __TIME__;
+static const char srv_libvers[] = STRING(LIBVERSION);
 
 const char *srvLibraryVersion(void)
 {
@@ -61,9 +61,7 @@ void srvLibInit()
   char *envString = getenv(envName);
   if ( envString )
     {
-      int nrun;
-      if ( strlen(envString) == 2 ) nrun = 1;
-      else                          nrun = 2;
+      int nrun = (strlen(envString) == 2) ? 1 : 2;
 
       int pos = 0;
       while ( nrun-- )
