@@ -30,41 +30,39 @@
 #include "cdo_int.h"
 #include "pstream_int.h"
 
-int *
-fill_vars(int vlistID)
+void
+fill_vars(int vlistID, std::vector<bool> &vars)
 {
   int varID;
   int nvars = vlistNvars(vlistID);
-  int *vars = (int *) Malloc(nvars * sizeof(int));
+  vars.resize(nvars);
 
   if (cdoNumVarnames)
     {
-      int nfound = 0;
+      bool lfound = false;
       char varname[CDI_MAX_NAME];
 
       for (varID = 0; varID < nvars; ++varID)
         {
-          vars[varID] = 0;
+          vars[varID] = false;
 
           vlistInqVarName(vlistID, varID, varname);
 
           for (int i = 0; i < cdoNumVarnames; ++i)
             if (strcmp(varname, cdoVarnames[i]) == 0)
               {
-                vars[varID] = 1;
-                nfound++;
+                vars[varID] = true;
+                lfound = true;
                 break;
               }
         }
 
-      if (nfound == 0) cdoAbort("Variable -n %s%s not found!", cdoVarnames[0], cdoNumVarnames > 1 ? ",..." : "");
+      if (!lfound) cdoAbort("Variable %s%s not found!", cdoVarnames[0], cdoNumVarnames > 1 ? ",..." : "");
     }
   else
     {
-      for (varID = 0; varID < nvars; ++varID) vars[varID] = 1;
+      for (varID = 0; varID < nvars; ++varID) vars[varID] = true;
     }
-
-  return vars;
 }
 
 void *
@@ -76,26 +74,33 @@ Arithc(void *process)
   cdoInitialize(process);
 
   // clang-format off
-  cdoOperatorAdd("addc", func_add, 0, "constant value");
-  cdoOperatorAdd("subc", func_sub, 0, "constant value");
-  cdoOperatorAdd("mulc", func_mul, 0, "constant value");
-  cdoOperatorAdd("divc", func_div, 0, "constant value");
+  cdoOperatorAdd("addc", func_add, 1, "constant value");
+  cdoOperatorAdd("subc", func_sub, 1, "constant value");
+  cdoOperatorAdd("mulc", func_mul, 1, "constant value");
+  cdoOperatorAdd("divc", func_div, 1, "constant value");
   cdoOperatorAdd("mod",  func_mod, 0, "divisor");
   // clang-format on
 
   int operatorID = cdoOperatorID();
   int operfunc = cdoOperatorF1(operatorID);
+  bool opercplx = cdoOperatorF2(operatorID);
 
   operatorInputArg(cdoOperatorEnter(operatorID));
-  operatorCheckArgc(1);
+  if (operatorArgc() < 1) cdoAbort("Too few arguments!");
+  if (operatorArgc() > 2) cdoAbort("Too many arguments!");
   double rconst = parameter2double(operatorArgv()[0]);
+  double rconstcplx[2];
+  rconstcplx[0] = rconst;
+  rconstcplx[1] = 0;
+  if (operatorArgc() == 2) rconstcplx[1] = parameter2double(operatorArgv()[1]);
 
   int streamID1 = cdoStreamOpenRead(cdoStreamName(0));
 
   int vlistID1 = cdoStreamInqVlist(streamID1);
   int vlistID2 = vlistDuplicate(vlistID1);
 
-  int *vars = fill_vars(vlistID1);
+  std::vector<bool> vars;
+  fill_vars(vlistID1, vars);
 
   int taxisID1 = vlistInqTaxis(vlistID1);
   int taxisID2 = taxisDuplicate(taxisID1);
@@ -104,11 +109,13 @@ Arithc(void *process)
   int streamID2 = cdoStreamOpenWrite(cdoStreamName(1), cdoFiletype());
   pstreamDefVlist(streamID2, vlistID2);
 
-  size_t gridsize = vlistGridsizeMax(vlistID1);
+  size_t nwpv = (vlistNumber(vlistID1) == CDI_COMP) ? 2 : 1;
+  if (nwpv == 2 && opercplx == false) cdoAbort("Fields with complex numbers are not supported by this operator!");
+  size_t gridsizemax = nwpv * vlistGridsizeMax(vlistID1);
 
-  field_type field;
+  Field field;
   field_init(&field);
-  field.ptr = (double *) Malloc(gridsize * sizeof(double));
+  field.ptr = (double *) Malloc(gridsizemax * sizeof(double));
   field.weight = NULL;
 
   int tsID = 0;
@@ -124,10 +131,15 @@ Arithc(void *process)
 
           if (vars[varID])
             {
-              field.grid = vlistInqVarGrid(vlistID1, varID);
+              int gridID = vlistInqVarGrid(vlistID1, varID);
+              size_t gridsize = nwpv * gridInqSize(gridID);
+              field.grid = gridID;
               field.missval = vlistInqVarMissval(vlistID1, varID);
 
-              farcfun(&field, rconst, operfunc);
+              if (nwpv == 2)
+                farcfuncplx(&field, rconstcplx, operfunc);
+              else
+                farcfun(&field, rconst, operfunc);
 
               // recalculate number of missing values
               field.nmiss = arrayNumMV(gridsize, field.ptr, field.missval);
@@ -144,7 +156,6 @@ Arithc(void *process)
   pstreamClose(streamID1);
 
   if (field.ptr) Free(field.ptr);
-  if (vars) Free(vars);
 
   vlistDestroy(vlistID2);
 
