@@ -15,18 +15,18 @@
   GNU General Public License for more details.
 */
 
-
 #include <cdi.h>
-#include "cdo.h"
+
 #include "cdo_int.h"
-#include "pstream.h"
+#include "pstream_int.h"
+#include "timer.h"
 
-
-static
-const char *filetypestr(int filetype)
+const char *
+filetypestr(int filetype)
 {
-  switch ( filetype )
+  switch (filetype)
     {
+    // clang-format off
     case CDI_FILETYPE_GRB:  return ("GRIB");
     case CDI_FILETYPE_GRB2: return ("GRIB2");
     case CDI_FILETYPE_NC:   return ("NetCDF");
@@ -38,17 +38,19 @@ const char *filetypestr(int filetype)
     case CDI_FILETYPE_EXT:  return ("EXTRA");
     case CDI_FILETYPE_IEG:  return ("IEG");
     default:                return ("");
+      // clang-format on
     }
 }
 
-static
-const char *datatypestr(int datatype)
+const char *
+datatypestr(int datatype)
 {
   static char str[20];
 
   str[0] = 0;
   snprintf(str, sizeof(str), "%d bit packed", datatype);
 
+  // clang-format off
   if      ( datatype == CDI_DATATYPE_PACK   ) return ("P0");
   else if ( datatype > 0 && datatype <= 32  ) return (str);
   else if ( datatype == CDI_DATATYPE_CPX32  ) return ("C32");
@@ -62,24 +64,27 @@ const char *datatypestr(int datatype)
   else if ( datatype == CDI_DATATYPE_UINT16 ) return ("U16");
   else if ( datatype == CDI_DATATYPE_UINT32 ) return ("U32");
   else                                        return ("");
+  // clang-format on
 }
 
-static
-void print_stat(const char *sinfo, int memtype, int datatype, int filetype, off_t nvalues, double data_size, double file_size, double tw)
+static void
+print_stat(const char *sinfo, int memtype, int datatype, int filetype, off_t nvalues, double data_size, double file_size, double tw)
 {
   nvalues /= 1000000;
-  data_size /= 1024.*1024.*1024.;
-  if ( memtype == MEMTYPE_FLOAT )
-    cdoPrint("%s Read %.1f GB of 32 bit floats from %s %s, %.1f MVal/s", sinfo, data_size, datatypestr(datatype), filetypestr(filetype), nvalues/tw);
+  data_size /= 1024. * 1024. * 1024.;
+  if (memtype == MEMTYPE_FLOAT)
+    cdoPrint("%s Read %.1f GB of 32 bit floats from %s %s, %.1f MVal/s", sinfo, data_size, datatypestr(datatype),
+             filetypestr(filetype), nvalues / tw);
   else
-    cdoPrint("%s Read %.1f GB of 64 bit floats from %s %s, %.1f MVal/s", sinfo, data_size, datatypestr(datatype), filetypestr(filetype), nvalues/tw);
+    cdoPrint("%s Read %.1f GB of 64 bit floats from %s %s, %.1f MVal/s", sinfo, data_size, datatypestr(datatype),
+             filetypestr(filetype), nvalues / tw);
 
-  file_size /= 1024.*1024.*1024.;
-  cdoPrint("%s Read %.1f GB in %.1f seconds, total %.1f MB/s", sinfo, file_size, tw, 1024*file_size/tw);
+  file_size /= 1024. * 1024. * 1024.;
+  cdoPrint("%s Read %.1f GB in %.1f seconds, total %.1f MB/s", sinfo, file_size, tw, 1024 * file_size / tw);
 }
 
-
-void *CDIread(void *argument)
+void *
+CDIread(void *process)
 {
   int memtype = CDO_Memtype;
   int varID, levelID;
@@ -96,92 +101,91 @@ void *CDIread(void *argument)
 
   sinfo[0] = 0;
 
-  cdoInitialize(argument);
+  cdoInitialize(process);
 
-  if ( cdoVerbose ) cdoPrint("parameter: <nruns>");
+  if (cdoVerbose) cdoPrint("parameter: <nruns>");
 
-  if ( operatorArgc() > 1 ) cdoAbort("Too many arguments!");
+  if (operatorArgc() > 1) cdoAbort("Too many arguments!");
 
-  if ( operatorArgc() == 1 ) nruns = parameter2int(operatorArgv()[0]);
+  if (operatorArgc() == 1) nruns = parameter2int(operatorArgv()[0]);
 
-  if ( nruns <  0 ) nruns = 0;
-  if ( nruns > 99 ) nruns = 99;
+  if (nruns < 0) nruns = 0;
+  if (nruns > 99) nruns = 99;
 
-  if ( cdoVerbose ) cdoPrint("nruns      : %d", nruns);
+  if (cdoVerbose) cdoPrint("nruns      : %d", nruns);
 
   // vlistDefNtsteps(vlistID, 1);
 
-  for ( int irun = 0; irun < nruns; ++irun )
+  for (int irun = 0; irun < nruns; ++irun)
     {
       tw0 = timer_val(timer_read);
       data_size = 0;
       nvalues = 0;
 
-      int streamID = pstreamOpenRead(cdoStreamName(0));
+      int streamID = cdoStreamOpenRead(cdoStreamName(0));
 
-      int vlistID = pstreamInqVlist(streamID);
+      int vlistID = cdoStreamInqVlist(streamID);
 
       filetype = pstreamInqFiletype(streamID);
       datatype = vlistInqVarDatatype(vlistID, 0);
-	  
-      int gridsize = vlistGridsizeMax(vlistID);
-      
-      if ( darray == NULL ) darray = (double*) Malloc(gridsize*sizeof(double));
-      if ( farray == NULL && memtype == MEMTYPE_FLOAT ) farray = (float*) Malloc(gridsize*sizeof(float));
+
+      size_t gridsize = vlistGridsizeMax(vlistID);
+
+      if (darray == NULL) darray = (double *) Malloc(gridsize * sizeof(double));
+      if (farray == NULL && memtype == MEMTYPE_FLOAT) farray = (float *) Malloc(gridsize * sizeof(float));
 
       t0 = timer_val(timer_read);
 
       int tsID = 0;
-      while ( (nrecs = pstreamInqTimestep(streamID, tsID)) )
-	{
+      while ((nrecs = cdoStreamInqTimestep(streamID, tsID)))
+        {
 
-	  for ( int recID = 0; recID < nrecs; recID++ )
-	    {
-	      pstreamInqRecord(streamID, &varID, &levelID);
+          for (int recID = 0; recID < nrecs; recID++)
+            {
+              pstreamInqRecord(streamID, &varID, &levelID);
 
-	      gridsize = gridInqSize(vlistInqVarGrid(vlistID, varID));
-	      nvalues += gridsize;
+              gridsize = gridInqSize(vlistInqVarGrid(vlistID, varID));
+              nvalues += gridsize;
 
-	      if ( memtype == MEMTYPE_FLOAT )
-		{
+              if (memtype == MEMTYPE_FLOAT)
+                {
                   pstreamReadRecordF(streamID, farray, &nmiss);
-                  //  for ( int i = 0; i < gridsize; ++i ) darray[i] = farray[i];
-		  data_size += gridsize*4;
-		}
-	      else
-		{
-		  pstreamReadRecord(streamID, darray, &nmiss);
-		  data_size += gridsize*8;
-		}
-	    }
+                  //  for ( size_t i = 0; i < gridsize; ++i ) darray[i] = farray[i];
+                  data_size += gridsize * 4;
+                }
+              else
+                {
+                  pstreamReadRecord(streamID, darray, &nmiss);
+                  data_size += gridsize * 8;
+                }
+            }
 
-	  if ( cdoVerbose )
-	    {
-	      tw = timer_val(timer_read) - t0;
-	      t0 = timer_val(timer_read);
-	      cdoPrint("Timestep %d: %.2f seconds", tsID+1, tw);
-	    }
+          if (cdoVerbose)
+            {
+              tw = timer_val(timer_read) - t0;
+              t0 = timer_val(timer_read);
+              cdoPrint("Timestep %d: %.2f seconds", tsID + 1, tw);
+            }
 
-	  tsID++;
-	}
+          tsID++;
+        }
 
       pstreamClose(streamID);
 
       tw = timer_val(timer_read) - tw0;
       twsum += tw;
 
-      file_size = (double) fileSize(cdoStreamName(0)->args);
+      file_size = (double) fileSize(cdoGetStreamName(0).c_str());
 
-      if ( nruns > 1 ) snprintf(sinfo, sizeof(sinfo), "(run %d)", irun+1);
+      if (nruns > 1) snprintf(sinfo, sizeof(sinfo), "(run %d)", irun + 1);
 
       print_stat(sinfo, memtype, datatype, filetype, nvalues, data_size, file_size, tw);
     }
 
-  if ( nruns > 1 )
-    print_stat("(mean)", memtype, datatype, filetype, nvalues, data_size, file_size, twsum/nruns);
+  if (nruns > 1) print_stat("(mean)", memtype, datatype, filetype, nvalues, data_size, file_size, twsum / nruns);
 
-  if ( darray ) Free(darray);
-  if ( farray ) Free(farray);
+  if (darray) Free(darray);
+  if (farray) Free(farray);
 
   cdoFinish();
 
