@@ -43,7 +43,7 @@ enum
 #define SWITCHWARN "Hit default case!This should never happen (%s).\n"
 
 static void
-selEndOfPeriod(field_type *periods, field_type history, field_type current, int isLastTimestep)
+selEndOfPeriod(Field *periods, Field history, Field current, int isLastTimestep)
 {
   size_t i;
   double pmissval = periods->missval;
@@ -124,8 +124,8 @@ selEndOfPeriod(field_type *periods, field_type history, field_type current, int
 void *
 Consecstat(void *process)
 {
-  int vdate = 0, vtime = 0;
-  int histvdate = 0, histvtime = 0;
+  int64_t vdate = 0, histvdate = 0;
+  int vtime = 0, histvtime = 0;
   int nrecs;
   int varID;
   int levelID, nlevels;
@@ -148,13 +148,13 @@ Consecstat(void *process)
   int otaxisID = taxisDuplicate(itaxisID);
   vlistDefTaxis(ovlistID, otaxisID);
 
-  field_type field;
+  Field field;
   field_init(&field);
   field.ptr = (double *) Malloc(vlistGridsizeMax(ovlistID) * sizeof(double));
 
   int nvars = vlistNvars(ivlistID);
-  field_type **vars = field_calloc(ivlistID, FIELD_PTR);
-  field_type **hist = NULL, **periods = NULL;
+  Field **vars = field_calloc(ivlistID, FIELD_PTR);
+  Field **hist = NULL, **periods = NULL;
   if (operatorID == CONSECTS)
     {
       hist = field_malloc(ivlistID, FIELD_PTR);
@@ -221,8 +221,7 @@ Consecstat(void *process)
               for (size_t i = 0; i < gridInqSize(vars[varID][levelID].grid); i++)
                 hist[varID][levelID].ptr[i] = vars[varID][levelID].ptr[i];
 #else
-              memcpy(hist[varID][levelID].ptr, vars[varID][levelID].ptr,
-                     gridInqSize(vars[varID][levelID].grid) * sizeof(double));
+              memcpy(hist[varID][levelID].ptr, vars[varID][levelID].ptr, gridInqSize(vars[varID][levelID].grid) * sizeof(double));
 #endif
               break;
             default: printf(SWITCHWARN, __func__); break;
