@@ -37,22 +37,21 @@ Derivepar(void *process)
 {
   ModelMode mode(ModelMode::UNDEF);
   int nrecs;
-  int i, offset;
+  int i;
+  size_t offset;
   int varID, levelID;
   int zaxisID;
   int nlevel;
   int surfaceID = -1;
   int sgeopotID = -1, geopotID = -1, tempID = -1, humID = -1, psID = -1, lnpsID = -1, presID = -1, gheightID = -1;
+  int lnpsID2 = -1;
   // int clwcID = -1, ciwcID = -1;
-  int code, param;
-  int pnum, pcat, pdis;
   char paramstr[32];
   char varname[CDI_MAX_NAME], stdname[CDI_MAX_NAME];
   double *single2;
   // double *lwater = NULL, *iwater = NULL;
   size_t nmiss, nmissout = 0;
   double minval, maxval;
-  int instNum, tableNum;
   gribcode_t gribcodes;
   memset(&gribcodes, 0, sizeof(gribcode_t));
 
@@ -89,8 +88,7 @@ Derivepar(void *process)
   bool useTable = false;
   for (varID = 0; varID < nvars; varID++)
     {
-      tableNum = tableInqNum(vlistInqVarTable(vlistID1, varID));
-
+      int tableNum = tableInqNum(vlistInqVarTable(vlistID1, varID));
       if (tableNum > 0 && tableNum != 255)
         {
           useTable = true;
@@ -102,16 +100,17 @@ Derivepar(void *process)
 
   for (varID = 0; varID < nvars; varID++)
     {
-      gridID = vlistInqVarGrid(vlistID1, varID);
-      zaxisID = vlistInqVarZaxis(vlistID1, varID);
-      nlevel = zaxisInqSize(zaxisID);
-      instNum = institutInqCenter(vlistInqVarInstitut(vlistID1, varID));
-      tableNum = tableInqNum(vlistInqVarTable(vlistID1, varID));
+      int gridID = vlistInqVarGrid(vlistID1, varID);
+      int zaxisID = vlistInqVarZaxis(vlistID1, varID);
+      int nlevel = zaxisInqSize(zaxisID);
+      int instNum = institutInqCenter(vlistInqVarInstitut(vlistID1, varID));
+      int tableNum = tableInqNum(vlistInqVarTable(vlistID1, varID));
 
-      code = vlistInqVarCode(vlistID1, varID);
-      param = vlistInqVarParam(vlistID1, varID);
+      int code = vlistInqVarCode(vlistID1, varID);
+      int param = vlistInqVarParam(vlistID1, varID);
 
       cdiParamToString(param, paramstr, sizeof(paramstr));
+      int pnum, pcat, pdis;
       cdiDecodeParam(param, &pnum, &pcat, &pdis);
       if (pdis >= 0 && pdis < 255) code = -1;
 
@@ -130,8 +129,7 @@ Derivepar(void *process)
           //  KNMI: HIRLAM model version 7.2 uses tableNum=1    (LAMH_D11*)
           //  KNMI: HARMONIE model version 36 uses tableNum=1   (grib*)
           //  (opreational NWP version) KNMI: HARMONIE model version 38 uses
-          //  tableNum=253 (grib,grib_md) and tableNum=1 (grib_sfx) (research
-          //  version)
+          //  tableNum=253 (grib,grib_md) and tableNum=1 (grib_sfx) (research version)
           else if (tableNum == 1 || tableNum == 253)
             {
               mode = ModelMode::HIRLAM;
@@ -155,7 +153,6 @@ Derivepar(void *process)
           strtolower(stdname);
 
           code = echamcode_from_stdname(stdname);
-
           if (code < 0)
             {
               // clang-format off
@@ -163,6 +160,7 @@ Derivepar(void *process)
               else if (psID == -1 && strcmp(varname, "aps") == 0) code = gribcodes.ps;
               else if (psID == -1 && strcmp(varname, "ps") == 0) code = gribcodes.ps;
               else if (lnpsID == -1 && strcmp(varname, "lsp") == 0) code = gribcodes.lsp;
+              else if (lnpsID2 == -1 && strcmp(varname, "lnps") == 0) code = 777;
               else if (tempID == -1 && strcmp(varname, "t") == 0) code = gribcodes.temp;
               else if (humID == -1 && strcmp(varname, "q") == 0) code = gribcodes.hum;
               // else if ( geopotID  == -1 && strcmp(stdname, "geopotential_full") == 0 ) code = gribcodes.geopot;
@@ -179,6 +177,7 @@ Derivepar(void *process)
       else if (code == gribcodes.hum && nlevel == nhlevf) humID = varID;
       else if (code == gribcodes.ps && nlevel == 1) psID = varID;
       else if (code == gribcodes.lsp && nlevel == 1) lnpsID = varID;
+      else if (code == 777 && nlevel == 1) lnpsID2 = varID;
       else if (code == gribcodes.gheight && nlevel == nhlevf) gheightID = varID;
       // else if ( code == 246 ) clwcID    = varID;
       // else if ( code == 247 ) ciwcID    = varID;
@@ -203,6 +202,8 @@ Derivepar(void *process)
       if (gheightID != -1) cdoPrint("  %s", var_stdname(geopotential_height));
     }
 
+  if (lnpsID != -1 && lnpsID2 != -1) cdoAbort("Found LOG(%s) twice: lsp and lnps!", var_stdname(surface_air_pressure));
+
   if (tempID == -1) cdoAbort("%s not found!", var_stdname(air_temperature));
 
   std::vector<double> array(gridsize);
@@ -217,8 +218,7 @@ Derivepar(void *process)
   if (operatorID == GHEIGHT)
     {
       if (humID == -1)
-        cdoWarning("%s not found - using algorithm without %s!", var_stdname(specific_humidity),
-                   var_stdname(specific_humidity));
+        cdoWarning("%s not found - using algorithm without %s!", var_stdname(specific_humidity), var_stdname(specific_humidity));
       else
         hum.resize(gridsize * nhlevf);
 
@@ -295,7 +295,6 @@ Derivepar(void *process)
   while ((nrecs = cdoStreamInqTimestep(streamID1, tsID)))
     {
       taxisCopyTimestep(taxisID2, taxisID1);
-
       pstreamDefTimestep(streamID2, tsID);
 
       for (int recID = 0; recID < nrecs; recID++)
@@ -332,11 +331,11 @@ Derivepar(void *process)
 
       if (zaxisIDh != -1)
         {
-          /* check range of ps_prog */
+          // check range of ps_prog
           arrayMinMaxMask(gridsize, ps.data(), NULL, &minval, &maxval);
           if (minval < MIN_PS || maxval > MAX_PS) cdoWarning("Surface pressure out of range (min=%g max=%g)!", minval, maxval);
 
-          /* check range of surface geopot */
+          // check range of surface geopot
           arrayMinMaxMask(gridsize, sgeopot.data(), NULL, &minval, &maxval);
           if (minval < MIN_FIS || maxval > MAX_FIS) cdoWarning("Orography out of range (min=%g max=%g)!", minval, maxval);
         }
