@@ -24,27 +24,33 @@
 #define MAX_BLOCKS 65536
 
 static void
-genGrids(int gridID1, int *gridIDs, size_t nxvals, size_t nyvals, size_t nxblocks, size_t nyblocks, size_t **gridindex,
-         size_t *ogridsize, size_t nsplit)
+genGrids(int gridID1, int *gridIDs, size_t nxvals, size_t nyvals, size_t nxblocks, size_t nyblocks,
+         std::vector<std::vector<size_t>> &gridindex, size_t *ogridsize, size_t nsplit)
 {
-  double *xpvals = NULL, *ypvals = NULL;
+  std::vector<double> xpvals, ypvals;
   int gridtype = gridInqType(gridID1);
+  bool lunstructured = gridtype == GRID_UNSTRUCTURED;
   bool lregular = true;
   if (gridtype == GRID_LONLAT || gridtype == GRID_GAUSSIAN || gridtype == GRID_GENERIC)
     lregular = true;
   else if (gridtype == GRID_CURVILINEAR)
     lregular = false;
+  else if (lunstructured)
+    lregular = false;
   else
     cdoAbort("Unsupported grid type: %s!", gridNamePtr(gridtype));
 
   size_t nx = gridInqXsize(gridID1);
-  size_t ny = gridInqYsize(gridID1);
+  size_t ny = lunstructured ? 1 : gridInqYsize(gridID1);
 
   bool lxcoord = gridInqXvals(gridID1, NULL) > 0;
   bool lycoord = gridInqYvals(gridID1, NULL) > 0;
+  bool lbounds = !lregular && gridInqXbounds(gridID1, NULL) > 0 && gridInqYbounds(gridID1, NULL) > 0;
 
   std::vector<double> xvals, yvals;
   std::vector<double> xvals2, yvals2;
+  std::vector<double> xbounds, ybounds;
+  std::vector<double> xbounds2, ybounds2;
 
   if (lxcoord)
     {
@@ -58,7 +64,7 @@ genGrids(int gridID1, int *gridIDs, size_t nxvals, size_t nyvals, size_t nxblock
           xvals2.resize(nxvals * nyvals);
         }
 
-      gridInqXvals(gridID1, &xvals[0]);
+      gridInqXvals(gridID1, xvals.data());
     }
 
   if (lycoord)
@@ -73,7 +79,26 @@ genGrids(int gridID1, int *gridIDs, size_t nxvals, size_t nyvals, size_t nxblock
           yvals2.resize(nxvals * nyvals);
         }
 
-      gridInqYvals(gridID1, &yvals[0]);
+      gridInqYvals(gridID1, yvals.data());
+    }
+
+  size_t nv = 0;
+  if (lbounds)
+    {
+      if (lregular)
+        {
+        }
+      else
+        {
+          nv = gridInqNvertex(gridID1);
+          xbounds.resize(nx * ny * nv);
+          ybounds.resize(nx * ny * nv);
+          xbounds2.resize(nxvals * nyvals * nv);
+          ybounds2.resize(nxvals * nyvals * nv);
+        }
+
+      gridInqXbounds(gridID1, xbounds.data());
+      gridInqYbounds(gridID1, ybounds.data());
     }
 
   std::vector<size_t> xlsize(nxblocks);
@@ -95,7 +120,7 @@ genGrids(int gridID1, int *gridIDs, size_t nxvals, size_t nyvals, size_t nxblock
       {
         size_t offset = iy * nyvals * nx + ix * nxvals;
         size_t gridsize2 = xlsize[ix] * ylsize[iy];
-        gridindex[index] = (size_t *) Malloc(gridsize2 * sizeof(size_t));
+        gridindex[index].resize(gridsize2);
 
         gridsize2 = 0;
         // printf("iy %d, ix %d offset %d\n", iy, ix,  offset);
@@ -107,16 +132,30 @@ genGrids(int gridID1, int *gridIDs, size_t nxvals, size_t nyvals, size_t nxblock
                 {
                   if (lxcoord) xvals2[gridsize2] = xvals[offset + j * nx + i];
                   if (lycoord) yvals2[gridsize2] = yvals[offset + j * nx + i];
+                  if (lbounds)
+                    {
+                      for (size_t k = 0; k < nv; ++k)
+                        {
+                          xbounds2[gridsize2 * nv + k] = xbounds[(offset + j * nx + i) * nv + k];
+                          ybounds2[gridsize2 * nv + k] = ybounds[(offset + j * nx + i) * nv + k];
+                        }
+                    }
                 }
               gridindex[index][gridsize2++] = offset + j * nx + i;
             }
         // printf("gridsize2 %d\n", gridsize2);
 
         int gridID2 = gridCreate(gridtype, gridsize2);
-        gridDefXsize(gridID2, xlsize[ix]);
-        gridDefYsize(gridID2, ylsize[iy]);
+        if (gridtype != GRID_UNSTRUCTURED)
+          {
+            gridDefXsize(gridID2, xlsize[ix]);
+            gridDefYsize(gridID2, ylsize[iy]);
+
+            gridDefNP(gridID2, gridInqNP(gridID1));
+          }
+
+        if (lbounds) gridDefNvertex(gridID2, nv);
 
-        gridDefNP(gridID2, gridInqNP(gridID1));
         gridDefDatatype(gridID2, gridInqDatatype(gridID1));
 
         grid_copy_attributes(gridID1, gridID2);
@@ -130,8 +169,13 @@ genGrids(int gridID1, int *gridIDs, size_t nxvals, size_t nyvals, size_t nxblock
           }
         else
           {
-            if (lxcoord) gridDefXvals(gridID2, &xvals2[0]);
-            if (lycoord) gridDefYvals(gridID2, &yvals2[0]);
+            if (lxcoord) gridDefXvals(gridID2, xvals2.data());
+            if (lycoord) gridDefYvals(gridID2, yvals2.data());
+            if (lbounds)
+              {
+                gridDefXbounds(gridID2, xbounds2.data());
+                gridDefYbounds(gridID2, ybounds2.data());
+              }
           }
 
         int projID1 = gridInqProj(gridID1);
@@ -147,22 +191,22 @@ genGrids(int gridID1, int *gridIDs, size_t nxvals, size_t nyvals, size_t nxblock
             bool lxpcoord = gridInqXvals(projID1, NULL) > 0;
             if (lxpcoord)
               {
-                if (!xpvals)
+                if (!xpvals.size())
                   {
-                    xpvals = (double *) Malloc(nx * sizeof(double));
-                    gridInqXvals(projID1, xpvals);
+                    xpvals.resize(nx);
+                    gridInqXvals(projID1, xpvals.data());
                   }
-                gridDefXvals(projID2, xpvals + ix * nxvals);
+                gridDefXvals(projID2, &xpvals[ix * nxvals]);
               }
             bool lypcoord = gridInqYvals(projID1, NULL) > 0;
             if (lypcoord)
               {
-                if (!ypvals)
+                if (!ypvals.size())
                   {
-                    ypvals = (double *) Malloc(ny * sizeof(double));
-                    gridInqYvals(projID1, ypvals);
+                    ypvals.resize(ny);
+                    gridInqYvals(projID1, ypvals.data());
                   }
-                gridDefYvals(projID2, ypvals + iy * nyvals);
+                gridDefYvals(projID2, &ypvals[iy * nyvals]);
               }
 
             gridDefProj(gridID2, projID2);
@@ -174,9 +218,6 @@ genGrids(int gridID1, int *gridIDs, size_t nxvals, size_t nyvals, size_t nxblock
         index++;
         if (index > nsplit) cdoAbort("Internal problem, index exceeded bounds!");
       }
-
-  if (xpvals) Free(xpvals);
-  if (ypvals) Free(ypvals);
 }
 
 static void
@@ -185,13 +226,13 @@ window_cell(double *array1, double *array2, size_t gridsize2, size_t *cellidx)
   for (size_t i = 0; i < gridsize2; ++i) array2[i] = array1[cellidx[i]];
 }
 
-typedef struct
+struct GridInfo
 {
   int gridID;
-  int *gridIDs;
-  size_t *gridsize;
-  size_t **gridindex;
-} sgridType;
+  std::vector<int> gridIDs;
+  std::vector<size_t> gridsize;
+  std::vector<std::vector<size_t>> gridindex;
+};
 
 void *
 Distgrid(void *process)
@@ -226,20 +267,20 @@ Distgrid(void *process)
     {
       gridID1 = vlistGrid(vlistID1, index);
       gridtype = gridInqType(gridID1);
-      if (gridtype == GRID_LONLAT || gridtype == GRID_GAUSSIAN || gridtype == GRID_CURVILINEAR
+      if (gridtype == GRID_LONLAT || gridtype == GRID_GAUSSIAN || gridtype == GRID_CURVILINEAR || gridtype == GRID_UNSTRUCTURED
           || (gridtype == GRID_GENERIC && gridInqXsize(gridID1) > 0 && gridInqYsize(gridID1) > 0))
         break;
     }
 
   if (index == ngrids)
-    cdoAbort("No Lon/Lat, Gaussian, curvilinear or generic grid found (%s data "
-             "unsupported)!",
-             gridNamePtr(gridtype));
+    cdoAbort("No Lon/Lat, Gaussian, curvilinear or generic grid found (%s data unsupported)!", gridNamePtr(gridtype));
+
+  bool lunstruct = gridtype == GRID_UNSTRUCTURED;
 
   gridID1 = vlistGrid(vlistID1, 0);
   size_t gridsize = gridInqSize(gridID1);
   size_t nx = gridInqXsize(gridID1);
-  size_t ny = gridInqYsize(gridID1);
+  size_t ny = lunstruct ? 1 : gridInqYsize(gridID1);
   for (int i = 1; i < ngrids; i++)
     {
       gridID1 = vlistGrid(vlistID1, i);
@@ -270,15 +311,13 @@ Distgrid(void *process)
   std::vector<int> vlistIDs(nsplit);
   std::vector<int> streamIDs(nsplit);
 
-  sgridType *grids = (sgridType *) Malloc(ngrids * sizeof(sgridType));
+  std::vector<GridInfo> gridinfo(ngrids);
   for (int i = 0; i < ngrids; i++)
     {
-      grids[i].gridID = vlistGrid(vlistID1, i);
-      grids[i].gridIDs = (int *) Malloc(nsplit * sizeof(int));
-      grids[i].gridsize = (size_t *) Malloc(nsplit * sizeof(size_t));
-      grids[i].gridindex = (size_t **) Malloc(nsplit * sizeof(size_t *));
-
-      for (size_t index = 0; index < nsplit; index++) grids[i].gridindex[index] = NULL;
+      gridinfo[i].gridID = vlistGrid(vlistID1, i);
+      gridinfo[i].gridIDs.resize(nsplit);
+      gridinfo[i].gridsize.resize(nsplit);
+      gridinfo[i].gridindex.resize(nsplit);
     }
 
   for (size_t index = 0; index < nsplit; index++) vlistIDs[index] = vlistDuplicate(vlistID1);
@@ -288,19 +327,20 @@ Distgrid(void *process)
   for (int i = 0; i < ngrids; i++)
     {
       gridID1 = vlistGrid(vlistID1, i);
-      genGrids(gridID1, &grids[i].gridIDs[0], xinc, yinc, nxblocks, nyblocks, grids[i].gridindex, grids[i].gridsize, nsplit);
+      genGrids(gridID1, gridinfo[i].gridIDs.data(), xinc, yinc, nxblocks, nyblocks, gridinfo[i].gridindex,
+               gridinfo[i].gridsize.data(), nsplit);
       /*
       if ( cdoVerbose )
         for ( size_t index = 0; index < nsplit; index++ )
           cdoPrint("Block %d,  gridID %d,  gridsize %zu", index+1,
-      grids[i].gridIDs[index], gridInqSize(grids[i].gridIDs[index]));
+      gridinfo[i].gridIDs[index], gridInqSize(grids[i].gridIDs[index]));
       */
-      for (size_t index = 0; index < nsplit; index++) vlistChangeGridIndex(vlistIDs[index], i, grids[i].gridIDs[index]);
+      for (size_t index = 0; index < nsplit; index++) vlistChangeGridIndex(vlistIDs[index], i, gridinfo[i].gridIDs[index]);
     }
 
   size_t gridsize2max = 0;
   for (size_t index = 0; index < nsplit; index++)
-    if (grids[0].gridsize[index] > gridsize2max) gridsize2max = grids[0].gridsize[index];
+    if (gridinfo[0].gridsize[index] > gridsize2max) gridsize2max = gridinfo[0].gridsize[index];
 
   std::vector<double> array2(gridsize2max);
 
@@ -336,9 +376,9 @@ Distgrid(void *process)
           for (size_t index = 0; index < nsplit; index++)
             {
               int i = 0;
-              window_cell(&array1[0], &array2[0], grids[i].gridsize[index], grids[i].gridindex[index]);
+              window_cell(&array1[0], &array2[0], gridinfo[i].gridsize[index], gridinfo[i].gridindex[index].data());
               pstreamDefRecord(streamIDs[index], varID, levelID);
-              if (nmiss > 0) nmiss = arrayNumMV(grids[i].gridsize[index], &array2[0], missval);
+              if (nmiss > 0) nmiss = arrayNumMV(gridinfo[i].gridsize[index], &array2[0], missval);
               pstreamWriteRecord(streamIDs[index], &array2[0], nmiss);
             }
         }
@@ -355,15 +395,7 @@ Distgrid(void *process)
     }
 
   for (int i = 0; i < ngrids; i++)
-    {
-      for (size_t index = 0; index < nsplit; index++) gridDestroy(grids[i].gridIDs[index]);
-      Free(grids[i].gridIDs);
-      Free(grids[i].gridsize);
-
-      for (size_t index = 0; index < nsplit; index++) Free(grids[i].gridindex[index]);
-      Free(grids[i].gridindex);
-    }
-  Free(grids);
+    for (size_t index = 0; index < nsplit; index++) gridDestroy(gridinfo[i].gridIDs[index]);
 
   cdoFinish();
 
