@@ -51,8 +51,8 @@ scale_eigvec_grid(double *restrict out, int tsID, size_t npack, const size_t *re
 }
 
 static void
-scale_eigvec_time(double *restrict out, int tsID, int nts, size_t npack, const size_t *restrict pack,
-                  const double *restrict weight, double **covar, double **data, double missval, double sum_w)
+scale_eigvec_time(double *restrict out, int tsID, int nts, size_t npack, const size_t *restrict pack, const double *restrict weight,
+                  double **covar, double **data, double missval, double sum_w)
 {
 #ifdef _OPENMP
 #pragma omp parallel for default(none) shared(npack, nts, tsID, pack, data, covar, out)
@@ -115,9 +115,7 @@ get_eigenmode(void)
         eigen_mode = JACOBI;
       else
         {
-          cdoWarning("Unknown environmental setting %s for CDO_SVD_MODE. "
-                     "Available options are",
-                     envstr);
+          cdoWarning("Unknown environmental setting %s for CDO_SVD_MODE. Available options are", envstr);
           cdoWarning("  - 'jacobi' for a one-sided parallelized jacobi algorithm");
           cdoWarning("  - 'danielson_lanzcos' for the D/L algorithm");
         }
@@ -152,14 +150,11 @@ get_weightmode(void)
       else if (!strncmp(envstr, "on", 2))
         weight_mode = WEIGHT_ON;
       else
-        cdoWarning("Unknown environmental setting %s for CDO_WEIGHT_MODE. "
-                   "Available options are: on/off",
-                   envstr);
+        cdoWarning("Unknown environmental setting %s for CDO_WEIGHT_MODE. Available options are: on/off", envstr);
     }
 
   if (cdoVerbose)
-    cdoPrint("Using CDO_WEIGHT_MODE '%s' from %s", weight_mode == WEIGHT_OFF ? "off" : "on",
-             envstr ? "Environment" : " default");
+    cdoPrint("Using CDO_WEIGHT_MODE '%s' from %s", weight_mode == WEIGHT_OFF ? "off" : "on", envstr ? "Environment" : " default");
 
   return weight_mode;
 }
@@ -184,7 +179,7 @@ EOFs(void *process)
 
   int calendar = CALENDAR_STANDARD;
 
-  typedef struct
+  struct eofdata_t
   {
     bool init;
     bool first_call;
@@ -192,7 +187,7 @@ EOFs(void *process)
     double *covar_array;
     double **covar;
     double **data;
-  } eofdata_t;
+  };
 
   if (cdoTimer)
     {
@@ -277,11 +272,9 @@ EOFs(void *process)
       if (n_eig > nts)
         {
           cdoWarning("Solving in time-space:");
-          cdoWarning("Number of eigen-functions to write out is bigger than "
-                     "number of time-steps.");
+          cdoWarning("Number of eigen-functions to write out is bigger than number of time-steps.");
           cdoWarning("Setting n_eig to %d.", nts);
-          cdoWarning("If You want to force a solution in grid-space use "
-                     "operator eofspatial");
+          cdoWarning("If You want to force a solution in grid-space use operator eofspatial");
           n_eig = nts;
         }
       n = nts;
@@ -293,11 +286,9 @@ EOFs(void *process)
       if ((size_t) n_eig > gridsize)
         {
           cdoWarning("Solving in spatial space");
-          cdoWarning("Number of eigen-functions to write out is bigger than "
-                     "grid size");
+          cdoWarning("Number of eigen-functions to write out is bigger than grid size");
           cdoWarning("Setting n_eig to %zu", gridsize);
-          cdoWarning("If You want to force a solution in time-space use "
-                     "operator eoftime");
+          cdoWarning("If You want to force a solution in time-space use operator eoftime");
           n_eig = gridsize;
         }
       n = gridsize;
@@ -306,12 +297,12 @@ EOFs(void *process)
   if (cdoVerbose)
     cdoPrint("Calculating %d eigenvectors and %zu eigenvalues in %s", n_eig, n, grid_space == 1 ? "grid_space" : "time_space");
 
-  double *weight = (double *) Malloc(gridsize * sizeof(double));
+  std::vector<double> weight(gridsize);
   for (size_t i = 0; i < gridsize; ++i) weight[i] = 1.;
 
   if (weight_mode == WEIGHT_ON)
     {
-      int wstatus = gridWeights(gridID1, weight);
+      int wstatus = gridWeights(gridID1, weight.data());
       if (wstatus != 0)
         {
           weight_mode = WEIGHT_OFF;
@@ -319,17 +310,16 @@ EOFs(void *process)
         }
     }
 
-  /* allocation of temporary fields and output structures */
+  // allocation of temporary fields and output structures
   size_t npack = SIZE_MAX;
-  size_t *pack = (size_t *) Malloc(gridsize * sizeof(size_t));
+  std::vector<size_t> pack(gridsize);
   double *in = (double *) Malloc(gridsize * sizeof(double));
-  eofdata_t **eofdata = (eofdata_t **) Malloc(nvars * sizeof(eofdata_t *));
+  std::vector<std::vector<eofdata_t>> eofdata(nvars);
 
   for (varID = 0; varID < nvars; ++varID)
     {
       nlevs = zaxisInqSize(vlistInqVarZaxis(vlistID1, varID));
-
-      eofdata[varID] = (eofdata_t *) Malloc(nlevs * sizeof(eofdata_t));
+      eofdata[varID].resize(nlevs);
 
       for (levelID = 0; levelID < nlevs; ++levelID)
         {
@@ -468,7 +458,7 @@ EOFs(void *process)
   pstreamDefVlist(streamID2, vlistID2);
   pstreamDefVlist(streamID3, vlistID3);
 
-  int vdate = 10101;
+  int64_t vdate = 10101;
   int vtime = 0;
   juldate_t juldate = juldate_encode(calendar, vdate, vtime);
 
@@ -510,10 +500,7 @@ EOFs(void *process)
                 {
                   eofdata[varID][levelID].first_call = false;
 
-                  if (cdoVerbose)
-                    cdoPrint("Calculating covar matrices for %i levels of "
-                             "var%i (%s)",
-                             nlevs, varID, vname);
+                  if (cdoVerbose) cdoPrint("Calculating covar matrices for %i levels of var%i (%s)", nlevs, varID, vname);
 
                   if (cdoTimer) timer_start(timer_cov);
 
@@ -544,17 +531,14 @@ EOFs(void *process)
                                   j = pack[jpack];
                                   covar[ipack][jpack] = covar[ipack][jpack] *                        // covariance
                                                         sqrt(weight[i]) * sqrt(weight[j]) / sum_w /  // weights
-                                                        nts;  // number of data contributing
+                                                        nts;                                         // number of data contributing
                                 }
                             }
                         }
                     }
                   else if (time_space)
                     {
-                      if (cdoVerbose)
-                        cdoPrint("allocating covar with %i x %i elements | "
-                                 "npack=%zu",
-                                 nts, nts, npack);
+                      if (cdoVerbose) cdoPrint("allocating covar with %i x %i elements | npack=%zu", nts, nts, npack);
 
                       covar_array = (double *) Malloc(nts * nts * sizeof(double));
                       covar = (double **) Malloc(nts * sizeof(double *));
@@ -590,15 +574,13 @@ EOFs(void *process)
                   if (cdoTimer) timer_start(timer_eig);
 
                   if (eigen_mode == JACOBI)
-                    // TODO: use return status (>0 okay, -1 did not converge at
-                    // all)
+                    // TODO: use return status (>0 okay, -1 did not converge at all)
                     parallel_eigen_solution_of_symmetric_matrix(covar, eig_val, n, __func__);
                   else
                     eigen_solution_of_symmetric_matrix(covar, eig_val, n, __func__);
 
                   if (cdoTimer) timer_stop(timer_eig);
-                  /* NOW: covar contains the eigenvectors, eig_val the
-                   * eigenvalues */
+                  /* NOW: covar contains the eigenvectors, eig_val the eigenvalues */
 
                   for (size_t i = 0; i < gridsize; ++i) out[i] = missval;
 
@@ -613,9 +595,9 @@ EOFs(void *process)
               if (tsID < n_eig)
                 {
                   if (grid_space)
-                    scale_eigvec_grid(out, tsID, npack, pack, weight, covar, sum_w);
+                    scale_eigvec_grid(out, tsID, npack, pack.data(), weight.data(), covar, sum_w);
                   else if (time_space)
-                    scale_eigvec_time(out, tsID, nts, npack, pack, weight, covar, data, missval, sum_w);
+                    scale_eigvec_time(out, tsID, nts, npack, pack.data(), weight.data(), covar, data, missval, sum_w);
 
                   nmiss = arrayNumMV(gridsize, out, missval);
                   pstreamDefRecord(streamID3, varID, levelID);
@@ -646,14 +628,9 @@ EOFs(void *process)
               Free(eofdata[varID][levelID].data);
             }
         }
-
-      Free(eofdata[varID]);
     }
 
-  Free(eofdata);
   Free(in);
-  Free(pack);
-  Free(weight);
 
   pstreamClose(streamID3);
   pstreamClose(streamID2);
