@@ -25,7 +25,6 @@ EstFreq(void *process)
 {
   int nrecs;
   int varID, levelID;
-  size_t gridsize;
   size_t nmiss;
 
   cdoInitialize(process);
@@ -47,16 +46,16 @@ EstFreq(void *process)
 
   int ntsteps = vlistNtsteps(vlistID1);
 
-  double *array = NULL;
+  std::vector<double> array;
   if (!lcopy)
     {
-      gridsize = vlistGridsizeMax(vlistID1);
-      array = (double *) Malloc(gridsize * sizeof(double));
+      size_t gridsizemax = vlistGridsizeMax(vlistID1);
+      array.resize(gridsizemax);
     }
 
   int tsID = 0;
-  int fyear, lyear, fmonth, lmonth, lymonth, dummy;
-  int step_per_year = 0, step_per_month, currentyear, currentmon;
+  int fyear, lyear, fmonth, lmonth, dummy;
+  int step_per_year = 0, currentyear, currentmon;
 
   while ((nrecs = streamInqTimestep(streamID1, tsID)))
     {
@@ -70,7 +69,7 @@ EstFreq(void *process)
         cdiDecodeDate(taxisInqVdate(taxisID1), &currentyear, &currentmon, &dummy);
       if (currentyear == fyear)
         {
-          lymonth = currentmon;
+          // lymonth = currentmon;
           step_per_year++;
         }
       taxisCopyTimestep(taxisID2, taxisID1);
@@ -87,8 +86,8 @@ EstFreq(void *process)
             }
           else
             {
-              streamReadRecord(streamID1, array, &nmiss);
-              streamWriteRecord(streamID2, array, nmiss);
+              streamReadRecord(streamID1, array.data(), &nmiss);
+              streamWriteRecord(streamID2, array.data(), nmiss);
             }
         }
 
@@ -99,15 +98,13 @@ EstFreq(void *process)
 
   if (ntsteps > 2)
     {
-      int reclast = streamInqTimestep(streamID2, ntsteps);
+      streamInqTimestep(streamID2, ntsteps);
       cdiDecodeDate(taxisInqVdate(taxisID2), &lyear, &lmonth, &dummy);
-      /* First, estimation by maximal number of time steps divided by covered
-       * years between last and first time step */
+      /* First, estimation by maximal number of time steps divided by covered years between last and first time step */
       if (cdoVerbose)
-        printf("Frequency is calculated by dividing the number of time steps "
-               "'%d' included in the time axis by the covered years of the "
-               "time axis\ncomputed by the difference of the year of the last "
-               "time stamp '%d' and the year of the first time stamp '%d'.\n",
+        printf("Frequency is calculated by dividing the number of time steps '%d' included in the time axis by the covered years"
+               " of the time axis\ncomputed by the difference of the year of the last time stamp '%d' and the year of the first"
+               " time stamp '%d'.\n",
                ntsteps, lyear, fyear);
       double covered_years = lyear - fyear + 1.0;
       if (DBL_IS_EQUAL(ntsteps / covered_years, 1.))
@@ -127,17 +124,13 @@ EstFreq(void *process)
         {
           int covered_months = lmonth - fmonth + 1;
           if (cdoVerbose)
-            printf("The fraction ntsteps / covered_years = '%f' is neither 1, "
-                   "12, 365, 365.25, 366 nor a multiple of 365 which would "
-                   "correspond to frequencies yearly, monthly, daily or "
-                   "subdaily respectively.\n Next try:\n\nFrequency is "
-                   "calculated by dividing the number of time steps '%d' in "
-                   "year '%d' by the covered months in that year '%d'.\n",
+            printf("The fraction ntsteps / covered_years = '%f' is neither 1, 12, 365, 365.25, 366 nor a multiple of 365 which "
+                   "would correspond to frequencies yearly, monthly, daily or subdaily respectively.\n Next try:\n\nFrequency is "
+                   "calculated by dividing the number of time steps '%d' in year '%d' by the covered months in that year '%d'.\n",
                    ntsteps / covered_years, step_per_year, fyear, covered_months);
           if (step_per_year > 366 * 8)
-            cdoAbort("Step per year '%d' in year '%d' is bigger than 366*8 "
-                     "which corresponds to a frequency of sub-3hourly! This is "
-                     "not yet enabled.",
+            cdoAbort("Step per year '%d' in year '%d' is bigger than 366*8 which corresponds to a frequency of sub-3hourly!"
+                     " This is not yet enabled.",
                      step_per_year, fyear);
           else
             {
@@ -155,9 +148,8 @@ EstFreq(void *process)
         }
     }
   else
-    cdoAbort("For %d found timesteps no frequency can be computed - at least 3 "
-             "timesteps are required.",
-             ntsteps);
+    cdoAbort("For %d found timesteps no frequency can be computed - at least 3 timesteps are required.", ntsteps);
+
   if (cdoVerbose) printf("Your file indicates a frequency of '%s'.\n", frequency);
   cdiDefAttTxt(vlistID2, CDI_GLOBAL, "frequency", 3, frequency);
 
@@ -166,8 +158,6 @@ EstFreq(void *process)
 
   vlistDestroy(vlistID2);
 
-  if (array) Free(array);
-
   cdoFinish();
 
   return 0;
