@@ -42,7 +42,7 @@
 #define NALLOC_INC 1024
 
 /* include from Tinfo.c */
-void getTimeInc(double jdelta, int vdate0, int vdate1, int *incperiod, int *incunit);
+void getTimeInc(double jdelta, int64_t vdate0, int64_t vdate1, int64_t *incperiod, int *incunit);
 
 static void
 create_fmasc(int nts, double fdata, double fmin, double fmax, int *fmasc)
@@ -121,12 +121,13 @@ Filter(void *process)
   int varID, levelID;
   int nalloc = 0;
   size_t nmiss;
-  int incperiod0, incunit0, incunit;
+  int64_t incperiod0;
+  int incunit0, incunit;
   int year0, month0, day0;
   bool use_fftw = false;
   double fmin = 0, fmax = 0;
   double fdata = 0;
-  dtlist_type *dtlist = dtlist_new();
+  DateTimeList dtlist;
   struct FftMemory
   {
     std::vector<double> array1;
@@ -172,7 +173,7 @@ Filter(void *process)
   int calendar = taxisInqCalendar(taxisID1);
 
   int nvars = vlistNvars(vlistID1);
-  std::vector<field_type **> vars;
+  std::vector<Field **> vars;
 
   int tsID = 0;
   while ((nrecs = cdoStreamInqTimestep(streamID1, tsID)))
@@ -183,7 +184,7 @@ Filter(void *process)
           vars.resize(nalloc);
         }
 
-      dtlist_taxisInqTimestep(dtlist, taxisID1, tsID);
+      dtlist.taxisInqTimestep(taxisID1, tsID);
 
       vars[tsID] = field_malloc(vlistID1, FIELD_NONE);
 
@@ -201,12 +202,12 @@ Filter(void *process)
       /* get and check time increment */
       if (tsID > 0)
         {
-          int incperiod = 0;
+          int64_t incperiod = 0;
           int year, month, day;
-          int vdate0 = dtlist_get_vdate(dtlist, tsID - 1);
-          int vdate = dtlist_get_vdate(dtlist, tsID);
-          int vtime0 = dtlist_get_vtime(dtlist, tsID - 1);
-          int vtime = dtlist_get_vtime(dtlist, tsID);
+          int64_t vdate0 = dtlist.getVdate(tsID - 1);
+          int64_t vdate = dtlist.getVdate(tsID);
+          int vtime0 = dtlist.getVtime(tsID - 1);
+          int vtime = dtlist.getVtime(tsID);
 
           cdiDecodeDate(vdate0, &year0, &month0, &day0);
           cdiDecodeDate(vdate, &year, &month, &day);
@@ -221,7 +222,7 @@ Filter(void *process)
               incperiod = incperiod0;
               if (incperiod == 0) cdoAbort("Time step must be different from zero!");
               incunit = incunit0;
-              if (cdoVerbose) cdoPrint("Time step %i %s", incperiod, tunits[incunit]);
+              if (cdoVerbose) cdoPrint("Time step %lld %s", incperiod, tunits[incunit]);
               fdata = 1. * iunits[incunit] / incperiod;
             }
           else
@@ -235,7 +236,7 @@ Filter(void *process)
             }
 
           if (!(incperiod == incperiod0 && incunit == incunit0))
-            cdoWarning("Time increment in step %i (%d%s) differs from step 1 (%d%s)!", tsID, incperiod, tunits[incunit],
+            cdoWarning("Time increment in step %d (%lld%s) differs from step 1 (%lld%s)!", tsID, incperiod, tunits[incunit],
                        incperiod0, tunits[incunit0]);
         }
       tsID++;
@@ -326,8 +327,7 @@ Filter(void *process)
 
                   filter_fftw(nts, fmasc, ompmem[ompthID].out_fft, &ompmem[ompthID].p_T2S, &ompmem[ompthID].p_S2T);
 
-                  for (int tsID = 0; tsID < nts; tsID++)
-                    vars[tsID][varID][levelID].ptr[i] = ompmem[ompthID].in_fft[tsID][0] / nts;
+                  for (int tsID = 0; tsID < nts; tsID++) vars[tsID][varID][levelID].ptr[i] = ompmem[ompthID].in_fft[tsID][0] / nts;
                 }
 #endif
             }
@@ -368,7 +368,7 @@ Filter(void *process)
 
   for (int tsID = 0; tsID < nts; tsID++)
     {
-      dtlist_taxisDefTimestep(dtlist, taxisID2, tsID);
+      dtlist.taxisDefTimestep(taxisID2, tsID);
       pstreamDefTimestep(streamID2, tsID);
 
       for (int varID = 0; varID < nvars; varID++)
@@ -391,8 +391,6 @@ Filter(void *process)
       field_free(vars[tsID], vlistID1);
     }
 
-  dtlist_delete(dtlist);
-
   pstreamClose(streamID2);
   pstreamClose(streamID1);
 
