@@ -19,24 +19,21 @@
 #include "cdo_int.h"
 #include "grid.h"
 
-void check_lon_range(long nlons, double *lons);
-void check_lat_range(long nlats, double *lats);
-
-typedef struct
+struct grid_type
 {
   int gridID;
   long size;
   long num_cell_corners;
   double *cell_corner_lon;
   double *cell_corner_lat;
-} grid_type;
+};
 
-typedef struct
+struct cellsearch_type
 {
   grid_type *src_grid;
   grid_type *tgt_grid;
   float *src_cell_bound_box;
-} cellsearch_type;
+};
 
 static grid_type *
 grid_new(int gridID, const char *txt)
@@ -81,9 +78,6 @@ grid_new(int gridID, const char *txt)
   grid_to_radian(xunits, grid->num_cell_corners * grid->size, grid->cell_corner_lon, "grid corner lon");
   grid_to_radian(yunits, grid->num_cell_corners * grid->size, grid->cell_corner_lat, "grid corner lat");
 
-  // check_lon_range(grid->num_cell_corners*grid->size, grid->cell_corner_lon);
-  // check_lat_range(grid->num_cell_corners*grid->size, grid->cell_corner_lat);
-
   if (lgrid_destroy) gridDestroy(gridID);
 
   return grid;
@@ -206,11 +200,9 @@ search_cells(cellsearch_type *cellsearch, long tgt_cell_add, long *srch_add)
   for (long src_cell_add = 0; src_cell_add < src_grid->size; ++src_cell_add)
     {
       src_cell_addm4 = src_cell_add << 2;
-      if ((src_cell_bound_box[src_cell_addm4 + 2] <= bound_box_lon2)
-          && (src_cell_bound_box[src_cell_addm4 + 3] >= bound_box_lon1))
+      if ((src_cell_bound_box[src_cell_addm4 + 2] <= bound_box_lon2) && (src_cell_bound_box[src_cell_addm4 + 3] >= bound_box_lon1))
         {
-          if ((src_cell_bound_box[src_cell_addm4] <= bound_box_lat2)
-              && (src_cell_bound_box[src_cell_addm4 + 1] >= bound_box_lat1))
+          if ((src_cell_bound_box[src_cell_addm4] <= bound_box_lat2) && (src_cell_bound_box[src_cell_addm4 + 1] >= bound_box_lat1))
             {
               srch_add[num_srch_cells] = src_cell_add;
               num_srch_cells++;
