@@ -188,8 +188,8 @@ vert_gen_weights(int expol, int nlev1, double *lev1, int nlev2, double *lev2, in
 }
 
 static void
-vert_gen_weights3d1d(bool expol, int nlev1, size_t gridsize, double *xlev1, int nlev2, double *lev2, int *xlev_idx1,
-                     int *xlev_idx2, double *xlev_wgt1, double *xlev_wgt2)
+vert_gen_weights3d1d(bool expol, int nlev1, size_t gridsize, double *xlev1, int nlev2, double *lev2, int *xlev_idx1, int *xlev_idx2,
+                     double *xlev_wgt1, double *xlev_wgt2)
 {
   std::vector<double> lev1(nlev1);
   std::vector<int> lev_idx1(nlev2);
@@ -321,7 +321,7 @@ Intlevel(void *process)
   // Find z-variable
   int zaxisID2 = CDI_UNDEFID;
   int nlev1 = 0;
-  double *lev1 = NULL;
+  std::vector<double> lev1;
   int zvarID = CDI_UNDEFID;
   bool zvarIsVarying = false;
   size_t zvarGridsize = 0;
@@ -345,7 +345,7 @@ Intlevel(void *process)
       zaxisID1 = vlistInqVarZaxis(vlistID1, zvarID);
       nlev1 = zaxisInqSize(zaxisID1);
 
-      lev1 = (double *) Malloc(zvarGridsize * (nlev1 + 2) * sizeof(double));
+      lev1.resize(zvarGridsize * (nlev1 + 2));
 
       zaxisID2 = zaxisCreate(ZAXIS_GENERIC, nlev2);
 
@@ -393,11 +393,11 @@ Intlevel(void *process)
       zaxisDefDatatype(zaxisID2, zaxisInqDatatype(zaxisID1));
 
       nlev1 = nlevel;
-      lev1 = (double *) Malloc((nlev1 + 2) * sizeof(double));
-      cdoZaxisInqLevels(zaxisID1, lev1 + 1);
+      lev1.resize(nlev1 + 2);
+      cdoZaxisInqLevels(zaxisID1, &lev1[1]);
 
-      bool lup = levelDirUp(nlev1, lev1 + 1);
-      bool ldown = levelDirDown(nlev1, lev1 + 1);
+      bool lup = levelDirUp(nlev1, &lev1[1]);
+      bool ldown = levelDirDown(nlev1, &lev1[1]);
 
       if (lup)
         {
@@ -423,10 +423,10 @@ Intlevel(void *process)
   for (int i = 0; i < nzaxis; i++)
     if (zaxisID1 == vlistZaxis(vlistID1, i)) vlistChangeZaxisIndex(vlistID2, i, zaxisID2);
 
-  int *lev_idx1 = (int *) Malloc(wisize * sizeof(int));
-  int *lev_idx2 = (int *) Malloc(wisize * sizeof(int));
-  double *lev_wgt1 = (double *) Malloc(wisize * sizeof(double));
-  double *lev_wgt2 = (double *) Malloc(wisize * sizeof(double));
+  std::vector<int> lev_idx1(wisize);
+  std::vector<int> lev_idx2(wisize);
+  std::vector<double> lev_wgt1(wisize);
+  std::vector<double> lev_wgt2(wisize);
 
   int streamID2 = cdoStreamOpenWrite(cdoStreamName(1), cdoFiletype());
 
@@ -490,14 +490,16 @@ Intlevel(void *process)
                 {
                   size_t offset1 = zvarGridsize * levelID;
                   size_t offset2 = zvarGridsize * (levelID + 1);
-                  arrayCopy(zvarGridsize, vardata1[zvarID] + offset1, lev1 + offset2);
+                  arrayCopy(zvarGridsize, vardata1[zvarID] + offset1, &lev1[offset2]);
                 }
 
-              vert_init_level_0_and_N(nlev1, zvarGridsize, lev1);
-              vert_gen_weights3d1d(expol, nlev1 + 2, zvarGridsize, lev1, nlev2, lev2, lev_idx1, lev_idx2, lev_wgt1, lev_wgt2);
+              vert_init_level_0_and_N(nlev1, zvarGridsize, lev1.data());
+              vert_gen_weights3d1d(expol, nlev1 + 2, zvarGridsize, lev1.data(), nlev2, lev2, lev_idx1.data(), lev_idx2.data(),
+                                   lev_wgt1.data(), lev_wgt2.data());
             }
           else
-            vert_gen_weights(expol, nlev1 + 2, lev1, nlev2, lev2, lev_idx1, lev_idx2, lev_wgt1, lev_wgt2);
+            vert_gen_weights(expol, nlev1 + 2, lev1.data(), nlev2, lev2, lev_idx1.data(), lev_idx2.data(), lev_wgt1.data(),
+                             lev_wgt2.data());
         }
 
       for (varID = 0; varID < nvars; varID++)
@@ -509,11 +511,11 @@ Intlevel(void *process)
               size_t gridsize = gridInqSize(gridID);
 
               if (zvarname)
-                vert_interp_lev3d(gridsize, missval, vardata1[varID], vardata2[varID], nlev2, lev_idx1, lev_idx2, lev_wgt1,
-                                  lev_wgt2);
+                vert_interp_lev3d(gridsize, missval, vardata1[varID], vardata2[varID], nlev2, lev_idx1.data(), lev_idx2.data(),
+                                  lev_wgt1.data(), lev_wgt2.data());
               else
-                vert_interp_lev(gridsize, missval, vardata1[varID], vardata2[varID], nlev2, lev_idx1, lev_idx2, lev_wgt1,
-                                lev_wgt2);
+                vert_interp_lev(gridsize, missval, vardata1[varID], vardata2[varID], nlev2, lev_idx1.data(), lev_idx2.data(),
+                                lev_wgt1.data(), lev_wgt2.data());
 
               for (levelID = 0; levelID < nlev2; levelID++)
                 {
@@ -553,13 +555,6 @@ Intlevel(void *process)
       if (varinterp[varID]) Free(vardata2[varID]);
     }
 
-  Free(lev_idx1);
-  Free(lev_idx2);
-  Free(lev_wgt1);
-  Free(lev_wgt2);
-
-  Free(lev1);
-
   cdoFinish();
 
   return 0;
