@@ -22,12 +22,14 @@
 
 #include "hetaeta.h"
 #include <cdi.h>
-#include "cdo.h"
+
 #include "cdo_int.h"
-#include "pstream.h"
+#include "pstream_int.h"
 #include "after_vertint.h"
 #include "listarray.h"
 #include "stdnametable.h"
+#include "util_string.h"
+#include "timer.h"
 
 static void
 setmissval(long nvals, int *imiss, double missval, double *array)
@@ -35,8 +37,7 @@ setmissval(long nvals, int *imiss, double missval, double *array)
   if (imiss)
     {
       for (long i = 0; i < nvals; ++i)
-        if (imiss[i])
-          array[i] = missval;
+        if (imiss[i]) array[i] = missval;
     }
 }
 
@@ -45,8 +46,7 @@ corr_hum(long gridsize, double *q, double q_min)
 {
   for (long i = 0; i < gridsize; ++i)
     {
-      if (q[i] < q_min)
-        q[i] = q_min;
+      if (q[i] < q_min) q[i] = q_min;
     }
 }
 
@@ -78,16 +78,14 @@ ncctop(double cptop, long nlev, long nlevp1, double *vct_a, double *vct_b)
 
   /* full level pressure */
 
-  for (long jk = 0; jk < nlev; ++jk)
-    zp[jk] = (zph[jk] + zph[jk + 1]) * 0.5;
+  for (long jk = 0; jk < nlev; ++jk) zp[jk] = (zph[jk] + zph[jk + 1]) * 0.5;
 
   /* search for pressure level cptop (Pa) */
 
   for (long jk = 0; jk < nlev; ++jk)
     {
       nctop = jk;
-      if (zp[jk] >= cptop)
-        break;
+      if (zp[jk] >= cptop) break;
     }
 
   return nctop;
@@ -111,22 +109,17 @@ vctFromFile(const char *filename, int *nvct)
 
   while (readline(fp, line, 1024))
     {
-      if (line[0] == '#' || line[0] == '\0')
-        continue;
+      if (line[0] == '#' || line[0] == '\0') continue;
 
       pline = line;
       num = (int) strtod(pline, &pline);
-      if (pline == NULL)
-        cdoAbort("Format error in VCT file %s!", filename);
-      if (num != i)
-        cdoWarning("Inconsistent VCT file, entry %d is %d.", i, num);
+      if (pline == NULL) cdoAbort("Format error in VCT file %s!", filename);
+      if (num != i) cdoWarning("Inconsistent VCT file, entry %d is %d.", i, num);
 
-      if (i + maxvct / 2 >= maxvct - 1)
-        cdoAbort("Too many values in VCT file!");
+      if (i + maxvct / 2 >= maxvct - 1) cdoAbort("Too many values in VCT file!");
 
       vct2[i] = strtod(pline, &pline);
-      if (pline == NULL)
-        cdoAbort("Format error in VCT file %s!", filename);
+      if (pline == NULL) cdoAbort("Format error in VCT file %s!", filename);
 
       vct2[i + maxvct / 2] = strtod(pline, &pline);
 
@@ -138,8 +131,7 @@ vctFromFile(const char *filename, int *nvct)
   int nvct2 = 2 * i;
   int nlevh2 = i - 1;
 
-  for (i = 0; i < nlevh2 + 1; ++i)
-    vct2[i + nvct2 / 2] = vct2[i + maxvct / 2];
+  for (i = 0; i < nlevh2 + 1; ++i) vct2[i + nvct2 / 2] = vct2[i + maxvct / 2];
 
   vct2 = (double *) Realloc(vct2, nvct2 * sizeof(double));
 
@@ -149,12 +141,12 @@ vctFromFile(const char *filename, int *nvct)
 }
 
 static void
-vert_sum(double *sum, double *var3d, long gridsize, long nlevel)
+vert_sum(double *sum, double *var3d, size_t gridsize, long nlevel)
 {
-  long i, k;
+  size_t i;
+  int k;
 
-  for (i = 0; i < gridsize; ++i)
-    sum[i] = 0;
+  for (i = 0; i < gridsize; ++i) sum[i] = 0;
 
   for (k = 0; k < nlevel; ++k)
     for (i = 0; i < gridsize; ++i)
@@ -164,12 +156,12 @@ vert_sum(double *sum, double *var3d, long gridsize, long nlevel)
 }
 
 static void
-vert_sumw(double *sum, double *var3d, long gridsize, long nlevel, double *deltap)
+vert_sumw(double *sum, double *var3d, size_t gridsize, long nlevel, double *deltap)
 {
-  long i, k;
+  size_t i;
+  int k;
 
-  for (i = 0; i < gridsize; ++i)
-    sum[i] = 0;
+  for (i = 0; i < gridsize; ++i) sum[i] = 0;
 
   for (k = 0; k < nlevel; ++k)
     for (i = 0; i < gridsize; ++i)
@@ -211,8 +203,7 @@ vlist_hybrid_vct(int vlistID, int *rzaxisIDh, int *rnvct, int *rnhlevf)
             }
           else
             {
-              if (cdoVerbose)
-                cdoPrint("nlevel = (nvct1/2 - 1): nlevel = %d", nlevel);
+              if (cdoVerbose) cdoPrint("nlevel = (nvct1/2 - 1): nlevel = %d", nlevel);
               if (nlevel < (nvct / 2 - 1))
                 cdoPrint("z-axis %d has only %d of %d hybrid sigma pressure levels!", i + 1, nlevel, (nvct / 2 - 1));
             }
@@ -229,11 +220,12 @@ vlist_hybrid_vct(int vlistID, int *rzaxisIDh, int *rnvct, int *rnhlevf)
 #define MAX_VARS3D 1024
 
 void *
-Remapeta(void *argument)
+Remapeta(void *process)
 {
-  int nfis2gp = 0;
+  size_t nfis2gp = 0;
   int nrecs;
-  int i, iv;
+  int i;
+  int iv;
   int varID, levelID;
   int nvars3D = 0;
   int sgeopotID = -1, tempID = -1, sqID = -1, psID = -1, lnpsID = -1;
@@ -259,10 +251,9 @@ Remapeta(void *argument)
   double cconst = 1.E-6;
   double cptop = 0; /* min. pressure level for cond. */
 
-  if (cdoTimer)
-    timer_hetaeta = timer_new("Remapeta_hetaeta");
+  if (cdoTimer) timer_hetaeta = timer_new("Remapeta_hetaeta");
 
-  cdoInitialize(argument);
+  cdoInitialize(process);
 
   // clang-format off
   int REMAPETA  = cdoOperatorAdd("remapeta",   0, 0, "VCT file name");
@@ -294,57 +285,50 @@ Remapeta(void *argument)
   double *b2 = vct2 + nvct2 / 2;
 
   if (cdoVerbose)
-    for (i = 0; i < nhlevf2 + 1; ++i)
-      cdoPrint("vct2: %5d %25.17f %25.17f", i, vct2[i], vct2[nvct2 / 2 + i]);
+    for (i = 0; i < nhlevf2 + 1; ++i) cdoPrint("vct2: %5d %25.17f %25.17f", i, vct2[i], vct2[nvct2 / 2 + i]);
 
-  int streamID1 = pstreamOpenRead(cdoStreamName(0));
+  int streamID1 = cdoStreamOpenRead(cdoStreamName(0));
 
   if (operatorArgc() == 2)
     {
       lfis2 = true;
 
       const char *fname = operatorArgv()[1];
-      argument_t *fileargument = file_argument_new(fname);
-      int streamID = pstreamOpenRead(fileargument);
-      file_argument_free(fileargument);
+      int streamID = streamOpenRead(fname);
 
-      int vlistID1 = pstreamInqVlist(streamID);
+      int vlistID1 = streamInqVlist(streamID);
 
-      pstreamInqRecord(streamID, &varID, &levelID);
+      streamInqRecord(streamID, &varID, &levelID);
       int gridID = vlistInqVarGrid(vlistID1, varID);
       nfis2gp = gridInqSize(gridID);
 
       fis2 = (double *) Malloc(nfis2gp * sizeof(double));
 
-      pstreamReadRecord(streamID, fis2, &nmiss);
+      streamReadRecord(streamID, fis2, &nmiss);
 
       if (nmiss)
         {
           missval = vlistInqVarMissval(vlistID1, varID);
           imiss = (int *) Malloc(nfis2gp * sizeof(int));
-          for (i = 0; i < nfis2gp; ++i)
+          for (size_t i = 0; i < nfis2gp; ++i)
             {
-              if (DBL_IS_EQUAL(fis2[i], missval))
-                imiss[i] = 1;
-              else
-                imiss[i] = 0;
+              imiss[i] = (DBL_IS_EQUAL(fis2[i], missval));
             }
 
           nmissout = nmiss;
         }
 
       /* check range of surface_geopotential */
-      minmaxval(nfis2gp, fis2, imiss, &minval, &maxval);
+      arrayMinMaxMask(nfis2gp, fis2, imiss, &minval, &maxval);
       if (minval < MIN_FIS || maxval > MAX_FIS)
         cdoWarning("%s out of range (min=%g max=%g)!", var_stdname(surface_geopotential), minval, maxval);
 
-      if (minval < -1.e10 || maxval > 1.e10)
-        cdoAbort("%s out of range!", var_stdname(surface_geopotential));
+      if (minval < -1.e10 || maxval > 1.e10) cdoAbort("%s out of range!", var_stdname(surface_geopotential));
 
-      pstreamClose(streamID);
+      streamClose(streamID);
     }
 
-  int vlistID1 = pstreamInqVlist(streamID1);
+  int vlistID1 = cdoStreamInqVlist(streamID1);
   int vlistID2 = vlistDuplicate(vlistID1);
 
   int taxisID1 = vlistInqTaxis(vlistID1);
@@ -352,20 +336,17 @@ Remapeta(void *argument)
   vlistDefTaxis(vlistID2, taxisID2);
 
   int gridID = vlistGrid(vlistID1, 0);
-  if (gridInqType(gridID) == GRID_SPECTRAL)
-    cdoAbort("Spectral data unsupported!");
+  if (gridInqType(gridID) == GRID_SPECTRAL) cdoAbort("Spectral data unsupported!");
 
-  int gridsize = vlist_check_gridsize(vlistID1);
+  size_t gridsize = vlist_check_gridsize(vlistID1);
 
   int zaxisID2 = zaxisCreate(ZAXIS_HYBRID, nhlevf2);
   double *lev2 = (double *) Malloc(nhlevf2 * sizeof(double));
-  for (i = 0; i < nhlevf2; ++i)
-    lev2[i] = i + 1;
+  for (i = 0; i < nhlevf2; ++i) lev2[i] = i + 1;
   zaxisDefLevels(zaxisID2, lev2);
   Free(lev2);
 
-  if (nvct2 == 0)
-    cdoAbort("Internal problem, vct2 undefined!");
+  if (nvct2 == 0) cdoAbort("Internal problem, vct2 undefined!");
   zaxisDefVct(zaxisID2, nvct2, vct2);
 
   int surfaceID = zaxisFromName("surface");
@@ -382,21 +363,18 @@ Remapeta(void *argument)
     {
       int zaxisID = vlistZaxis(vlistID1, i);
       int nlevel = zaxisInqSize(zaxisID);
-      if (zaxisInqType(zaxisID) == ZAXIS_HYBRID && nlevel == 1)
-        vlistChangeZaxisIndex(vlistID2, i, surfaceID);
+      if (zaxisInqType(zaxisID) == ZAXIS_HYBRID && nlevel == 1) vlistChangeZaxisIndex(vlistID2, i, surfaceID);
     }
 
   double *a1 = vct1;
   double *b1 = vct1 + nvct1 / 2;
   if (cdoVerbose)
-    for (i = 0; i < nvct1 / 2; ++i)
-      cdoPrint("vct1: %5d %25.17f %25.17f", i, vct1[i], vct1[nvct1 / 2 + i]);
+    for (i = 0; i < nvct1 / 2; ++i) cdoPrint("vct1: %5d %25.17f %25.17f", i, vct1[i], vct1[nvct1 / 2 + i]);
 
-  int streamID2 = pstreamOpenWrite(cdoStreamName(1), cdoFiletype());
+  int streamID2 = cdoStreamOpenWrite(cdoStreamName(1), cdoFiletype());
   pstreamDefVlist(streamID2, vlistID2);
 
-  if (zaxisIDh == -1)
-    cdoWarning("No 3D variable with hybrid sigma pressure coordinate found!");
+  if (zaxisIDh == -1) cdoWarning("No 3D variable with hybrid sigma pressure coordinate found!");
 
   int nvars = vlistNvars(vlistID1);
 
@@ -420,7 +398,7 @@ Remapeta(void *argument)
 
           if (code == -1)
             {
-              /*                                  ECHAM                            ECMWF       */
+              /*                                  ECHAM ECMWF       */
               if (sgeopotID == -1 && (strcmp(varname, "geosp") == 0 || strcmp(varname, "z") == 0))
                 code = 129;
               else if (tempID == -1 && (strcmp(varname, "st") == 0 || strcmp(varname, "t") == 0))
@@ -448,36 +426,27 @@ Remapeta(void *argument)
       if (gridInqType(gridID) == GRID_SPECTRAL && zaxisInqType(zaxisID) == ZAXIS_HYBRID)
         cdoAbort("Spectral data on model level unsupported!");
 
-      if (gridInqType(gridID) == GRID_SPECTRAL)
-        cdoAbort("Spectral data unsupported!");
+      if (gridInqType(gridID) == GRID_SPECTRAL) cdoAbort("Spectral data unsupported!");
 
       if (zaxisInqType(zaxisID) == ZAXIS_HYBRID && zaxisIDh != -1 && nlevel == nhlevf1)
         {
-          if (!(code == 130 || code == 133))
-            varids[nvars3D++] = varID;
+          if (!(code == 130 || code == 133)) varids[nvars3D++] = varID;
         }
       else
         {
-          if (code == 130)
-            tempID = -1;
-          if (code == 133)
-            sqID = -1;
+          if (code == 130) tempID = -1;
+          if (code == 133) sqID = -1;
         }
     }
 
   if (cdoVerbose)
     {
       cdoPrint("Found:");
-      if (tempID != -1)
-        cdoPrint("  %s", var_stdname(air_temperature));
-      if (psID != -1)
-        cdoPrint("  %s", var_stdname(surface_air_pressure));
-      if (lnpsID != -1)
-        cdoPrint("  LOG(%s)", var_stdname(surface_air_pressure));
-      if (sgeopotID != -1)
-        cdoPrint("  %s", var_stdname(surface_geopotential));
-      if (sqID != -1)
-        cdoPrint("  %s", var_stdname(specific_humidity));
+      if (tempID != -1) cdoPrint("  %s", var_stdname(air_temperature));
+      if (psID != -1) cdoPrint("  %s", var_stdname(surface_air_pressure));
+      if (lnpsID != -1) cdoPrint("  LOG(%s)", var_stdname(surface_air_pressure));
+      if (sgeopotID != -1) cdoPrint("  %s", var_stdname(surface_geopotential));
+      if (sqID != -1) cdoPrint("  %s", var_stdname(specific_humidity));
     }
 
   if (tempID != -1 && sqID != -1)
@@ -486,10 +455,8 @@ Remapeta(void *argument)
     }
   else
     {
-      if (tempID != -1)
-        cdoAbort("Temperature without humidity unsupported!");
-      if (sqID != -1)
-        cdoAbort("Humidity without temperature unsupported!");
+      if (tempID != -1) cdoAbort("Temperature without humidity unsupported!");
+      if (sqID != -1) cdoAbort("Humidity without temperature unsupported!");
     }
   /*
   if ( ltq == false )
@@ -520,10 +487,8 @@ Remapeta(void *argument)
   double *fis1 = (double *) Malloc(gridsize * sizeof(double));
   double *ps1 = (double *) Malloc(gridsize * sizeof(double));
 
-  if (lfis2 == false)
-    fis2 = (double *) Malloc(gridsize * sizeof(double));
-  if (lfis2 == true && gridsize != nfis2gp)
-    cdoAbort("Orographies have different grid size!");
+  if (lfis2 == false) fis2 = (double *) Malloc(gridsize * sizeof(double));
+  if (lfis2 == true && gridsize != nfis2gp) cdoAbort("Orographies have different grid size!");
 
   double *ps2 = (double *) Malloc(gridsize * sizeof(double));
 
@@ -554,10 +519,9 @@ Remapeta(void *argument)
 
   if (zaxisIDh != -1 && sgeopotID == -1)
     {
-      if (ltq)
-        cdoWarning("%s not found - set to zero!", var_stdname(surface_geopotential));
+      if (ltq) cdoWarning("%s not found - set to zero!", var_stdname(surface_geopotential));
 
-      memset(fis1, 0, gridsize * sizeof(double));
+      arrayFill(gridsize, fis1, 0.0);
     }
 
   int presID = lnpsID;
@@ -577,11 +541,10 @@ Remapeta(void *argument)
         cdoPrint("using %s", var_stdname(surface_air_pressure));
     }
 
-  if (cdoVerbose)
-    cdoPrint("nvars3D = %d   ltq = %d", nvars3D, (int) ltq);
+  if (cdoVerbose) cdoPrint("nvars3D = %d   ltq = %d", nvars3D, (int) ltq);
 
   int tsID = 0;
-  while ((nrecs = pstreamInqTimestep(streamID1, tsID)))
+  while ((nrecs = cdoStreamInqTimestep(streamID1, tsID)))
     {
       taxisCopyTimestep(taxisID2, taxisID1);
       pstreamDefTimestep(streamID2, tsID);
@@ -591,36 +554,33 @@ Remapeta(void *argument)
           pstreamInqRecord(streamID1, &varID, &levelID);
           int zaxisID = vlistInqVarZaxis(vlistID1, varID);
           int nlevel = zaxisInqSize(zaxisID);
-          int offset = gridsize * levelID;
+          size_t offset = gridsize * levelID;
           pstreamReadRecord(streamID1, array, &nmiss);
 
           if (zaxisIDh != -1)
             {
               if (varID == sgeopotID)
-                memcpy(fis1, array, gridsize * sizeof(double));
+                arrayCopy(gridsize, array, fis1);
               else if (varID == presID)
                 {
                   if (lnpsID != -1)
-                    for (i = 0; i < gridsize; ++i)
-                      ps1[i] = exp(array[i]);
+                    for (size_t i = 0; i < gridsize; ++i) ps1[i] = exp(array[i]);
                   else if (psID != -1)
-                    memcpy(ps1, array, gridsize * sizeof(double));
+                    arrayCopy(gridsize, array, ps1);
                 }
               else if (ltq && varID == tempID)
-                memcpy(t1 + offset, array, gridsize * sizeof(double));
+                arrayCopy(gridsize, array, t1 + offset);
               else if (ltq && varID == sqID)
-                memcpy(q1 + offset, array, gridsize * sizeof(double));
+                arrayCopy(gridsize, array, q1 + offset);
               /* else if ( zaxisID == zaxisIDh ) */
               else if (zaxisInqType(zaxisID) == ZAXIS_HYBRID && nlevel == nhlevf1)
                 {
                   for (i = 0; i < nvars3D; ++i)
-                    if (varID == varids[i])
-                      break;
+                    if (varID == varids[i]) break;
 
-                  if (i == nvars3D)
-                    cdoAbort("Internal error, 3D variable not found!");
+                  if (i == nvars3D) cdoAbort("Internal error, 3D variable not found!");
 
-                  memcpy(vars1[i] + offset, array, gridsize * sizeof(double));
+                  arrayCopy(gridsize, array, vars1[i] + offset);
                 }
               else
                 {
@@ -638,19 +598,16 @@ Remapeta(void *argument)
       if (zaxisIDh != -1)
         {
           /* check range of ps_prog */
-          minmaxval(gridsize, ps1, imiss, &minval, &maxval);
-          if (minval < MIN_PS || maxval > MAX_PS)
-            cdoWarning("Surface pressure out of range (min=%g max=%g)!", minval, maxval);
+          arrayMinMaxMask(gridsize, ps1, imiss, &minval, &maxval);
+          if (minval < MIN_PS || maxval > MAX_PS) cdoWarning("Surface pressure out of range (min=%g max=%g)!", minval, maxval);
 
           /* check range of geop */
-          minmaxval(gridsize, fis1, imiss, &minval, &maxval);
-          if (minval < MIN_FIS || maxval > MAX_FIS)
-            cdoWarning("Orography out of range (min=%g max=%g)!", minval, maxval);
+          arrayMinMaxMask(gridsize, fis1, imiss, &minval, &maxval);
+          if (minval < MIN_FIS || maxval > MAX_FIS) cdoWarning("Orography out of range (min=%g max=%g)!", minval, maxval);
         }
 
       if (lfis2 == false)
-        for (int i = 0; i < gridsize; i++)
-          fis2[i] = fis1[i];
+        for (size_t i = 0; i < gridsize; i++) fis2[i] = fis1[i];
 
       if (ltq)
         {
@@ -658,10 +615,10 @@ Remapeta(void *argument)
           int nlevel = zaxisInqSize(vlistInqVarZaxis(vlistID1, varID));
           for (levelID = 0; levelID < nlevel; levelID++)
             {
-              int offset = gridsize * levelID;
+              size_t offset = gridsize * levelID;
               single2 = t1 + offset;
 
-              minmaxval(gridsize, single2, imiss, &minval, &maxval);
+              arrayMinMaxMask(gridsize, single2, imiss, &minval, &maxval);
               if (minval < MIN_T || maxval > MAX_T)
                 cdoWarning("Input temperature at level %d out of range (min=%g max=%g)!", levelID + 1, minval, maxval);
             }
@@ -670,12 +627,12 @@ Remapeta(void *argument)
           nlevel = zaxisInqSize(vlistInqVarZaxis(vlistID1, varID));
           for (levelID = 0; levelID < nlevel; levelID++)
             {
-              int offset = gridsize * levelID;
+              size_t offset = gridsize * levelID;
               single2 = q1 + offset;
 
               corr_hum(gridsize, single2, MIN_Q);
 
-              minmaxval(gridsize, single2, imiss, &minval, &maxval);
+              arrayMinMaxMask(gridsize, single2, imiss, &minval, &maxval);
               if (minval < MIN_Q || maxval > MAX_Q)
                 cdoWarning("Input humidity at level %d out of range (min=%g max=%g)!", levelID + 1, minval, maxval);
             }
@@ -683,37 +640,13 @@ Remapeta(void *argument)
 
       if (nvars3D || ltq)
         {
-          if (cdoTimer)
-            timer_start(timer_hetaeta);
-          hetaeta(ltq,
-                  gridsize,
-                  imiss,
-                  nhlevf1,
-                  a1,
-                  b1,
-                  fis1,
-                  ps1,
-                  t1,
-                  q1,
-                  nhlevf2,
-                  a2,
-                  b2,
-                  fis2,
-                  ps2,
-                  t2,
-                  q2,
-                  nvars3D,
-                  vars1,
-                  vars2,
-                  tscor,
-                  pscor,
-                  secor);
-          if (cdoTimer)
-            timer_stop(timer_hetaeta);
+          if (cdoTimer) timer_start(timer_hetaeta);
+          hetaeta(ltq, gridsize, imiss, nhlevf1, a1, b1, fis1, ps1, t1, q1, nhlevf2, a2, b2, fis2, ps2, t2, q2, nvars3D, vars1,
+                  vars2, tscor, pscor, secor);
+          if (cdoTimer) timer_stop(timer_hetaeta);
         }
 
-      if (cptop > 0)
-        nctop = ncctop(cptop, (long) nhlevf2, (long) nhlevf2 + 1, a2, b2);
+      if (cptop > 0) nctop = ncctop(cptop, (long) nhlevf2, (long) nhlevf2 + 1, a2, b2);
 
       if (zaxisIDh != -1 && sgeopotID != -1)
         {
@@ -725,8 +658,7 @@ Remapeta(void *argument)
         }
 
       if (zaxisIDh != -1 && lnpsID != -1)
-        for (i = 0; i < gridsize; ++i)
-          ps2[i] = log(ps2[i]);
+        for (size_t i = 0; i < gridsize; ++i) ps2[i] = log(ps2[i]);
 
       if (zaxisIDh != -1 && presID != -1)
         {
@@ -743,10 +675,10 @@ Remapeta(void *argument)
           int nlevel = zaxisInqSize(vlistInqVarZaxis(vlistID2, varID));
           for (levelID = 0; levelID < nlevel; levelID++)
             {
-              int offset = gridsize * levelID;
+              size_t offset = gridsize * levelID;
               single2 = t2 + offset;
 
-              minmaxval(gridsize, single2, imiss, &minval, &maxval);
+              arrayMinMaxMask(gridsize, single2, imiss, &minval, &maxval);
               if (minval < MIN_T || maxval > MAX_T)
                 cdoWarning("Output temperature at level %d out of range (min=%g max=%g)!", levelID + 1, minval, maxval);
 
@@ -759,16 +691,15 @@ Remapeta(void *argument)
           nlevel = zaxisInqSize(vlistInqVarZaxis(vlistID2, varID));
           for (levelID = 0; levelID < nlevel; levelID++)
             {
-              int offset = gridsize * levelID;
+              size_t offset = gridsize * levelID;
               single2 = q2 + offset;
 
               corr_hum(gridsize, single2, MIN_Q);
 
               if (levelID < nctop)
-                for (i = 0; i < gridsize; ++i)
-                  single2[i] = cconst;
+                for (size_t i = 0; i < gridsize; ++i) single2[i] = cconst;
 
-              minmaxval(gridsize, single2, imiss, &minval, &maxval);
+              arrayMinMaxMask(gridsize, single2, imiss, &minval, &maxval);
               if (minval < MIN_Q || maxval > MAX_Q)
                 cdoWarning("Output humidity at level %d out of range (min=%g max=%g)!", levelID + 1, minval, maxval);
 
@@ -795,7 +726,7 @@ Remapeta(void *argument)
 
               presh(NULL, half_press1, vct1, ps1, nhlevf1, gridsize);
               for (k = 0; k < nhlevf1; ++k)
-                for (i = 0; i < gridsize; ++i)
+                for (size_t i = 0; i < gridsize; ++i)
                   {
                     deltap1[k * gridsize + i] = half_press1[(k + 1) * gridsize + i] - half_press1[k * gridsize + i];
                     deltap1[k * gridsize + i] = log(deltap1[k * gridsize + i]);
@@ -804,7 +735,7 @@ Remapeta(void *argument)
 
               presh(NULL, half_press2, vct2, ps1, nhlevf2, gridsize);
               for (k = 0; k < nhlevf2; ++k)
-                for (i = 0; i < gridsize; ++i)
+                for (size_t i = 0; i < gridsize; ++i)
                   {
                     deltap2[k * gridsize + i] = half_press2[(k + 1) * gridsize + i] - half_press2[k * gridsize + i];
                     deltap2[k * gridsize + i] = log(deltap2[k * gridsize + i]);
@@ -814,19 +745,18 @@ Remapeta(void *argument)
 
           for (levelID = 0; levelID < nlevel; levelID++)
             {
-              int offset = gridsize * levelID;
+              size_t offset = gridsize * levelID;
               single2 = vars2[iv] + offset;
 
               if (operatorID == REMAPETAS || operatorID == REMAPETAZ)
                 {
                   /*
-                  for ( i = 0; i < gridsize; ++i )
+                  for ( size_t i = 0; i < gridsize; ++i )
                     if ( i %100 == 0 )
-                      printf("%d %g %g %g %g %g\n",i, single2[i], sum1[i], sum2[i], sum1[i]/sum2[i],
-                  single2[i]*sum1[i]/sum2[i]);
+                      printf("%d %g %g %g %g %g\n",i, single2[i], sum1[i],
+                  sum2[i], sum1[i]/sum2[i], single2[i]*sum1[i]/sum2[i]);
                   */
-                  for (i = 0; i < gridsize; ++i)
-                    single2[i] = single2[i] * sum1[i] / sum2[i];
+                  for (size_t i = 0; i < gridsize; ++i) single2[i] = single2[i] * sum1[i] / sum2[i];
                 }
 
               setmissval(gridsize, imiss, missval, single2);
@@ -863,33 +793,25 @@ Remapeta(void *argument)
       Free(tscor);
     }
 
-  if (imiss)
-    Free(imiss);
+  if (imiss) Free(imiss);
 
   Free(ps2);
   Free(fis2);
   Free(ps1);
   Free(fis1);
 
-  if (sum1)
-    Free(sum1);
-  if (sum2)
-    Free(sum2);
+  if (sum1) Free(sum1);
+  if (sum2) Free(sum2);
 
-  if (deltap1)
-    Free(deltap1);
-  if (deltap2)
-    Free(deltap2);
+  if (deltap1) Free(deltap1);
+  if (deltap2) Free(deltap2);
 
-  if (half_press1)
-    Free(half_press1);
-  if (half_press2)
-    Free(half_press2);
+  if (half_press1) Free(half_press1);
+  if (half_press2) Free(half_press2);
 
   Free(array);
   Free(vct2);
-  if (vct1)
-    Free(vct1);
+  if (vct1) Free(vct1);
 
   cdoFinish();
 
