@@ -22,83 +22,81 @@
 */
 
 #include <cdi.h>
-#include "cdo_int.h"  /* processSelf */
-#include "pstream.h"
+
+#include "cdo_int.h" /* processSelf */
+#include "pstream_int.h"
 #include "listarray.h"
 
-
-void *Selrec(void *argument)
+void *
+Selrec(void *process)
 {
   int nrecs;
   int varID, levelID;
-  lista_t *ilista = lista_new(INT_LISTA);
+  ListArray<int> listArrayInt;
 
-  cdoInitialize(argument);
+  cdoInitialize(process);
 
-  if ( processSelf().m_ID != 0 ) cdoAbort("This operator can't be combined with other operators!");
+  if (processSelf().m_ID != 0) cdoAbort("This operator can't be combined with other operators!");
 
   operatorInputArg("records");
 
-  int nsel = args2int_lista(operatorArgc(), operatorArgv(), ilista);
+  int nsel = listArrayInt.argvToInt(operatorArgc(), operatorArgv());
 
-  int *intarr = (int *) lista_dataptr(ilista);
+  int *intarr = listArrayInt.data();
 
-  if ( cdoVerbose )
+  if (cdoVerbose)
     {
-      for ( int i = 0; i < nsel; i++ )
-	cdoPrint("intarr entry: %d %d", i, intarr[i]);
+      for (int i = 0; i < nsel; i++) cdoPrint("intarr entry: %d %d", i, intarr[i]);
     }
 
-  int streamID1 = pstreamOpenRead(cdoStreamName(0));
+  int streamID1 = cdoStreamOpenRead(cdoStreamName(0));
 
   int filetype = pstreamInqFiletype(streamID1);
 
-  if ( filetype == CDI_FILETYPE_NC || filetype == CDI_FILETYPE_NC2 || filetype == CDI_FILETYPE_NC4 ||
-       filetype == CDI_FILETYPE_NC4C || filetype == CDI_FILETYPE_NC5 )
+  if (filetype == CDI_FILETYPE_NC || filetype == CDI_FILETYPE_NC2 || filetype == CDI_FILETYPE_NC4 || filetype == CDI_FILETYPE_NC4C
+      || filetype == CDI_FILETYPE_NC5)
     cdoAbort("This operator does not work on NetCDF data!");
 
-  int vlistID1 = pstreamInqVlist(streamID1);
+  int vlistID1 = cdoStreamInqVlist(streamID1);
   int vlistID2 = vlistDuplicate(vlistID1);
 
   int taxisID1 = vlistInqTaxis(vlistID1);
   int taxisID2 = taxisDuplicate(taxisID1);
   vlistDefTaxis(vlistID2, taxisID2);
 
-  int streamID2 = pstreamOpenWrite(cdoStreamName(1), cdoFiletype());
+  int streamID2 = cdoStreamOpenWrite(cdoStreamName(1), cdoFiletype());
   pstreamDefVlist(streamID2, vlistID2);
 
   int recordID = 0;
   int tsID = 0;
-  while ( (nrecs = pstreamInqTimestep(streamID1, tsID)) )
+  while ((nrecs = cdoStreamInqTimestep(streamID1, tsID)))
     {
       taxisCopyTimestep(taxisID2, taxisID1);
       pstreamDefTimestep(streamID2, tsID);
-     
-      for ( int recID = 0; recID < nrecs; recID++ )
-	{
-	  recordID++;
-	  pstreamInqRecord(streamID1, &varID, &levelID);
 
-	  for ( int i = 0; i < nsel; i++ )
-	    {
-	      if ( recordID == intarr[i] )
-		{
-		  pstreamDefRecord(streamID2, varID, levelID);
-		  pstreamCopyRecord(streamID2, streamID1);
+      for (int recID = 0; recID < nrecs; recID++)
+        {
+          recordID++;
+          pstreamInqRecord(streamID1, &varID, &levelID);
+
+          for (int i = 0; i < nsel; i++)
+            {
+              if (recordID == intarr[i])
+                {
+                  pstreamDefRecord(streamID2, varID, levelID);
+                  pstreamCopyRecord(streamID2, streamID1);
+
+                  break;
+                }
+            }
+        }
 
-		  break;
-		}
-	    }
-	}
-       
       tsID++;
     }
 
   pstreamClose(streamID2);
   pstreamClose(streamID1);
 
-  lista_destroy(ilista);
-
   cdoFinish();
 
   return 0;
