@@ -30,17 +30,17 @@
       Selvar     selgrid         Select grids
       Selvar     selzaxis        Select zaxis
       Selvar     seltabnum       Select parameter table number
-      Selvar     selltype        Select GRIB level type 
+      Selvar     selltype        Select GRIB level type
 */
 
-
 #include <cdi.h>
+
 #include "cdo_int.h"
-#include "pstream.h"
+#include "pstream_int.h"
 #include "listarray.h"
 
-
-void *Selvar(void *argument)
+void *
+Selvar(void *process)
 {
   int varID2, levelID2;
   int varID, levelID;
@@ -55,17 +55,17 @@ void *Selvar(void *argument)
   char **argnames = NULL;
   size_t nmiss;
   int gridnum = 0;
-  lista_t *ilista = lista_new(INT_LISTA);
-  lista_t *flista = lista_new(FLT_LISTA);
+  ListArray<int> listArrayInt;
+  ListArray<double> listArrayFlt;
 
-  cdoInitialize(argument);
+  cdoInitialize(process);
 
   bool lcopy = UNCHANGED_RECORD;
 
-# define INVERTS_SELECTION(id) (cdoOperatorF2(id) & 1)
-# define TAKES_STRINGS(id) (cdoOperatorF2(id) & 2)
-# define TAKES_INTEGERS(id) (cdoOperatorF2(id) & 4)
-# define TAKES_FLOATS(id) (cdoOperatorF2(id) & 8)
+#define INVERTS_SELECTION(id) (cdoOperatorF2(id) & 1)
+#define TAKES_STRINGS(id) (cdoOperatorF2(id) & 2)
+#define TAKES_INTEGERS(id) (cdoOperatorF2(id) & 4)
+#define TAKES_FLOATS(id) (cdoOperatorF2(id) & 8)
 
   // clang-format off
   int SELPARAM     = cdoOperatorAdd("selparam",     0, 2,   "parameters");
@@ -81,72 +81,68 @@ void *Selvar(void *argument)
   int DELPARAM     = cdoOperatorAdd("delparam",     1, 2|1, "parameter");
   int DELCODE      = cdoOperatorAdd("delcode",      1, 1,   "code numbers");
   int DELNAME      = cdoOperatorAdd("delname",      1, 2|1, "variable names");
-  int SELLTYPE     = cdoOperatorAdd("selltype",     0, 4,   "GRIB level types"); 
+  int SELLTYPE     = cdoOperatorAdd("selltype",     0, 4,   "GRIB level types");
   // clang-format on
 
   int operatorID = cdoOperatorID();
 
   operatorInputArg(cdoOperatorEnter(operatorID));
 
-  bool ldelete = (cdoOperatorF1(operatorID) == 1) ? true : false;
+  bool ldelete = (cdoOperatorF1(operatorID) == 1);
 
   int args_are_numeric = operatorArgc() > 0 && isdigit(*operatorArgv()[0]);
 
-  if ( TAKES_STRINGS(operatorID) && !( TAKES_INTEGERS(operatorID) && args_are_numeric ) )
+  if (TAKES_STRINGS(operatorID) && !(TAKES_INTEGERS(operatorID) && args_are_numeric))
     {
-      nsel     = operatorArgc();
+      nsel = operatorArgc();
       argnames = operatorArgv();
 
-      if ( cdoVerbose )
-	for ( int i = 0; i < nsel; i++ )
-	  cdoPrint("name %d = %s", i+1, argnames[i]);
+      if (cdoVerbose)
+        for (int i = 0; i < nsel; i++) cdoPrint("name %d = %s", i + 1, argnames[i]);
     }
-  else if ( TAKES_FLOATS(operatorID) )
+  else if (TAKES_FLOATS(operatorID))
     {
-      nsel = args2flt_lista(operatorArgc(), operatorArgv(), flista);
-      fltarr = (double *) lista_dataptr(flista);
+      nsel = listArrayFlt.argvToFlt(operatorArgc(), operatorArgv());
+      fltarr = listArrayFlt.data();
 
-      if ( cdoVerbose )
-	for ( int i = 0; i < nsel; i++ )
-	  cdoPrint("flt %d = %g", i+1, fltarr[i]);
+      if (cdoVerbose)
+        for (int i = 0; i < nsel; i++) cdoPrint("flt %d = %g", i + 1, fltarr[i]);
     }
   else
     {
-      nsel = args2int_lista(operatorArgc(), operatorArgv(), ilista);
-      intarr = (int *) lista_dataptr(ilista);
+      nsel = listArrayInt.argvToInt(operatorArgc(), operatorArgv());
+      intarr = listArrayInt.data();
 
-      if ( cdoVerbose )
-	for ( int i = 0; i < nsel; i++ )
-	  cdoPrint("int %d = %d", i+1, intarr[i]);
+      if (cdoVerbose)
+        for (int i = 0; i < nsel; i++) cdoPrint("int %d = %d", i + 1, intarr[i]);
     }
 
-  bool *selfound = NULL;
-  if ( nsel )
+  std::vector<bool> selfound;
+  if (nsel)
     {
-      selfound = (bool*) Malloc(nsel*sizeof(bool));
-      for ( int i = 0; i < nsel; i++ ) selfound[i] = false;
+      selfound.resize(nsel);
+      for (int i = 0; i < nsel; i++) selfound[i] = false;
     }
 
   /*
   if ( nsel == 0 )
     cdoAbort("missing code argument!");
   */
-  int streamID1 = pstreamOpenRead(cdoStreamName(0));
+  int streamID1 = cdoStreamOpenRead(cdoStreamName(0));
 
-  int vlistID1 = pstreamInqVlist(streamID1);
+  int vlistID1 = cdoStreamInqVlist(streamID1);
   int nvars = vlistNvars(vlistID1);
-  bool *vars = (bool*) Malloc(nvars*sizeof(bool));
+  std::vector<bool> vars(nvars);
 
-  if ( operatorID == SELGRID && !args_are_numeric && nsel == 1 && strncmp(argnames[0], "var=", 4) == 0 )
+  if (operatorID == SELGRID && !args_are_numeric && nsel == 1 && strncmp(argnames[0], "var=", 4) == 0)
     {
       const char *gridvarname = argnames[0] + 4;
+      if (*gridvarname == 0) cdoAbort("Variable name missing!");
 
-      if ( *gridvarname == 0 ) cdoAbort("Variable name missing!", gridvarname);
-      
-      for ( varID = 0; varID < nvars; varID++ )
+      for (varID = 0; varID < nvars; varID++)
         {
           vlistInqVarName(vlistID1, varID, varname);
-          if ( strcmp(varname, gridvarname) == 0 )
+          if (strcmp(varname, gridvarname) == 0)
             {
               int gridID = vlistInqVarGrid(vlistID1, varID);
               gridnum = 1 + vlistGridIndex(vlistID1, gridID);
@@ -156,93 +152,95 @@ void *Selvar(void *argument)
             }
         }
 
-      if ( !gridnum ) cdoAbort("Variable %s not found!", gridvarname);
+      if (!gridnum) cdoAbort("Variable %s not found!", gridvarname);
     }
 
   vlistClearFlag(vlistID1);
-  for ( varID = 0; varID < nvars; varID++ )
+  for (varID = 0; varID < nvars; varID++)
     {
       vars[varID] = ldelete;
 
       vlistInqVarName(vlistID1, varID, varname);
       vlistInqVarStdname(vlistID1, varID, stdname);
-      int param    = vlistInqVarParam(vlistID1, varID);
-      int code     = vlistInqVarCode(vlistID1, varID);
-      int tabnum   = tableInqNum(vlistInqVarTable(vlistID1, varID));
-      int gridID   = vlistInqVarGrid(vlistID1, varID);
-      int grididx  = vlistGridIndex(vlistID1, gridID);
-      int zaxisID  = vlistInqVarZaxis(vlistID1, varID);
+      int param = vlistInqVarParam(vlistID1, varID);
+      int code = vlistInqVarCode(vlistID1, varID);
+      int tabnum = tableInqNum(vlistInqVarTable(vlistID1, varID));
+      int gridID = vlistInqVarGrid(vlistID1, varID);
+      int grididx = vlistGridIndex(vlistID1, gridID);
+      int zaxisID = vlistInqVarZaxis(vlistID1, varID);
       int zaxisidx = vlistZaxisIndex(vlistID1, zaxisID);
-      int nlevs    = zaxisInqSize(zaxisID);
+      int nlevs = zaxisInqSize(zaxisID);
       gridName(gridInqType(gridID), gridname);
       zaxisInqName(zaxisID, zaxisname);
       zaxisName(zaxisInqType(zaxisID), zaxistypename);
 
       cdiParamToString(param, paramstr, sizeof(paramstr));
 
-      for ( int levID = 0; levID < nlevs; levID++ )
-	{
-	  double level = cdoZaxisInqLevel(zaxisID, levID);
+      for (int levID = 0; levID < nlevs; levID++)
+        {
+          double level = cdoZaxisInqLevel(zaxisID, levID);
 
-	  if ( ldelete ) vlistDefFlag(vlistID1, varID, levID, TRUE);
-          
-	  for ( int isel = 0; isel < nsel; isel++ )
-	    {
+          if (ldelete) vlistDefFlag(vlistID1, varID, levID, TRUE);
+
+          for (int isel = 0; isel < nsel; isel++)
+            {
               bool found = false;
-	      if ( operatorID == SELCODE ) found = intarr[isel] == code;
-	      else if ( operatorID == SELPARAM )
-                found = wildcardmatch(argnames[isel], paramstr) == 0;
-	      else if ( operatorID == SELNAME )
-                found = wildcardmatch(argnames[isel], varname) == 0;
-	      else if ( operatorID == SELSTDNAME )
-                found = wildcardmatch(argnames[isel], stdname) == 0;
-	      else if ( operatorID == SELLEVEL )
-                found = fabs(fltarr[isel] - level) < 0.0001;
-	      else if ( operatorID == SELLEVIDX )
-                found = intarr[isel] == (levID+1);
-	      else if ( operatorID == SELGRID && args_are_numeric )
-                found = intarr[isel] == (grididx+1);
-	      else if ( operatorID == SELGRID && !args_are_numeric )
-                found = memcmp(argnames[isel], gridname, strlen(argnames[isel])) == 0;
-	      else if ( operatorID == SELZAXIS && args_are_numeric )
-                found = intarr[isel] == (zaxisidx+1);
-	      else if ( operatorID == SELZAXIS && !args_are_numeric )
-                found = memcmp(argnames[isel], zaxistypename, strlen(argnames[isel])) == 0;
-	      else if ( operatorID == SELZAXISNAME )
-                found = wildcardmatch(argnames[isel], zaxisname) == 0;
-	      else if ( operatorID == SELTABNUM )
-                found = intarr[isel] == tabnum;
-	      else if ( operatorID == DELCODE )
+              if (operatorID == SELCODE)
                 found = intarr[isel] == code;
-	      else if ( operatorID == DELNAME )
+              else if (operatorID == SELPARAM)
+                found = wildcardmatch(argnames[isel], paramstr) == 0;
+              else if (operatorID == SELNAME)
                 found = wildcardmatch(argnames[isel], varname) == 0;
-	      else if ( operatorID == DELPARAM )
+              else if (operatorID == SELSTDNAME)
+                found = wildcardmatch(argnames[isel], stdname) == 0;
+              else if (operatorID == SELLEVEL)
+                found = fabs(fltarr[isel] - level) < 0.0001;
+              else if (operatorID == SELLEVIDX)
+                found = intarr[isel] == (levID + 1);
+              else if (operatorID == SELGRID && args_are_numeric)
+                found = intarr[isel] == (grididx + 1);
+              else if (operatorID == SELGRID && !args_are_numeric)
+                found = memcmp(argnames[isel], gridname, strlen(argnames[isel])) == 0;
+              else if (operatorID == SELZAXIS && args_are_numeric)
+                found = intarr[isel] == (zaxisidx + 1);
+              else if (operatorID == SELZAXIS && !args_are_numeric)
+                found = memcmp(argnames[isel], zaxistypename, strlen(argnames[isel])) == 0;
+              else if (operatorID == SELZAXISNAME)
+                found = wildcardmatch(argnames[isel], zaxisname) == 0;
+              else if (operatorID == SELTABNUM)
+                found = intarr[isel] == tabnum;
+              else if (operatorID == DELCODE)
+                found = intarr[isel] == code;
+              else if (operatorID == DELNAME)
+                found = wildcardmatch(argnames[isel], varname) == 0;
+              else if (operatorID == DELPARAM)
                 found = strcmp(argnames[isel], paramstr) == 0;
-	      else if ( operatorID == SELLTYPE )
+              else if (operatorID == SELLTYPE)
                 found = intarr[isel] == zaxis2ltype(zaxisID);
 
-	      if ( found )
-	        {
-		  vlistDefFlag(vlistID1, varID, levID, !INVERTS_SELECTION(operatorID));
-		  selfound[isel] = true;
+              if (found)
+                {
+                  vlistDefFlag(vlistID1, varID, levID, !INVERTS_SELECTION(operatorID));
+                  selfound[isel] = true;
                   vars[varID] = ldelete ? false : true;
-	        }
-	    }
-	}
+                }
+            }
+        }
     }
 
   int npar = 0;
-  for ( varID = 0; varID < nvars; varID++ ) if ( vars[varID] ) npar++;
+  for (varID = 0; varID < nvars; varID++)
+    if (vars[varID]) npar++;
 
-  for ( varID = 0; varID < nvars; varID++ )
+  for (varID = 0; varID < nvars; varID++)
     {
-      if ( vars[varID] )
+      if (vars[varID])
         {
           int zaxisID = vlistInqVarZaxis(vlistID1, varID);
-          if ( zaxisInqType(zaxisID) == ZAXIS_HYBRID )
+          if (zaxisInqType(zaxisID) == ZAXIS_HYBRID)
             {
               int psvarid = vlist_get_psvarid(vlistID1, zaxisID);
-              if ( psvarid != -1 && !vars[psvarid] )
+              if (psvarid != -1 && !vars[psvarid])
                 {
                   vars[psvarid] = true;
                   vlistDefFlag(vlistID1, psvarid, 0, !INVERTS_SELECTION(operatorID));
@@ -251,48 +249,48 @@ void *Selvar(void *argument)
         }
     }
 
-  for ( int isel = 0; isel < nsel; isel++ )
+  for (int isel = 0; isel < nsel; isel++)
     {
-      if ( selfound[isel] == false )
-	{
-	  if ( operatorID == SELCODE || operatorID == DELCODE )
+      if (selfound[isel] == false)
+        {
+          if (operatorID == SELCODE || operatorID == DELCODE)
             cdoWarning("Code number %d not found!", intarr[isel]);
-	  else if ( operatorID == SELPARAM || operatorID == DELPARAM )
+          else if (operatorID == SELPARAM || operatorID == DELPARAM)
             cdoWarning("Parameter %s not found!", argnames[isel]);
-	  else if ( operatorID == SELNAME || operatorID == DELNAME )
+          else if (operatorID == SELNAME || operatorID == DELNAME)
             cdoWarning("Variable name %s not found!", argnames[isel]);
-	  else if ( operatorID == SELSTDNAME )
+          else if (operatorID == SELSTDNAME)
             cdoWarning("Variable with standard name %s not found!", argnames[isel]);
-	  else if ( operatorID == SELLEVEL )
+          else if (operatorID == SELLEVEL)
             cdoWarning("Level %g not found!", fltarr[isel]);
-	  else if ( operatorID == SELLEVIDX )
+          else if (operatorID == SELLEVIDX)
             cdoWarning("Level index %d not found!", intarr[isel]);
-	  else if ( operatorID == SELGRID && args_are_numeric )
+          else if (operatorID == SELGRID && args_are_numeric)
             cdoWarning("Grid %d not found!", intarr[isel]);
-	  else if ( operatorID == SELGRID && !args_are_numeric )
+          else if (operatorID == SELGRID && !args_are_numeric)
             cdoWarning("Grid name %s not found!", argnames[isel]);
-	  else if ( operatorID == SELZAXIS && args_are_numeric )
+          else if (operatorID == SELZAXIS && args_are_numeric)
             cdoWarning("Zaxis %d not found!", intarr[isel]);
-	  else if ( operatorID == SELZAXIS && !args_are_numeric )
+          else if (operatorID == SELZAXIS && !args_are_numeric)
             cdoWarning("Zaxis type %s not found!", argnames[isel]);
-	  else if ( operatorID == SELZAXISNAME )
+          else if (operatorID == SELZAXISNAME)
             cdoWarning("Zaxis name %s not found!", argnames[isel]);
-	  else if ( operatorID == SELTABNUM )
+          else if (operatorID == SELTABNUM)
             cdoWarning("Table number %d not found!", intarr[isel]);
-	  else if ( operatorID == SELLTYPE )
+          else if (operatorID == SELLTYPE)
             cdoWarning("GRIB level type %d not found!", intarr[isel]);
-	}
+        }
     }
 
-  if ( npar == 0 ) cdoAbort("No variables selected!");
+  if (npar == 0) cdoAbort("No variables selected!");
 
   int vlistID2 = vlistCreate();
   cdoVlistCopyFlag(vlistID2, vlistID1);
 
   nvars = vlistNvars(vlistID2);
-  for ( varID = 0; varID < nvars; ++varID )
-    if ( vlistInqVarTimetype(vlistID2, varID) != TIME_CONSTANT ) break;
-  if ( varID == nvars ) vlistDefNtsteps(vlistID2, 0);
+  for (varID = 0; varID < nvars; ++varID)
+    if (vlistInqVarTimetype(vlistID2, varID) != TIME_CONSTANT) break;
+  if (varID == nvars) vlistDefNtsteps(vlistID2, 0);
 
   int taxisID1 = vlistInqTaxis(vlistID1);
   int taxisID2 = taxisDuplicate(taxisID1);
@@ -300,62 +298,52 @@ void *Selvar(void *argument)
 
   int nrecs = vlistNrecs(vlistID2);
 
-  int streamID2 = pstreamOpenWrite(cdoStreamName(1), cdoFiletype());
+  int streamID2 = cdoStreamOpenWrite(cdoStreamName(1), cdoFiletype());
   pstreamDefVlist(streamID2, vlistID2);
 
-  double *array = NULL;
-  if ( ! lcopy )
+  std::vector<double> array;
+  if (!lcopy)
     {
-      int gridsize = vlistGridsizeMax(vlistID1);
-      if ( vlistNumber(vlistID1) != CDI_REAL ) gridsize *= 2;
-      array = (double*) Malloc(gridsize*sizeof(double));
+      size_t gridsizemax = vlistGridsizeMax(vlistID1);
+      if (vlistNumber(vlistID1) != CDI_REAL) gridsizemax *= 2;
+      array.resize(gridsizemax);
     }
 
   int tsID = 0;
-  while ( (nrecs = pstreamInqTimestep(streamID1, tsID)) )
+  while ((nrecs = cdoStreamInqTimestep(streamID1, tsID)))
     {
       taxisCopyTimestep(taxisID2, taxisID1);
       pstreamDefTimestep(streamID2, tsID);
-     
-      for ( int recID = 0; recID < nrecs; recID++ )
-	{
-	  pstreamInqRecord(streamID1, &varID, &levelID);
-	  if ( vlistInqFlag(vlistID1, varID, levelID) == TRUE )
-	    {
-	      varID2   = vlistFindVar(vlistID2, varID);
-	      levelID2 = vlistFindLevel(vlistID2, varID, levelID);
 
-	      pstreamDefRecord(streamID2, varID2, levelID2);
-	      if ( lcopy )
-		{
-		  pstreamCopyRecord(streamID2, streamID1);
-		}
-	      else
-		{
-		  pstreamReadRecord(streamID1, array, &nmiss);
-		  pstreamWriteRecord(streamID2, array, nmiss);
-		}
-     	    }
-	}
-       
+      for (int recID = 0; recID < nrecs; recID++)
+        {
+          pstreamInqRecord(streamID1, &varID, &levelID);
+          if (vlistInqFlag(vlistID1, varID, levelID) == TRUE)
+            {
+              varID2 = vlistFindVar(vlistID2, varID);
+              levelID2 = vlistFindLevel(vlistID2, varID, levelID);
+
+              pstreamDefRecord(streamID2, varID2, levelID2);
+              if (lcopy)
+                {
+                  pstreamCopyRecord(streamID2, streamID1);
+                }
+              else
+                {
+                  pstreamReadRecord(streamID1, array.data(), &nmiss);
+                  pstreamWriteRecord(streamID2, array.data(), nmiss);
+                }
+            }
+        }
+
       tsID++;
     }
 
   pstreamClose(streamID2);
   pstreamClose(streamID1);
- 
+
   vlistDestroy(vlistID2);
 
-  if ( ! lcopy )
-    if ( array ) Free(array);
-
-  if ( vars ) Free(vars);
-
-  if ( selfound ) Free(selfound);
-
-  lista_destroy(ilista);
-  lista_destroy(flista);
-
   cdoFinish();
 
   return 0;
