@@ -231,9 +231,7 @@ Shiftxy(void *process)
       else
         {
           cdoPrint("Unsupported grid type: %s", gridNamePtr(gridtype));
-          if (gridtype == GRID_GAUSSIAN_REDUCED)
-            cdoPrint("Use option -R to convert Gaussian reduced grid to a "
-                     "regular grid!");
+          if (gridtype == GRID_GAUSSIAN_REDUCED) cdoPrint("Use option -R to convert Gaussian reduced grid to a regular grid!");
           cdoAbort("Unsupported grid type!");
         }
     }
