@@ -26,14 +26,14 @@
 #include "cdo_int.h"
 #include "pstream_int.h"
 
-typedef struct
+struct levinfo_t
 {
   int levelID;
   size_t nmiss;
   double level;
-} levinfo_t;
+};
 
-typedef struct
+struct varinfo_t
 {
   int varID;
   int nlevs;
@@ -41,7 +41,7 @@ typedef struct
   char param[CDI_MAX_NAME];
   char name[CDI_MAX_NAME];
   levinfo_t *levInfo;
-} varinfo_t;
+};
 
 static int
 cmpvarcode(const void *a, const void *b)
@@ -253,8 +253,8 @@ Sort(void *process)
               {
                 nlevs = varInfo[vindex].nlevs;
                 for (lindex = 0; lindex < nlevs; ++lindex)
-                  printf("sort out: %d %s %d %d %g\n", vindex, varInfo[vindex].name, varInfo[vindex].code,
-                         varInfo[vindex].nlevs, varInfo[vindex].levInfo[lindex].level);
+                  printf("sort out: %d %s %d %d %g\n", vindex, varInfo[vindex].name, varInfo[vindex].code, varInfo[vindex].nlevs,
+                         varInfo[vindex].levInfo[lindex].level);
               }
         }
 
