@@ -29,7 +29,8 @@
 void *
 Trend(void *process)
 {
-  int vdate = 0, vtime = 0;
+  int64_t vdate = 0;
+  int vtime = 0;
   int varID, levelID;
   size_t nmiss;
   int nrecs;
@@ -38,7 +39,7 @@ Trend(void *process)
   {
     nwork = 5
   };
-  field_type **work[5];
+  Field **work[5];
 
   cdoInitialize(process);
 
@@ -56,7 +57,7 @@ Trend(void *process)
   int nvars = vlistNvars(vlistID1);
 
   int maxrecs = vlistNrecs(vlistID1);
-  std::vector<recinfo_type> recinfo(maxrecs);
+  std::vector<RecordInfo> recinfo(maxrecs);
 
   for (varID = 0; varID < nvars; varID++) vlistDefVarDatatype(vlistID2, varID, CDI_DATATYPE_FLT64);
 
@@ -68,7 +69,7 @@ Trend(void *process)
 
   size_t gridsize = vlistGridsizeMax(vlistID1);
 
-  field_type field1, field2;
+  Field field1, field2;
   field_init(&field1);
   field_init(&field2);
   field1.ptr = (double *) Malloc(gridsize * sizeof(double));
@@ -134,12 +135,10 @@ Trend(void *process)
 
       for (size_t i = 0; i < gridsize; i++)
         {
-          temp1 = SUBMN(
-              work[2][varID][levelID].ptr[i],
-              DIVMN(MULMN(work[0][varID][levelID].ptr[i], work[3][varID][levelID].ptr[i]), work[4][varID][levelID].ptr[i]));
-          temp2 = SUBMN(
-              work[1][varID][levelID].ptr[i],
-              DIVMN(MULMN(work[0][varID][levelID].ptr[i], work[0][varID][levelID].ptr[i]), work[4][varID][levelID].ptr[i]));
+          temp1 = SUBMN(work[2][varID][levelID].ptr[i], DIVMN(MULMN(work[0][varID][levelID].ptr[i], work[3][varID][levelID].ptr[i]),
+                                                              work[4][varID][levelID].ptr[i]));
+          temp2 = SUBMN(work[1][varID][levelID].ptr[i], DIVMN(MULMN(work[0][varID][levelID].ptr[i], work[0][varID][levelID].ptr[i]),
+                                                              work[4][varID][levelID].ptr[i]));
 
           field2.ptr[i] = DIVMN(temp1, temp2);
           field1.ptr[i] = SUBMN(DIVMN(work[3][varID][levelID].ptr[i], work[4][varID][levelID].ptr[i]),
