@@ -260,8 +260,8 @@ Vertstat(void *process)
             vert[index].numlevel = nlev;
             vert[index].thickness.resize(nlev);
             vert[index].weights.resize(nlev);
-            vert[index].status
-              = getLayerThickness(useweights, genbounds, index, zaxisID, nlev, vert[index].thickness.data(), vert[index].weights.data());
+            vert[index].status = getLayerThickness(useweights, genbounds, index, zaxisID, nlev, vert[index].thickness.data(),
+                                                   vert[index].weights.data());
           }
           if (!useweights) vert[index].status = 3;
         }
@@ -272,13 +272,13 @@ Vertstat(void *process)
 
   size_t gridsize = vlistGridsizeMax(vlistID1);
 
-  field_type field;
+  Field field;
   field_init(&field);
   field.ptr = (double *) Malloc(gridsize * sizeof(double));
 
-  std::vector<field_type> vars1(nvars);
-  std::vector<field_type> samp1(nvars);
-  std::vector<field_type> vars2;
+  std::vector<Field> vars1(nvars);
+  std::vector<Field> samp1(nvars);
+  std::vector<Field> vars2;
   if (lvarstd || lrange) vars2.resize(nvars);
 
   for (varID = 0; varID < nvars; varID++)
@@ -337,9 +337,7 @@ Vertstat(void *process)
                       {
                         char varname[CDI_MAX_NAME];
                         vlistInqVarName(vlistID1, varID, varname);
-                        cdoWarning("Layer bounds not available, using constant "
-                                   "vertical weights for variable %s!",
-                                   varname);
+                        cdoWarning("Layer bounds not available, using constant vertical weights for variable %s!", varname);
                       }
                     else
                       {
