@@ -14,6 +14,7 @@
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
 */
+#include <vector>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -250,8 +251,8 @@ phcs(double *pnm, double *hnm, int waves, double pmu, double *ztemp1, double *zt
   hnm[0] = pmu * ztemp2[0];
 
   for (jn = 1; jn < waves; jn++)
-    hnm[jn] = (jn + 1) * pmu * ztemp2[jn]
-              - sqrt(((jn + jn + 3.0) * ((jn + 1) * (jn + 1) - 1.0)) / (jn + jn + 1.0)) * ztemp2[jn - 1];
+    hnm[jn]
+        = (jn + 1) * pmu * ztemp2[jn] - sqrt(((jn + jn + 3.0) * ((jn + 1) * (jn + 1) - 1.0)) / (jn + jn + 1.0)) * ztemp2[jn - 1];
 
   hnm += waves;
 
@@ -298,16 +299,16 @@ after_legini_full(int ntr, int nlat, double *restrict poli, double *restrict pol
   int waves = ntr + 1;
   int dimsp = (ntr + 1) * (ntr + 2);
 
-  double *gmu = (double *) Malloc(nlat * sizeof(double));
-  double *gwt = (double *) Malloc(nlat * sizeof(double));
+  std::vector<double> gmu(nlat);
+  std::vector<double> gwt(nlat);
 
-  gaussaw(gmu, gwt, nlat);
+  gaussaw(gmu.data(), gwt.data(), nlat);
 
-#if !defined(_OPENMP)
-  double *pnm = (double *) Malloc(dimsp * sizeof(double));
-  double *hnm = (double *) Malloc(dimsp * sizeof(double));
-  double *ztemp1 = (double *) Malloc((waves << 1) * sizeof(double));
-  double *ztemp2 = (double *) Malloc((waves << 1) * sizeof(double));
+#ifndef _OPENMP
+  std::vector<double> pnm(dimsp);
+  std::vector<double> hnm(dimsp);
+  std::vector<double> ztemp1(waves << 1);
+  std::vector<double> ztemp2(waves << 1);
 #endif
 
 #ifdef _OPENMP
@@ -316,15 +317,15 @@ after_legini_full(int ntr, int nlat, double *restrict poli, double *restrict pol
   for (jgl = 0; jgl < nlat; jgl++)
     {
 #ifdef _OPENMP
-      double *pnm = (double *) Malloc(dimsp * sizeof(double));
-      double *hnm = (double *) Malloc(dimsp * sizeof(double));
-      double *ztemp1 = (double *) Malloc((waves << 1) * sizeof(double));
-      double *ztemp2 = (double *) Malloc((waves << 1) * sizeof(double));
+      std::vector<double> pnm(dimsp);
+      std::vector<double> hnm(dimsp);
+      std::vector<double> ztemp1(waves << 1);
+      std::vector<double> ztemp2(waves << 1);
 #endif
       gmusq = 1.0 - gmu[jgl] * gmu[jgl];
       coslat[jgl] = sqrt(gmusq);
 
-      phcs(pnm, hnm, waves, gmu[jgl], ztemp1, ztemp2);
+      phcs(pnm.data(), hnm.data(), waves, gmu[jgl], ztemp1.data(), ztemp2.data());
 
       double zgwt = gwt[jgl];
       double zrafgmusqr = 1. / (PlanetRadius * gmusq);
@@ -346,23 +347,7 @@ after_legini_full(int ntr, int nlat, double *restrict poli, double *restrict pol
             if (lpol3) pol3[jsp] = pnm[jm * waves + jn] * zgwt * jm * zrafgmusqr;
             jsp += nlat;
           }
-
-#ifdef _OPENMP
-      Free(ztemp2);
-      Free(ztemp1);
-      Free(pnm);
-      Free(hnm);
-#endif
     }
-
-#if !defined(_OPENMP)
-  Free(ztemp2);
-  Free(ztemp1);
-  Free(pnm);
-  Free(hnm);
-#endif
-  Free(gwt);
-  Free(gmu);
 }
 
 void
@@ -373,12 +358,12 @@ after_legini(int ntr, int nlat, double *restrict poli, double *restrict pold, do
   int waves = ntr + 1;
   int dimpnm = (ntr + 1) * (ntr + 4) / 2;
 
-  double *gmu = (double *) Malloc(nlat * sizeof(double));
-  double *gwt = (double *) Malloc(nlat * sizeof(double));
-  double *pnm = (double *) Malloc(dimpnm * sizeof(double));
-  double *work = (double *) Malloc(3 * waves * sizeof(double));
+  std::vector<double> gmu(nlat);
+  std::vector<double> gwt(nlat);
+  std::vector<double> pnm(dimpnm);
+  std::vector<double> work(3 * waves);
 
-  gaussaw(gmu, gwt, nlat);
+  gaussaw(gmu.data(), gwt.data(), nlat);
   for (int jgl = 0; jgl < nlat; ++jgl) gwt[jgl] *= 0.5;
 
   for (int jgl = 0; jgl < nlat; ++jgl) coslat[jgl] = sqrt(1.0 - gmu[jgl] * gmu[jgl]);
@@ -387,7 +372,7 @@ after_legini(int ntr, int nlat, double *restrict poli, double *restrict pold, do
     {
       double zgwt = gwt[jgl];
 
-      jspleg1(pnm, gmu[jgl], ntr, work);
+      jspleg1(pnm.data(), gmu[jgl], ntr, work.data());
 
       int latn = jgl;
       int isp = 0;
@@ -413,11 +398,6 @@ after_legini(int ntr, int nlat, double *restrict poli, double *restrict pold, do
           isp++;
         }
     }
-
-  Free(work);
-  Free(pnm);
-  Free(gwt);
-  Free(gmu);
 }
 
 /* to slow for nec, 2.0 instead of 2.3 GFlops ( vector length too small ) */
