@@ -31,8 +31,7 @@ double
 cdoZaxisInqLevel(int zaxisID, int levelID)
 {
   int zaxistype = zaxisInqType(zaxisID);
-  double level
-      = zaxisInqLevels(zaxisID, NULL) ? zaxisInqLevel(zaxisID, levelID) : (zaxistype == ZAXIS_SURFACE) ? 0 : levelID + 1;
+  double level = zaxisInqLevels(zaxisID, NULL) ? zaxisInqLevel(zaxisID, levelID) : (zaxistype == ZAXIS_SURFACE) ? 0 : levelID + 1;
   return level;
 }
 
@@ -298,9 +297,7 @@ vlistCompareX(int vlistID1, int vlistID2, int flag)
   int nvars2 = vlistNvars(vlistID2);
   int nlevels2 = zaxisInqSize(vlistInqVarZaxis(vlistID2, 0));
 
-  if (nvars2 != 1)
-    cdoAbort("Internal problem, vlistCompareX() called with unexpected "
-             "vlistID2 argument!");
+  if (nvars2 != 1) cdoAbort("Internal problem, vlistCompareX() called with unexpected vlistID2 argument!");
 
   for (int varID = 0; varID < nvars; varID++)
     {
@@ -443,8 +440,8 @@ vlist_read_vct(int vlistID, int *rzaxisIDh, int *rnvct, int *rnhlev, int *rnhlev
                   vct = (double *) Malloc(nvct * sizeof(double));
                   zaxisInqVct(zaxisID, vct);
                   if (cdoVerbose)
-                    cdoPrint("Detected half-level model definition : nlevel == (nvct/2 - 1) (nlevel: %d, nvct: %d, "
-                             "nhlevf: %d, nhlevh: %d) ",
+                    cdoPrint("Detected half-level model definition : nlevel == (nvct/2 - 1) (nlevel: %d, nvct: %d, nhlevf: %d, "
+                             "nhlevh: %d) ",
                              nlevel, nvct, nhlevf, nhlevh);
                 }
             }
@@ -461,9 +458,9 @@ vlist_read_vct(int vlistID, int *rzaxisIDh, int *rnvct, int *rnhlev, int *rnhlev
                   vct = (double *) Malloc(nvct * sizeof(double));
                   zaxisInqVct(zaxisID, vct);
                   if (cdoVerbose)
-                    cdoPrint("Detected full-level model definition : nlevel == (nvct/2) (nlevel: %d, nvct: %d, nhlevf: "
-                             "%d, nhlevh: %d) ",
-                             nlevel, nvct, nhlevf, nhlevh);
+                    cdoPrint(
+                        "Detected full-level model definition : nlevel == (nvct/2) (nlevel: %d, nvct: %d, nhlevf: %d, nhlevh: %d) ",
+                        nlevel, nvct, nhlevf, nhlevh);
                 }
             }
           else if (nlevel == (nvct - 4 - 1))
@@ -527,7 +524,7 @@ void
 vlist_change_hybrid_zaxis(int vlistID1, int vlistID2, int zaxisID1, int zaxisID2)
 {
   int nvct0 = 0;
-  double *vct = NULL;
+  std::vector<double> vct;
 
   int nzaxis = vlistNzaxis(vlistID1);
   for (int i = 0; i < nzaxis; ++i)
@@ -538,23 +535,21 @@ vlist_change_hybrid_zaxis(int vlistID1, int vlistID2, int zaxisID1, int zaxisID2
       if (zaxisID == zaxisID1 && nlevel > 1)
         {
           int nvct = zaxisInqVctSize(zaxisID);
-          if (vct == NULL)
+          if (!vct.size())
             {
               nvct0 = nvct;
-              vct = (double *) Malloc(nvct * sizeof(double));
-              zaxisInqVct(zaxisID, vct);
+              vct.resize(nvct);
+              zaxisInqVct(zaxisID, vct.data());
 
               vlistChangeZaxisIndex(vlistID2, i, zaxisID2);
             }
           else
             {
-              if (nvct0 == nvct && memcmp(vct, zaxisInqVctPtr(zaxisID), nvct * sizeof(double)) == 0)
+              if (nvct0 == nvct && memcmp(vct.data(), zaxisInqVctPtr(zaxisID), nvct * sizeof(double)) == 0)
                 vlistChangeZaxisIndex(vlistID2, i, zaxisID2);
             }
         }
     }
-
-  if (vct) Free(vct);
 }
 
 int
