@@ -34,7 +34,7 @@
 #if defined(HAVE_DECL_ISNAN) && !defined(DISABLE_ISNAN)
 #define DBL_IS_NAN(x) (std::isnan(x))
 #elif defined(FP_NAN)
-#define DBL_IS_NAN(x) (fpclassify(x) == FP_NAN)
+#define DBL_IS_NAN(x) (std::fpclassify(x) == FP_NAN)
 #else
 #define DBL_IS_NAN(x) ((x) != (x))
 #endif
