@@ -18,29 +18,29 @@
 #include "cdo_int.h"
 #include "grid.h"
 
-
-void fld_field_init(field_type *field, size_t nmiss, double missval, size_t ngp, double *array, double *w)
+void
+fld_field_init(Field *field, size_t nmiss, double missval, size_t ngp, double *array, double *w)
 {
   field_init(field);
 
-  field->size    = ngp;
-  field->nmiss   = nmiss;
+  field->size = ngp;
+  field->nmiss = nmiss;
   field->missval = missval;
-  field->ptr     = array;
-  field->weight  = w;
+  field->ptr = array;
+  field->weight = w;
 }
 
-
-double *fld_weights(int gridID, size_t ngp)
+double *
+fld_weights(int gridID, size_t ngp)
 {
   static bool lwarn = true;
-  double *weights = (double*) Malloc(ngp*sizeof(double));
-  for ( size_t i = 0; i < ngp; ++i ) weights[i] = 1;
+  double *weights = (double *) Malloc(ngp * sizeof(double));
+  for (size_t i = 0; i < ngp; ++i) weights[i] = 1;
 
-  if ( ngp > 1 )
+  if (ngp > 1)
     {
       int wstatus = gridWeights(gridID, weights);
-      if ( wstatus != 0 && lwarn )
+      if (wstatus != 0 && lwarn)
         {
           lwarn = false;
           cdoWarning("Grid cell bounds not available, using constant grid cell area weights!");
@@ -50,27 +50,23 @@ double *fld_weights(int gridID, size_t ngp)
   return weights;
 }
 
+int getLayerThickness(bool useweights, bool genbounds, int index, int zaxisID, int nlev, double *thickness, double *weights);
 
-int getLayerThickness(bool genbounds, int index, int zaxisID, int nlev, double *thickness, double *weights);
-
-double *vert_weights(int zaxisID, size_t nlev)
+void
+vert_weights(int zaxisID, size_t nlev, std::vector<double> &weights)
 {
   static bool lwarn = true;
-  double *weights = (double*) Malloc(nlev*sizeof(double));
-  double *thickness = (double*) Malloc(nlev*sizeof(double));
-  for ( size_t i = 0; i < nlev; ++i ) weights[i] = 1;
+  weights.resize(nlev);
+  std::vector<double> thickness(nlev);
+  for (size_t i = 0; i < nlev; ++i) weights[i] = 1;
 
-  if ( nlev > 1 )
+  if (nlev > 1)
     {
-      int wstatus = getLayerThickness(0, 0, zaxisID, nlev, thickness, weights);
-      if ( wstatus != 0 && lwarn && nlev > 1 )
+      int wstatus = getLayerThickness(1, 0, 0, zaxisID, nlev, thickness.data(), weights.data());
+      if (wstatus != 0 && lwarn && nlev > 1)
         {
           lwarn = false;
           cdoWarning("Layer bounds not available, using constant vertical weights!");
         }
     }
-
-  Free(thickness);
-  
-  return weights;
 }
