@@ -19,7 +19,7 @@
 #include <cdi.h>
 
 void
-farcfun(field_type *field, double rconst, int function)
+farcfun(Field *field, double rconst, int function)
 {
   switch (function)
     {
@@ -33,9 +33,8 @@ farcfun(field_type *field, double rconst, int function)
 }
 
 void
-farcmul(field_type *field, double rconst)
+farcmul(Field *field, double rconst)
 {
-  int i, len;
   int nwpv = field->nwpv;
   int grid = field->grid;
   size_t nmiss = field->nmiss;
@@ -45,11 +44,11 @@ farcmul(field_type *field, double rconst)
 
   if (nwpv != 2) nwpv = 1;
 
-  len = nwpv * gridInqSize(grid);
+  size_t len = nwpv * gridInqSize(grid);
 
   if (nmiss > 0)
     {
-      for (i = 0; i < len; i++) array[i] = MULMN(array[i], rconst);
+      for (size_t i = 0; i < len; i++) array[i] = MULMN(array[i], rconst);
     }
   else
     {
@@ -58,64 +57,68 @@ farcmul(field_type *field, double rconst)
 #pragma omp parallel for default(shared) private(i)
 #endif
       */
-      for (i = 0; i < len; i++) array[i] *= rconst;
+      for (size_t i = 0; i < len; i++) array[i] *= rconst;
     }
 }
 
 void
-farcdiv(field_type *field, double rconst)
+farcdiv(Field *field, double rconst)
 {
-  int i, len;
+  int nwpv = field->nwpv;
   int grid = field->grid;
   size_t nmiss = field->nmiss;
   double missval1 = field->missval;
   double missval2 = field->missval;
   double *array = field->ptr;
 
-  len = gridInqSize(grid);
+  if (nwpv != 2) nwpv = 1;
+
+  size_t len = nwpv * gridInqSize(grid);
 
   if (nmiss > 0 || IS_EQUAL(rconst, 0))
     {
-      for (i = 0; i < len; i++) array[i] = DIVMN(array[i], rconst);
+      for (size_t i = 0; i < len; i++) array[i] = DIVMN(array[i], rconst);
 
       if (IS_EQUAL(rconst, 0)) field->nmiss = len;
     }
   else
     {
-      for (i = 0; i < len; i++) array[i] /= rconst;
+      for (size_t i = 0; i < len; i++) array[i] /= rconst;
     }
 }
 
 void
-farcadd(field_type *field, double rconst)
+farcadd(Field *field, double rconst)
 {
-  int i, len;
+  int nwpv = field->nwpv;
   int grid = field->grid;
   size_t nmiss = field->nmiss;
   double missval1 = field->missval;
   double missval2 = field->missval;
   double *array = field->ptr;
 
-  len = gridInqSize(grid);
+  if (nwpv != 2) nwpv = 1;
+
+  size_t len = nwpv * gridInqSize(grid);
 
   if (nmiss > 0)
     {
-      for (i = 0; i < len; i++) array[i] = ADDMN(array[i], rconst);
+      for (size_t i = 0; i < len; i++) array[i] = ADDMN(array[i], rconst);
     }
   else
     {
-      for (i = 0; i < len; i++) array[i] += rconst;
+      for (size_t i = 0; i < len; i++) array[i] += rconst;
     }
 }
 
 void
-farcsub(field_type *field, double rconst)
+farcsub(Field *field, double rconst)
 {
   farcadd(field, -rconst);
 }
 
 void
-farinv(field_type *field)
+farinv(Field *field)
 {
   int grid = field->grid;
   double missval1 = field->missval;
@@ -130,7 +133,7 @@ farinv(field_type *field)
 }
 
 void
-farround(field_type *field)
+farround(Field *field)
 {
   int grid = field->grid;
   double missval1 = field->missval;
@@ -143,7 +146,7 @@ farround(field_type *field)
 }
 
 void
-farmod(field_type *field, double divisor)
+farmod(Field *field, double divisor)
 {
   int grid = field->grid;
   double missval1 = field->missval;
