@@ -19,10 +19,10 @@
 
 #include <stdio.h>
 
-void intgridbil(field_type *field1, field_type *field2);
-void intgridcon(field_type *field1, field_type *field2);
-void interpolate(field_type *field1, field_type *field2);
+void intgridbil(Field *field1, Field *field2);
+void intgridcon(Field *field1, Field *field2);
+void interpolate(Field *field1, Field *field2);
 
-void intgriddis(field_type *field1, field_type *field2, size_t nnn);
+void intgriddis(Field *field1, Field *field2, size_t nnn);
 
 #endif
