@@ -15,7 +15,7 @@
   GNU General Public License for more details.
 */
 
-#ifdef  HAVE_CONFIG_H
+#ifdef HAVE_CONFIG_H
 #include "config.h"
 #include "cdoDebugOutput.h"
 #endif
@@ -24,32 +24,45 @@
 #include <string.h>
 #include <time.h>  // time()
 #include <cdi.h>
-#include "cdo.h"
+
 #include "cdo_int.h"
 #include "error.h"
 #include "dmemory.h"
 #include "pipe.h"
 
-#ifdef  HAVE_LIBPTHREAD
-
+#ifdef HAVE_LIBPTHREAD
 
 pipe_t::pipe_t() { pipe_init(); }
 
+void
+pipe_t::close()
+{
+  pthread_mutex_lock(m_mutex);
+  EOP = true;
+  if (CdoDebug::PSTREAM)
+    {
+      MESSAGE(name, " write closed");
+    }
+  pthread_mutex_unlock(m_mutex);
+  pthread_cond_signal(tsDef);
+  pthread_cond_signal(tsInq);
+}
+
 void
 pipe_t::pipe_init()
 {
-/*  pthread_mutexattr_t m_attr;
-  pthread_condattr_t c_attr;
+  /*  pthread_mutexattr_t m_attr;
+    pthread_condattr_t c_attr;
 
-  pthread_mutexattr_init(&m_attr);
-  pthread_condattr_init(&c_attr);
-  */
+    pthread_mutexattr_init(&m_attr);
+    pthread_condattr_init(&c_attr);
+    */
   /*
 #if defined(_POSIX_THREAD_PROCESS_SHARED)
   if ( CdoDebug::PIPE )
     {
-      Message("setpshared mutexattr to PTHREAD_PROCESS_SHARED");
-      Message("setpshared condattr to PTHREAD_PROCESS_SHARED");
+      MESSAGE("setpshared mutexattr to PTHREAD_PROCESS_SHARED");
+      MESSAGE("setpshared condattr to PTHREAD_PROCESS_SHARED");
     }
 
   pthread_mutexattr_setpshared(&m_attr, PTHREAD_PROCESS_SHARED);
@@ -60,19 +73,19 @@ pipe_t::pipe_init()
       int pshared;
       pthread_mutexattr_getpshared(&m_attr, &pshared);
       if ( pshared == PTHREAD_PROCESS_SHARED )
-        Message("getpshared mutexattr is PTHREAD_PROCESS_SHARED");
+        MESSAGE("getpshared mutexattr is PTHREAD_PROCESS_SHARED");
       else if ( pshared == PTHREAD_PROCESS_PRIVATE )
-        Message("getpshared mutexattr is PTHREAD_PROCESS_PRIVATE");
+        MESSAGE("getpshared mutexattr is PTHREAD_PROCESS_PRIVATE");
 
       pthread_condattr_getpshared(&c_attr, &pshared);
       if ( pshared == PTHREAD_PROCESS_SHARED )
-        Message("getpshared condattr is PTHREAD_PROCESS_SHARED");
+        MESSAGE("getpshared condattr is PTHREAD_PROCESS_SHARED");
       else if ( pshared == PTHREAD_PROCESS_PRIVATE )
-        Message("getpshared condattr is PTHREAD_PROCESS_PRIVATE");
+        MESSAGE("getpshared condattr is PTHREAD_PROCESS_PRIVATE");
     }
 #else
   if ( CdoDebug::PIPE )
-    Message("_POSIX_THREAD_PROCESS_SHARED undefined");
+    MeSSAGE("_POSIX_THREAD_PROCESS_SHARED undefined");
 #endif
   */
   EOP = false;
@@ -88,34 +101,34 @@ pipe_t::pipe_init()
   hasdata = false;
   usedata = true;
   // pstreamptr_in = 0;
-/*
-  mutex = (pthread_mutex_t *) Malloc(sizeof(pthread_mutex_t));
-  pthread_mutex_init(mutex, &m_attr);
+  /*
+    mutex = (pthread_mutex_t *) Malloc(sizeof(pthread_mutex_t));
+    pthread_mutex_init(mutex, &m_attr);
 
-  tsDef = (pthread_cond_t *) Malloc(sizeof(pthread_cond_t));
-  pthread_cond_init(tsDef, &c_attr);
-  tsInq = (pthread_cond_t *) Malloc(sizeof(pthread_cond_t));
-  pthread_cond_init(tsInq, &c_attr);
+    tsDef = (pthread_cond_t *) Malloc(sizeof(pthread_cond_t));
+    pthread_cond_init(tsDef, &c_attr);
+    tsInq = (pthread_cond_t *) Malloc(sizeof(pthread_cond_t));
+    pthread_cond_init(tsInq, &c_attr);
 
-  recDef = (pthread_cond_t *) Malloc(sizeof(pthread_cond_t));
-  pthread_cond_init(recDef, &c_attr);
-  recInq = (pthread_cond_t *) Malloc(sizeof(pthread_cond_t));
-  pthread_cond_init(recInq, &c_attr);
+    recDef = (pthread_cond_t *) Malloc(sizeof(pthread_cond_t));
+    pthread_cond_init(recDef, &c_attr);
+    recInq = (pthread_cond_t *) Malloc(sizeof(pthread_cond_t));
+    pthread_cond_init(recInq, &c_attr);
 
-  vlistDef = (pthread_cond_t *) Malloc(sizeof(pthread_cond_t));
-  pthread_cond_init(vlistDef, &c_attr);
-  isclosed = (pthread_cond_t *) Malloc(sizeof(pthread_cond_t));
-  pthread_cond_init(isclosed, &c_attr);
+    vlistDef = (pthread_cond_t *) Malloc(sizeof(pthread_cond_t));
+    pthread_cond_init(vlistDef, &c_attr);
+    isclosed = (pthread_cond_t *) Malloc(sizeof(pthread_cond_t));
+    pthread_cond_init(isclosed, &c_attr);
 
-  writeCond = (pthread_cond_t *) Malloc(sizeof(pthread_cond_t));
-  pthread_cond_init(writeCond, &c_attr);
+    writeCond = (pthread_cond_t *) Malloc(sizeof(pthread_cond_t));
+    pthread_cond_init(writeCond, &c_attr);
 
-  readCond = (pthread_cond_t *) Malloc(sizeof(pthread_cond_t));
-  pthread_cond_init(readCond, &c_attr);
+    readCond = (pthread_cond_t *) Malloc(sizeof(pthread_cond_t));
+    pthread_cond_init(readCond, &c_attr);
 
-  pthread_mutexattr_destroy(&m_attr);
-  pthread_condattr_destroy(&c_attr);
-  */
+    pthread_mutexattr_destroy(&m_attr);
+    pthread_condattr_destroy(&c_attr);
+    */
 }
 int
 pipe_t::pipeInqTimestep(int p_tsID)
@@ -135,25 +148,22 @@ pipe_t::pipeInqTimestep(int p_tsID)
     {
       if (EOP)
         {
-          if (CdoDebug::PIPE)
-            Message("%s EOP", name.c_str());
+          if (CdoDebug::PIPE) MESSAGE(name.c_str(), " EOP");
           break;
         }
       if (hasdata)
         {
-          if (CdoDebug::PIPE)
-            Message("%s has data", name.c_str());
+          if (CdoDebug::PIPE) MESSAGE(name.c_str(), " has data");
           hasdata = false;
           data = NULL;
           readCond.notify_all();
         }
       else if (CdoDebug::PIPE)
-        Message("%s has no data", name.c_str());
+        MESSAGE(name.c_str(), " has no data");
 
       recInq.notify_all(); /* o.k. ??? */
 
-      if (CdoDebug::PIPE)
-        Message("%s wait of tsDef", name.c_str());
+      if (CdoDebug::PIPE) MESSAGE(name.c_str(), " wait of tsDef");
       tsDef.wait(locked_mutex);
     }
 
@@ -201,13 +211,12 @@ pipe_t::pipeInqVlist(int &p_vlistID)
     {
       time_to_wait += TIMEOUT;
       // fprintf(stderr, "tvsec %g\n", (double) time_to_wait.tv_sec);
-      if (CdoDebug::PIPE)
-        Message("%s wait of vlistDef", name.c_str());
+      if (CdoDebug::PIPE) MESSAGE(name.c_str(), " wait of vlistDef");
       // pthread_cond_wait(pipe->vlistDef, pipe->mutex);
       retcode = vlistDef.wait_for(locked_mutex, time_to_wait);
-      // fprintf(stderr, "self %d retcode %d %d %d\n", pstreamptr->self, retcode, processNumsActive(),
-      // vlistID);
-      //if (retcode != 0 && nwaitcycles++ < MAX_WAIT_CYCLES)
+      // fprintf(stderr, "self %d retcode %d %d %d\n", pstreamptr->self,
+      // retcode, processNumsActive(), vlistID);
+      // if (retcode != 0 && nwaitcycles++ < MAX_WAIT_CYCLES)
       if (retcode != std::cv_status::timeout && nwaitcycles++ < MAX_WAIT_CYCLES)
         {
           if (processNumsActive() > 1 || (processNumsActive() == 1 && nwaitcycles < MIN_WAIT_CYCLES))
@@ -218,7 +227,7 @@ pipe_t::pipeInqVlist(int &p_vlistID)
   if (retcode == std::cv_status::timeout)
     vlistID = p_vlistID;
   else if (CdoDebug::PIPE)
-    Message("%s timeout!", name.c_str());
+    MESSAGE(name.c_str(), " timeout!");
 
   // UNLOCK
 
@@ -234,8 +243,7 @@ pipe_t::pipeDefTimestep(int p_vlistID, int p_tsID)
   m_mutex.lock();
   recIDw = -1;
   tsIDw++;
-  if (p_tsID != tsIDw)
-    Error("unexpected p_tsID %d(%d) for %s", p_tsID, tsIDw, name.c_str());
+  if (p_tsID != tsIDw) Error("unexpected p_tsID %d(%d) for %s", p_tsID, tsIDw, name.c_str());
 
   if (p_tsID == 0)
     numrecs = vlistNrecs(p_vlistID);
@@ -250,15 +258,12 @@ pipe_t::pipeDefTimestep(int p_vlistID, int p_tsID)
               numrecs += zaxisInqSize(vlistInqVarZaxis(vlistID, varID));
             }
         }
-      if (CdoDebug::PIPE)
-        Message("%s numrecs = %d nvars = %d", name.c_str(), numrecs, vlistNvars(vlistID));
+      if (CdoDebug::PIPE) MESSAGE(name.c_str(), "numrecs = ", numrecs, "nvars = ", vlistNvars(vlistID));
     }
 
   nrecs = numrecs;
-  if (CdoDebug::PIPE)
-    Message("%s numrecs %d p_tsID %d %d %d", name.c_str(), numrecs, p_tsID, tsIDw, tsIDr);
-  if (numrecs == 0)
-    EOP = true;
+  if (CdoDebug::PIPE) MESSAGE(name.c_str(), " numrecs ", numrecs, " p_tsID ", p_tsID, " ", tsIDw, " ", tsIDr);
+  if (numrecs == 0) EOP = true;
   m_mutex.unlock();
   // UNLOCK
 
@@ -271,12 +276,10 @@ pipe_t::pipeDefTimestep(int p_vlistID, int p_tsID)
     {
       if (EOP)
         {
-          if (CdoDebug::PIPE)
-            Message("EOP");
+          if (CdoDebug::PIPE) MESSAGE("EOP");
           break;
         }
-      if (CdoDebug::PIPE)
-        Message("%s wait of tsInq (p_tsID %d %d)", name.c_str(), p_tsID, tsIDr);
+      if (CdoDebug::PIPE) MESSAGE(name.c_str(), " wait of tsInq (p_tsID ", p_tsID, " ", tsIDr, ")");
       tsInq.wait(locked_mutex);
     }
   // UNLOCK
@@ -291,8 +294,7 @@ pipe_t::pipeInqRecord(int *p_varID, int *p_levelID)
 
   // LOCK
   m_mutex.lock();
-  if (CdoDebug::PIPE)
-    Message("%s has no data %d %d", name.c_str(), recIDr, recIDw);
+  if (CdoDebug::PIPE) MESSAGE(name.c_str(), " has no data ", recIDr, " ", recIDw);
   if (hasdata || usedata)
     {
       hasdata = false;
@@ -303,27 +305,23 @@ pipe_t::pipeInqRecord(int *p_varID, int *p_levelID)
   m_mutex.unlock();
   // UNLOCK
 
-  if (condSignal)
-    readCond.notify_all();
+  if (condSignal) readCond.notify_all();
 
   // LOCK
   std::unique_lock<std::mutex> locked_mutex(m_mutex);
   usedata = true;
   recIDr++;
 
-  if (CdoDebug::PIPE)
-    Message("%s recID %d %d", name.c_str(), recIDr, recIDw);
+  if (CdoDebug::PIPE) MESSAGE(name.c_str(), "recID", recIDr, " ", recIDw);
 
   while (recIDw != recIDr)
     {
       if (EOP)
         {
-          if (CdoDebug::PIPE)
-            Message("EOP");
+          if (CdoDebug::PIPE) MESSAGE("EOP");
           break;
         }
-      if (CdoDebug::PIPE)
-        Message("%s wait of recDef", name.c_str());
+      if (CdoDebug::PIPE) MESSAGE(name.c_str(), "wait for recDef");
       recDef.wait(locked_mutex);
     }
 
@@ -353,8 +351,7 @@ pipe_t::pipeDefRecord(int p_varID, int p_levelID)
 
   // LOCK
   m_mutex.lock();
-  if (CdoDebug::PIPE)
-    Message("%s has data %d %d", name.c_str(), recIDr, recIDw);
+  if (CdoDebug::PIPE) MESSAGE(name.c_str(), " has data ", recIDr, " ", recIDw);  //<- TODO: rethink positioning
   if (hasdata)
     {
       hasdata = false;
@@ -364,8 +361,7 @@ pipe_t::pipeDefRecord(int p_varID, int p_levelID)
   m_mutex.unlock();
   // UNLOCK
 
-  if (condSignal)
-    readCond.notify_all();
+  if (condSignal) readCond.notify_all();
 
   // LOCK
   m_mutex.lock();
@@ -373,8 +369,7 @@ pipe_t::pipeDefRecord(int p_varID, int p_levelID)
   recIDw++;
   varID = p_varID;
   levelID = p_levelID;
-  if (CdoDebug::PIPE)
-    Message("%s recID %d %d", name.c_str(), recIDr, recIDw);
+  if (CdoDebug::PIPE) MESSAGE(name.c_str(), "recID", recIDr, " ", recIDw);
   m_mutex.unlock();
   // UNLOCK
 
@@ -384,12 +379,9 @@ pipe_t::pipeDefRecord(int p_varID, int p_levelID)
   std::unique_lock<std::mutex> locked_mutex(m_mutex);
   while (recIDr < recIDw)
     {
-      if (tsIDw != tsIDr)
-        break;
-      if (EOP)
-        break;
-      if (CdoDebug::PIPE)
-        Message("%s wait of recInq %d", name.c_str(), recIDr);
+      if (tsIDw != tsIDr) break;
+      if (EOP) break;
+      if (CdoDebug::PIPE) MESSAGE(name.c_str(), "wait of recInq ", recIDr);
       recInq.wait(locked_mutex);
     }
   // UNLOCK
@@ -404,20 +396,18 @@ pipe_t::pipeDefRecord(int p_varID, int p_levelID)
 void
 pipe_t::pipeReadPipeRecord(double *p_data, int vlistID, size_t *p_nmiss)
 {
-  if (!p_data)
-    Error("No data pointer for %s", name.c_str());
+  if (!p_data) Error("No data pointer for %s", name.c_str());
 
   size_t datasize = gridInqSize(vlistInqVarGrid(vlistID, varID));
   nvals += datasize;
-  if (vlistNumber(vlistID) != CDI_REAL)
-    datasize *= 2;
+  if (vlistNumber(vlistID) != CDI_REAL) datasize *= 2;
   memcpy(p_data, data, datasize * sizeof(double));
   *p_nmiss = nmiss;
 }
 
 /*
 void
-pipeGetReadTarget(pstream_t *pstreamptr, pstream_t *pstreamptr_in)
+pipeGetReadTarget(PstreamType *pstreamptr, PstreamType *pstreamptr_in)
 {
 
   pstreamptr_in = pstreamptr->pipe->pstreamptr_in;
@@ -425,11 +415,9 @@ pipeGetReadTarget(pstream_t *pstreamptr, pstream_t *pstreamptr_in)
   while (pstreamptr_in->ispipe)
     {
       if (CdoDebug::PIPE)
-        fprintf(stderr, "%s: istream %d is pipe\n", __func__, pstreamptr_in->self);
-      pstreamptr = pstreamptr_in;
-      pstreamptr_in = pstreamptr_in->pipe->pstreamptr_in;
-      if (pstreamptr_in == 0)
-        break;
+        fprintf(stderr, "%s: istream %d is pipe\n", __func__,
+pstreamptr_in->self); pstreamptr = pstreamptr_in; pstreamptr_in =
+pstreamptr_in->pipe->pstreamptr_in; if (pstreamptr_in == 0) break;
     }
 
   if (pstreamptr->pipe->hasdata == false)
@@ -451,8 +439,7 @@ pipe_t::pipeReadRecord(int p_vlistID, double *data, size_t *nmiss)
   std::unique_lock<std::mutex> locked_mutex(m_mutex);
   while (!hasdata)
     {
-      if (CdoDebug::PIPE)
-        Message("%s wait of writeCond", name.c_str());
+      if (CdoDebug::PIPE) MESSAGE(name.c_str(), " wait of writeCond");
       writeCond.wait(locked_mutex);
     }
 
@@ -465,8 +452,7 @@ pipe_t::pipeReadRecord(int p_vlistID, double *data, size_t *nmiss)
       Error("data type %d not implemented", hasdata);
     }
 
-  if (CdoDebug::PIPE)
-    Message("%s read record %d", name.c_str(), recIDr);
+  if (CdoDebug::PIPE) MESSAGE(name.c_str(), " read record ", recIDr);
 
   hasdata = false;
   data = NULL;
@@ -492,32 +478,32 @@ pipe_t::pipeWriteRecord(double *p_data, size_t p_nmiss)
 
   writeCond.notify_all();
 
-  if (CdoDebug::PIPE)
-    Message("%s write record %d", name.c_str(), recIDw);
+  if (CdoDebug::PIPE) MESSAGE(name.c_str(), " write record ", recIDw);
 
   // LOCK
   std::unique_lock<std::mutex> locked_mutex(m_mutex);
   while (hasdata)
     {
-      if (!usedata)
-        break;
+      if (!usedata) break;
       /*
       printf("ts ids %d %d\n", tsIDw, tsIDr);
       printf("rec ids %d %d\n", recIDw, recIDr);
       */
-      if (recIDw != recIDr)
-        break;
+      if (recIDw != recIDr) break;
 
       if (EOP)
         {
-          if (CdoDebug::PIPE)
-            Message("EOP");
+          if (CdoDebug::PIPE) MESSAGE("EOP");
           break;
         }
-      if (CdoDebug::PIPE)
-        Message("%s wait of readCond", name.c_str());
+      if (CdoDebug::PIPE) MESSAGE(name.c_str(), " wait of readCond");
       readCond.wait(locked_mutex);
     }
   // UNLOCK
 }
+void
+pipe_t::pipeSetName(int processID, int inputIDX)
+{
+  name = "(pipe" + std::to_string(processID + 1) + "." + std::to_string(inputIDX + 1) + ")";
+}
 #endif
