@@ -1,29 +1,33 @@
 // This file is used in CDI and CDO !!!
 
-#if defined (HAVE_CONFIG_H)
+#ifdef HAVE_CONFIG_H
 #include "../src/config.h"
 #endif
 
 #include <stdio.h>
 
 #ifdef CDO
-#define  streamInqFiletype        pstreamInqFiletype
-#define  streamInqByteorder       pstreamInqByteorder
-#define  streamInqTimestep        pstreamInqTimestep
+#include "text.h"
+#include "datetime.h"
+#define streamInqFiletype pstreamInqFiletype
+#define streamInqByteorder pstreamInqByteorder
+#define streamInqTimestep cdoStreamInqTimestep
 #endif
 
 #define DATE_FORMAT "%5.4d-%2.2d-%2.2d"
 #define TIME_FORMAT "%2.2d:%2.2d:%2.2d"
 
-void my_reset_text_color(FILE *fp)
+void
+my_reset_text_color(FILE *fp)
 {
-  (void)fp;
+  (void) fp;
 #ifdef CDO
   reset_text_color(fp);
 #endif
 }
 
-void datetime2str(int date, int time, char *datetimestr, int maxlen)
+void
+datetime2str(int64_t date, int time, char *datetimestr, int maxlen)
 {
   int year, month, day;
   cdiDecodeDate(date, &year, &month, &day);
@@ -31,44 +35,41 @@ void datetime2str(int date, int time, char *datetimestr, int maxlen)
   cdiDecodeTime(time, &hour, &minute, &second);
 
   int len = sprintf(datetimestr, DATE_FORMAT "T" TIME_FORMAT, year, month, day, hour, minute, second);
-  if ( len > ( maxlen-1) )
-    fprintf(stderr, "Internal problem (%s): sizeof input string is too small!\n", __func__);
+  if (len > (maxlen - 1)) fprintf(stderr, "Internal problem (%s): sizeof input string is too small!\n", __func__);
 }
 
-
-void date2str(int date, char *datestr, int maxlen)
+void
+date2str(int64_t date, char *datestr, int maxlen)
 {
   int year, month, day;
   cdiDecodeDate(date, &year, &month, &day);
 
   int len = sprintf(datestr, DATE_FORMAT, year, month, day);
-  if ( len > ( maxlen-1) )
-    fprintf(stderr, "Internal problem (%s): sizeof input string is too small!\n", __func__);
+  if (len > (maxlen - 1)) fprintf(stderr, "Internal problem (%s): sizeof input string is too small!\n", __func__);
 }
 
-
-void time2str(int time, char *timestr, int maxlen)
+void
+time2str(int time, char *timestr, int maxlen)
 {
   int hour, minute, second;
   cdiDecodeTime(time, &hour, &minute, &second);
 
   int len = sprintf(timestr, TIME_FORMAT, hour, minute, second);
-  if ( len > ( maxlen-1) )
-    fprintf(stderr, "Internal problem (%s): sizeof input string is too small!\n", __func__);
+  if (len > (maxlen - 1)) fprintf(stderr, "Internal problem (%s): sizeof input string is too small!\n", __func__);
 }
 
-
-const char *comp_name(int comptype)
+const char *
+comp_name(int comptype)
 {
-  if ( comptype == CDI_COMPRESS_SZIP  ) return "szip";
-  if ( comptype == CDI_COMPRESS_ZIP   ) return "zip";
-  if ( comptype == CDI_COMPRESS_JPEG  ) return "jpeg";
-  if ( comptype == CDI_COMPRESS_AEC   ) return "aec";
+  if (comptype == CDI_COMPRESS_SZIP) return "szip";
+  if (comptype == CDI_COMPRESS_ZIP) return "zip";
+  if (comptype == CDI_COMPRESS_JPEG) return "jpeg";
+  if (comptype == CDI_COMPRESS_AEC) return "aec";
   return " ";
 }
 
-
-void printFiletype(int streamID, int vlistID)
+void
+printFiletype(int streamID, int vlistID)
 {
   int filetype = streamInqFiletype(streamID);
 
@@ -99,18 +100,19 @@ void printFiletype(int streamID, int vlistID)
     }
   // clang-format on
 
-
   int nvars = vlistNvars(vlistID);
-  int comps[] = {CDI_COMPRESS_ZIP, CDI_COMPRESS_JPEG, CDI_COMPRESS_SZIP, CDI_COMPRESS_AEC};
+  int comps[] = { CDI_COMPRESS_ZIP, CDI_COMPRESS_JPEG, CDI_COMPRESS_SZIP, CDI_COMPRESS_AEC };
   unsigned kk = 0;
-  for ( unsigned k = 0; k < sizeof(comps)/sizeof(int); ++k )
-    for ( int varID = 0; varID < nvars; varID++ )
+  for (unsigned k = 0; k < sizeof(comps) / sizeof(int); ++k)
+    for (int varID = 0; varID < nvars; varID++)
       {
         int comptype = vlistInqVarCompType(vlistID, varID);
-        if ( comptype == comps[k] )
+        if (comptype == comps[k])
           {
-            if ( kk++ == 0 ) printf(" ");
-            else printf("/");
+            if (kk++ == 0)
+              printf(" ");
+            else
+              printf("/");
             printf("%s", comp_name(comptype));
             break;
           }
@@ -119,51 +121,50 @@ void printFiletype(int streamID, int vlistID)
   printf("\n");
 }
 
-static
-void print_xvals(int gridID, int dig)
+static void
+print_xvals(int gridID, int dig)
 {
   size_t xsize = gridInqXsize(gridID);
-  if ( xsize > 0 && gridInqXvals(gridID, NULL) )
+  if (xsize > 0 && gridInqXvals(gridID, NULL))
     {
       char xname[CDI_MAX_NAME], xunits[CDI_MAX_NAME];
       gridInqXname(gridID, xname);
       gridInqXunits(gridID, xunits);
 
       double xfirst = gridInqXval(gridID, 0);
-      double xlast  = gridInqXval(gridID, xsize-1);
-      double xinc   = gridInqXinc(gridID);
+      double xlast = gridInqXval(gridID, xsize - 1);
+      double xinc = gridInqXinc(gridID);
       fprintf(stdout, "%33s : %.*g", xname, dig, xfirst);
-      if ( xsize > 1 )
+      if (xsize > 1)
         {
           fprintf(stdout, " to %.*g", dig, xlast);
-          if ( IS_NOT_EQUAL(xinc, 0) )
-            fprintf(stdout, " by %.*g", dig, xinc);
+          if (IS_NOT_EQUAL(xinc, 0)) fprintf(stdout, " by %.*g", dig, xinc);
         }
       fprintf(stdout, " %s", xunits);
-      if ( gridIsCircular(gridID) ) fprintf(stdout, "  circular");
+      if (gridIsCircular(gridID)) fprintf(stdout, "  circular");
       fprintf(stdout, "\n");
     }
 }
 
-static
-void print_yvals(int gridID, int dig)
+static void
+print_yvals(int gridID, int dig)
 {
   size_t ysize = gridInqYsize(gridID);
-  if ( ysize > 0 && gridInqYvals(gridID, NULL) )
+  if (ysize > 0 && gridInqYvals(gridID, NULL))
     {
       char yname[CDI_MAX_NAME], yunits[CDI_MAX_NAME];
       gridInqYname(gridID, yname);
       gridInqYunits(gridID, yunits);
 
       double yfirst = gridInqYval(gridID, 0);
-      double ylast  = gridInqYval(gridID, ysize-1);
-      double yinc   = gridInqYinc(gridID);
+      double ylast = gridInqYval(gridID, ysize - 1);
+      double yinc = gridInqYinc(gridID);
       fprintf(stdout, "%33s : %.*g", yname, dig, yfirst);
-      if ( ysize > 1 )
+      if (ysize > 1)
         {
           int gridtype = gridInqType(gridID);
           fprintf(stdout, " to %.*g", dig, ylast);
-          if ( IS_NOT_EQUAL(yinc, 0) && gridtype != GRID_GAUSSIAN && gridtype != GRID_GAUSSIAN_REDUCED )
+          if (IS_NOT_EQUAL(yinc, 0) && gridtype != GRID_GAUSSIAN && gridtype != GRID_GAUSSIAN_REDUCED)
             fprintf(stdout, " by %.*g", dig, yinc);
         }
       fprintf(stdout, " %s", yunits);
@@ -171,10 +172,10 @@ void print_yvals(int gridID, int dig)
     }
 }
 
-static
-void print_xyvals2D(int gridID, int dig)
+static void
+print_xyvals2D(int gridID, int dig)
 {
-  if ( gridInqXvals(gridID, NULL) && gridInqYvals(gridID, NULL) )
+  if (gridInqXvals(gridID, NULL) && gridInqYvals(gridID, NULL))
     {
       char xname[CDI_MAX_NAME], yname[CDI_MAX_NAME], xunits[CDI_MAX_NAME], yunits[CDI_MAX_NAME];
       gridInqXname(gridID, xname);
@@ -183,60 +184,88 @@ void print_xyvals2D(int gridID, int dig)
       gridInqYunits(gridID, yunits);
 
       size_t gridsize = gridInqSize(gridID);
-      double *xvals2D = (double*) malloc(gridsize*sizeof(double));
-      double *yvals2D = (double*) malloc(gridsize*sizeof(double));
+      double *xvals2D = (double *) malloc(gridsize * sizeof(double));
+      double *yvals2D = (double *) malloc(gridsize * sizeof(double));
 
       gridInqXvals(gridID, xvals2D);
       gridInqYvals(gridID, yvals2D);
 
       double xfirst = xvals2D[0];
-      double xlast  = xvals2D[0];
+      double xlast = xvals2D[0];
       double yfirst = yvals2D[0];
-      double ylast  = yvals2D[0];
-      for ( size_t i = 1; i < gridsize; i++ )
+      double ylast = yvals2D[0];
+      for (size_t i = 1; i < gridsize; i++)
         {
-          if ( xvals2D[i] < xfirst ) xfirst = xvals2D[i];
-          if ( xvals2D[i] > xlast  ) xlast  = xvals2D[i];
-          if ( yvals2D[i] < yfirst ) yfirst = yvals2D[i];
-          if ( yvals2D[i] > ylast  ) ylast  = yvals2D[i];
+          if (xvals2D[i] < xfirst) xfirst = xvals2D[i];
+          if (xvals2D[i] > xlast) xlast = xvals2D[i];
+          if (yvals2D[i] < yfirst) yfirst = yvals2D[i];
+          if (yvals2D[i] > ylast) ylast = yvals2D[i];
         }
 
       double xinc = 0;
       double yinc = 0;
       int gridtype = gridInqType(gridID);
-      if ( gridtype == GRID_CURVILINEAR )
+      if (gridtype == GRID_CURVILINEAR)
         {
           size_t xsize = gridInqXsize(gridID);
-          if ( xsize > 1 )
-            {
-              double *xvals = (double*) malloc((size_t)xsize*sizeof(double));
-              for ( size_t i = 0; i < xsize; ++i ) xvals[i] = xvals2D[i];
-              xinc = fabs(xvals[xsize-1] - xvals[0])/(xsize-1);
-              for ( size_t i = 2; i < xsize; i++ )
-                if ( fabs(fabs(xvals[i-1] - xvals[i]) - xinc) > 0.01*xinc ) { xinc = 0; break; }
-              free(xvals);
-            }
           size_t ysize = gridInqYsize(gridID);
-          if ( ysize > 1 )
+          if (xsize > 1)
             {
-              double *yvals = (double*) malloc((size_t)ysize*sizeof(double));
-              for ( size_t i = 0; i < ysize; ++i ) yvals[i] = yvals2D[i*xsize];
-              yinc = fabs(yvals[ysize-1] - yvals[0])/(ysize-1);
-              for ( size_t i = 2; i < ysize; i++ )
-                if ( fabs(fabs(yvals[i-1] - yvals[i]) - yinc) > 0.01*yinc ) { yinc = 0; break; }
+              double *xvals = (double *) malloc((size_t) xsize * sizeof(double));
+              for (size_t i = 0; i < xsize; ++i) xvals[i] = xvals2D[i];
+              xinc = fabs(xvals[xsize - 1] - xvals[0]) / (xsize - 1);
+              for (size_t i = 1; i < xsize; i++)
+                if (fabs(fabs(xvals[i - 1] - xvals[i]) - xinc) > 0.01 * xinc)
+                  {
+                    xinc = 0;
+                    break;
+                  }
+              free(xvals);
+              if (IS_NOT_EQUAL(xinc, 0))
+                {
+                  for (size_t i = 1; i < ysize; i++)
+                    if (IS_NOT_EQUAL(xvals2D[i * xsize], xvals2D[0])
+                        || IS_NOT_EQUAL(xvals2D[(i + 1) * xsize - 1], xvals2D[xsize - 1]))
+                      {
+                        xinc = 0;
+                        break;
+                      }
+                }
+            }
+          if (ysize > 1)
+            {
+              double *yvals = (double *) malloc((size_t) ysize * sizeof(double));
+              for (size_t i = 0; i < ysize; ++i) yvals[i] = yvals2D[i * xsize];
+              yinc = fabs(yvals[ysize - 1] - yvals[0]) / (ysize - 1);
+              for (size_t i = 1; i < ysize; i++)
+                if (fabs(fabs(yvals[i - 1] - yvals[i]) - yinc) > 0.01 * yinc)
+                  {
+                    yinc = 0;
+                    break;
+                  }
               free(yvals);
+              if (IS_NOT_EQUAL(yinc, 0))
+                {
+                  for (size_t i = 1; i < xsize; i++)
+                    if (IS_NOT_EQUAL(yvals2D[i], yvals2D[0])
+                        || IS_NOT_EQUAL(yvals2D[(ysize - 1) * xsize + i], yvals2D[(ysize - 1) * xsize]))
+                      {
+                        yinc = 0;
+                        break;
+                      }
+                }
             }
         }
 
       fprintf(stdout, "%33s : %.*g", xname, dig, xfirst);
-      if ( gridsize > 1 ) fprintf(stdout, " to %.*g", dig, xlast);
-      if ( IS_NOT_EQUAL(xinc, 0) ) fprintf(stdout, " by %.*g", dig, xinc);
+      if (gridsize > 1) fprintf(stdout, " to %.*g", dig, xlast);
+      if (IS_NOT_EQUAL(xinc, 0)) fprintf(stdout, " by %.*g", dig, xinc);
       fprintf(stdout, " %s", xunits);
-      if ( gridIsCircular(gridID) ) fprintf(stdout, "  circular");
+      if (gridIsCircular(gridID)) fprintf(stdout, "  circular");
       fprintf(stdout, "\n");
       fprintf(stdout, "%33s : %.*g", yname, dig, yfirst);
-      if ( gridsize > 1 ) fprintf(stdout, " to %.*g", dig, ylast);
-      if ( IS_NOT_EQUAL(yinc, 0) ) fprintf(stdout, " by %.*g", dig, yinc);
+      if (gridsize > 1) fprintf(stdout, " to %.*g", dig, ylast);
+      if (IS_NOT_EQUAL(yinc, 0)) fprintf(stdout, " by %.*g", dig, yinc);
       fprintf(stdout, " %s", yunits);
       fprintf(stdout, "\n");
 
@@ -245,19 +274,19 @@ void print_xyvals2D(int gridID, int dig)
     }
 }
 
-static
-void printGridInfoKernel(int gridID, int index, bool lproj)
+static void
+printGridInfoKernel(int gridID, int index, bool lproj)
 {
   int gridtype = gridInqType(gridID);
 
-  if ( lproj && gridtype != GRID_PROJECTION )
+  if (lproj && gridtype != GRID_PROJECTION)
     fprintf(stderr, "Internal problem (%s): sub grid not equal GRID_PROJECTION!\n", __func__);
 
-  int trunc    = gridInqTrunc(gridID);
+  int trunc = gridInqTrunc(gridID);
   size_t gridsize = gridInqSize(gridID);
-  size_t xsize    = gridInqXsize(gridID);
-  size_t ysize    = gridInqYsize(gridID);
-  size_t xysize   = xsize*ysize;
+  size_t xsize = gridInqXsize(gridID);
+  size_t ysize = gridInqYsize(gridID);
+  size_t xysize = xsize * ysize;
 
   // int prec     = gridInqDatatype(gridID);
   // int dig = (prec == CDI_DATATYPE_FLT64) ? 15 : 7;
@@ -267,9 +296,9 @@ void printGridInfoKernel(int gridID, int index, bool lproj)
   dig = CDO_flt_digits;
 #endif
 
-  if ( !lproj )
+  if (!lproj)
     {
-      fprintf(stdout, "  %4d : ", index+1);
+      fprintf(stdout, "  %4d : ", index + 1);
 #ifdef CDO
       set_text_color(stdout, RESET, BLUE);
 #endif
@@ -278,36 +307,32 @@ void printGridInfoKernel(int gridID, int index, bool lproj)
       fprintf(stdout, " : ");
     }
 
-  if ( gridtype == GRID_LONLAT     ||
-       gridtype == GRID_PROJECTION ||
-       gridtype == GRID_GENERIC    ||
-       gridtype == GRID_CHARXY    ||
-       gridtype == GRID_GAUSSIAN   ||
-       gridtype == GRID_GAUSSIAN_REDUCED )
+  if (gridtype == GRID_LONLAT || gridtype == GRID_PROJECTION || gridtype == GRID_GENERIC || gridtype == GRID_CHARXY
+      || gridtype == GRID_GAUSSIAN || gridtype == GRID_GAUSSIAN_REDUCED)
     {
-      if ( !lproj )
+      if (!lproj)
         {
 #ifdef CDO
           set_text_color(stdout, RESET, GREEN);
 #endif
           fprintf(stdout, "points=%zu", gridsize);
-          if ( gridtype == GRID_GAUSSIAN_REDUCED )
+          if (gridtype == GRID_GAUSSIAN_REDUCED)
             fprintf(stdout, "  nlat=%zu", ysize);
-          else if ( xysize )
+          else if (xysize)
             fprintf(stdout, " (%zux%zu)", xsize, ysize);
 
-          if ( gridtype == GRID_GAUSSIAN || gridtype == GRID_GAUSSIAN_REDUCED )
-            fprintf(stdout, "  np=%d", gridInqNP(gridID));
+          if (gridtype == GRID_GAUSSIAN || gridtype == GRID_GAUSSIAN_REDUCED) fprintf(stdout, "  np=%d", gridInqNP(gridID));
           my_reset_text_color(stdout);
 
           fprintf(stdout, "\n");
         }
 
-      char name[CDI_MAX_NAME]; name[0] = 0;
+      char name[CDI_MAX_NAME];
+      name[0] = 0;
       cdiGridInqKeyStr(gridID, CDI_KEY_MAPNAME, CDI_MAX_NAME, name);
-      if ( gridtype == GRID_PROJECTION || name[0] )
+      if (gridtype == GRID_PROJECTION || name[0])
         {
-          if ( name[0] == 0 ) strcpy(name, "undefined");
+          if (name[0] == 0) strcpy(name, "undefined");
 #ifdef CDO
           set_text_color(stdout, RESET, BLUE);
 #endif
@@ -324,34 +349,34 @@ void printGridInfoKernel(int gridID, int index, bool lproj)
       print_xvals(gridID, dig);
       print_yvals(gridID, dig);
 
-      if ( gridInqXbounds(gridID, NULL) || gridInqYbounds(gridID, NULL) )
+      if (gridInqXbounds(gridID, NULL) || gridInqYbounds(gridID, NULL))
         {
           fprintf(stdout, "%33s :", "available");
-          if ( gridInqXbounds(gridID, NULL) && gridInqYbounds(gridID, NULL) ) fprintf(stdout, " cellbounds");
-          if ( gridHasArea(gridID) )          fprintf(stdout, " area");
-          if ( gridInqMask(gridID, NULL) )    fprintf(stdout, " mask");
+          if (gridInqXbounds(gridID, NULL) && gridInqYbounds(gridID, NULL)) fprintf(stdout, " cellbounds");
+          if (gridHasArea(gridID)) fprintf(stdout, " area");
+          if (gridInqMask(gridID, NULL)) fprintf(stdout, " mask");
           fprintf(stdout, "\n");
         }
     }
-  else if ( gridtype == GRID_SPECTRAL )
+  else if (gridtype == GRID_SPECTRAL)
     {
 #ifdef CDO
       set_text_color(stdout, RESET, GREEN);
 #endif
-      fprintf(stdout, "points=%zu  nsp=%zu  truncation=%d", gridsize, gridsize/2, trunc);
-      if ( gridInqComplexPacking(gridID) ) fprintf(stdout, "  complexPacking");
+      fprintf(stdout, "points=%zu  nsp=%zu  truncation=%d", gridsize, gridsize / 2, trunc);
+      if (gridInqComplexPacking(gridID)) fprintf(stdout, "  complexPacking");
       my_reset_text_color(stdout);
       fprintf(stdout, "\n");
     }
-  else if ( gridtype == GRID_FOURIER )
+  else if (gridtype == GRID_FOURIER)
     {
 #ifdef CDO
       set_text_color(stdout, RESET, GREEN);
 #endif
-      fprintf(stdout, "points=%zu  nfc=%zu  truncation=%d\n", gridsize, gridsize/2, trunc);
+      fprintf(stdout, "points=%zu  nfc=%zu  truncation=%d\n", gridsize, gridsize / 2, trunc);
       my_reset_text_color(stdout);
     }
-  else if ( gridtype == GRID_GME )
+  else if (gridtype == GRID_GME)
     {
       int nd, ni, ni2, ni3;
       gridInqParamGME(gridID, &nd, &ni, &ni2, &ni3);
@@ -361,30 +386,28 @@ void printGridInfoKernel(int gridID, int index, bool lproj)
       fprintf(stdout, "points=%zu  nd=%d  ni=%d\n", gridsize, nd, ni);
       my_reset_text_color(stdout);
     }
-  else if ( gridtype == GRID_CURVILINEAR || gridtype == GRID_UNSTRUCTURED )
+  else if (gridtype == GRID_CURVILINEAR || gridtype == GRID_UNSTRUCTURED)
     {
 #ifdef CDO
       set_text_color(stdout, RESET, GREEN);
 #endif
-      if ( gridtype == GRID_CURVILINEAR )
+      if (gridtype == GRID_CURVILINEAR)
         fprintf(stdout, "points=%zu (%zux%zu)", gridsize, xsize, ysize);
       else
         fprintf(stdout, "points=%zu", gridsize);
 
-      if ( gridtype == GRID_UNSTRUCTURED && gridInqNvertex(gridID) > 0 )
-        fprintf(stdout, "  nvertex=%d", gridInqNvertex(gridID));
+      if (gridtype == GRID_UNSTRUCTURED && gridInqNvertex(gridID) > 0) fprintf(stdout, "  nvertex=%d", gridInqNvertex(gridID));
       my_reset_text_color(stdout);
 
       fprintf(stdout, "\n");
 
-      if ( gridtype == GRID_UNSTRUCTURED )
+      if (gridtype == GRID_UNSTRUCTURED)
         {
-          int number   = gridInqNumber(gridID);
+          int number = gridInqNumber(gridID);
           int position = gridInqPosition(gridID);
-          if ( number > 0 )
-            fprintf(stdout, "%33s : number=%d  position=%d\n", "grid", number, position);
+          if (number > 0) fprintf(stdout, "%33s : number=%d  position=%d\n", "grid", number, position);
 
-          if ( gridInqReference(gridID, NULL) )
+          if (gridInqReference(gridID, NULL))
             {
               char reference_link[8192];
               gridInqReference(gridID, reference_link);
@@ -399,65 +422,63 @@ void printGridInfoKernel(int gridID, int index, bool lproj)
 #ifdef CDO
       set_text_color(stdout, RESET, GREEN);
 #endif
-      if ( ysize == 0 )
+      if (ysize == 0)
         fprintf(stdout, "points=%zu\n", gridsize);
       else
         fprintf(stdout, "points=%zu (%zux%zu)\n", gridsize, xsize, ysize);
       my_reset_text_color(stdout);
     }
 
-  if ( gridtype == GRID_CURVILINEAR || gridtype == GRID_UNSTRUCTURED )
+  if (gridtype == GRID_CURVILINEAR || gridtype == GRID_UNSTRUCTURED)
     {
-      if ( gridHasArea(gridID) ||
-           gridInqXbounds(gridID, NULL) || gridInqYbounds(gridID, NULL) )
+      if (gridHasArea(gridID) || gridInqXbounds(gridID, NULL) || gridInqYbounds(gridID, NULL))
         {
           fprintf(stdout, "%33s :", "available");
-          if ( gridInqXbounds(gridID, NULL) && gridInqYbounds(gridID, NULL) ) fprintf(stdout, " cellbounds");
-          if ( gridHasArea(gridID) )          fprintf(stdout, " area");
-          if ( gridInqMask(gridID, NULL) )    fprintf(stdout, " mask");
+          if (gridInqXbounds(gridID, NULL) && gridInqYbounds(gridID, NULL)) fprintf(stdout, " cellbounds");
+          if (gridHasArea(gridID)) fprintf(stdout, " area");
+          if (gridInqMask(gridID, NULL)) fprintf(stdout, " mask");
           fprintf(stdout, "\n");
         }
     }
 
   unsigned char uuidOfHGrid[CDI_UUID_SIZE];
   gridInqUUID(gridID, uuidOfHGrid);
-  if ( !cdiUUIDIsNull(uuidOfHGrid) )
+  if (!cdiUUIDIsNull(uuidOfHGrid))
     {
       char uuidOfHGridStr[37];
       cdiUUID2Str(uuidOfHGrid, uuidOfHGridStr);
-      if ( uuidOfHGridStr[0] != 0  && strlen(uuidOfHGridStr) == 36 )
+      if (uuidOfHGridStr[0] != 0 && strlen(uuidOfHGridStr) == 36)
         {
           fprintf(stdout, "%33s : %s\n", "uuid", uuidOfHGridStr);
         }
     }
 }
 
-static
-void printGridInfo(int vlistID)
+static void
+printGridInfo(int vlistID)
 {
   int ngrids = vlistNgrids(vlistID);
-  for ( int index = 0; index < ngrids; index++ )
+  for (int index = 0; index < ngrids; index++)
     {
       int gridID = vlistGrid(vlistID, index);
       printGridInfoKernel(gridID, index, false);
       int projID = gridInqProj(gridID);
-      if ( projID != CDI_UNDEFID )
-        printGridInfoKernel(projID, index, true);
+      if (projID != CDI_UNDEFID) printGridInfoKernel(projID, index, true);
     }
 }
 
-static
-void printZaxisInfo(int vlistID)
+static void
+printZaxisInfo(int vlistID)
 {
   char zaxisname[CDI_MAX_NAME], zname[CDI_MAX_NAME], zunits[CDI_MAX_NAME];
 
   int nzaxis = vlistNzaxis(vlistID);
-  for ( int index = 0; index < nzaxis; index++ )
+  for (int index = 0; index < nzaxis; index++)
     {
       double zinc = 0;
-      int zaxisID   = vlistZaxis(vlistID, index);
+      int zaxisID = vlistZaxis(vlistID, index);
       int zaxistype = zaxisInqType(zaxisID);
-      int ltype     = zaxisInqLtype(zaxisID);
+      int ltype = zaxisInqLtype(zaxisID);
       int levelsize = zaxisInqSize(zaxisID);
       // int prec      = zaxisInqDatatype(zaxisID);
       // int dig = (prec == CDI_DATATYPE_FLT64) ? 15 : 7;
@@ -472,11 +493,11 @@ void printZaxisInfo(int vlistID)
       zaxisInqUnits(zaxisID, zunits);
       zunits[12] = 0;
 
-      fprintf(stdout, "  %4d : ", vlistZaxisIndex(vlistID, zaxisID)+1);
+      fprintf(stdout, "  %4d : ", vlistZaxisIndex(vlistID, zaxisID) + 1);
 #ifdef CDO
       set_text_color(stdout, RESET, BLUE);
 #endif
-      if ( zaxistype == ZAXIS_GENERIC && ltype != 0 )
+      if (zaxistype == ZAXIS_GENERIC && ltype != 0)
         fprintf(stdout, "%-12s (ltype=%3d)", zaxisname, ltype);
       else
         fprintf(stdout, "%-24s", zaxisname);
@@ -489,24 +510,24 @@ void printZaxisInfo(int vlistID)
 #endif
       fprintf(stdout, " levels=%d", levelsize);
       bool zscalar = (levelsize == 1) ? zaxisInqScalar(zaxisID) : false;
-      if ( zscalar ) fprintf(stdout, "  scalar");
+      if (zscalar) fprintf(stdout, "  scalar");
       my_reset_text_color(stdout);
       fprintf(stdout, "\n");
 
-      if ( zaxisInqLevels(zaxisID, NULL) )
+      if (zaxisInqLevels(zaxisID, NULL))
         {
-          double *levels = (double*) malloc((size_t)levelsize*sizeof(double));
+          double *levels = (double *) malloc((size_t) levelsize * sizeof(double));
           zaxisInqLevels(zaxisID, levels);
 
-          if ( !(zaxistype == ZAXIS_SURFACE && levelsize == 1 && !(fabs(levels[0]) > 0)) )
+          if (!(zaxistype == ZAXIS_SURFACE && levelsize == 1 && !(fabs(levels[0]) > 0)))
             {
               double zfirst = levels[0];
-              double zlast  = levels[levelsize-1];
-              if ( levelsize > 2 )
+              double zlast = levels[levelsize - 1];
+              if (levelsize > 2)
                 {
-                  zinc = (levels[levelsize-1] - levels[0]) / (levelsize-1);
-                  for ( int levelID = 2; levelID < levelsize; ++levelID )
-                    if ( fabs(fabs(levels[levelID] - levels[levelID-1]) - zinc) > 0.001*zinc )
+                  zinc = (levels[levelsize - 1] - levels[0]) / (levelsize - 1);
+                  for (int levelID = 2; levelID < levelsize; ++levelID)
+                    if (fabs(fabs(levels[levelID] - levels[levelID - 1]) - zinc) > 0.001 * zinc)
                       {
                         zinc = 0;
                         break;
@@ -514,11 +535,10 @@ void printZaxisInfo(int vlistID)
                 }
 
               fprintf(stdout, "%33s : %.*g", zname, dig, zfirst);
-              if ( levelsize > 1 )
+              if (levelsize > 1)
                 {
                   fprintf(stdout, " to %.*g", dig, zlast);
-                  if ( IS_NOT_EQUAL(zinc, 0) )
-                    fprintf(stdout, " by %.*g", dig, zinc);
+                  if (IS_NOT_EQUAL(zinc, 0)) fprintf(stdout, " by %.*g", dig, zinc);
                 }
               fprintf(stdout, " %s", zunits);
               fprintf(stdout, "\n");
@@ -527,7 +547,7 @@ void printZaxisInfo(int vlistID)
           free(levels);
         }
 
-      if ( zaxisInqLbounds(zaxisID, NULL) && zaxisInqUbounds(zaxisID, NULL) )
+      if (zaxisInqLbounds(zaxisID, NULL) && zaxisInqUbounds(zaxisID, NULL))
         {
           double level1, level2;
           fprintf(stdout, "%33s : ", "bounds");
@@ -535,37 +555,37 @@ void printZaxisInfo(int vlistID)
           level1 = zaxisInqLbound(zaxisID, 0);
           level2 = zaxisInqUbound(zaxisID, 0);
           fprintf(stdout, "%.*g-%.*g", dig, level1, dig, level2);
-          if ( levelsize > 1 )
+          if (levelsize > 1)
             {
-              level1 = zaxisInqLbound(zaxisID, levelsize-1);
-              level2 = zaxisInqUbound(zaxisID, levelsize-1);
+              level1 = zaxisInqLbound(zaxisID, levelsize - 1);
+              level2 = zaxisInqUbound(zaxisID, levelsize - 1);
               fprintf(stdout, " to %.*g-%.*g", dig, level1, dig, level2);
-              if ( IS_NOT_EQUAL(zinc, 0) )
-                fprintf(stdout, " by %.*g", dig, zinc);
+              if (IS_NOT_EQUAL(zinc, 0)) fprintf(stdout, " by %.*g", dig, zinc);
             }
           fprintf(stdout, " %s", zunits);
           fprintf(stdout, "\n");
         }
 
-      if ( zaxistype == ZAXIS_HYBRID )
+      if (zaxistype == ZAXIS_HYBRID)
         {
-          char psname[CDI_MAX_NAME]; psname[0] = 0;
+          char psname[CDI_MAX_NAME];
+          psname[0] = 0;
           cdiZaxisInqKeyStr(zaxisID, CDI_KEY_PSNAME, CDI_MAX_NAME, psname);
           int vctsize = zaxisInqVctSize(zaxisID);
-          if ( vctsize || psname[0] )
+          if (vctsize || psname[0])
             {
-	      fprintf(stdout, "%33s :", "available");
-              if ( vctsize   ) fprintf(stdout, " vct");
-              if ( psname[0] ) fprintf(stdout, "  ps: %s", psname);
+              fprintf(stdout, "%33s :", "available");
+              if (vctsize) fprintf(stdout, " vct");
+              if (psname[0]) fprintf(stdout, "  ps: %s", psname);
               fprintf(stdout, "\n");
             }
         }
 
-      if ( zaxistype == ZAXIS_REFERENCE )
+      if (zaxistype == ZAXIS_REFERENCE)
         {
-          int number   = zaxisInqNumber(zaxisID);
+          int number = zaxisInqNumber(zaxisID);
 
-          if ( number > 0 )
+          if (number > 0)
             {
               fprintf(stdout, "%33s : ", "zaxis");
               fprintf(stdout, "number=%d\n", number);
@@ -573,11 +593,11 @@ void printZaxisInfo(int vlistID)
 
           unsigned char uuidOfVGrid[CDI_UUID_SIZE];
           zaxisInqUUID(zaxisID, uuidOfVGrid);
-          if ( !cdiUUIDIsNull(uuidOfVGrid) )
+          if (!cdiUUIDIsNull(uuidOfVGrid))
             {
               char uuidOfVGridStr[37];
               cdiUUID2Str(uuidOfVGrid, uuidOfVGridStr);
-              if ( uuidOfVGridStr[0] != 0  && strlen(uuidOfVGridStr) == 36 )
+              if (uuidOfVGridStr[0] != 0 && strlen(uuidOfVGridStr) == 36)
                 {
                   fprintf(stdout, "%33s : ", "uuid");
                   fprintf(stdout, "%s\n", uuidOfVGridStr);
@@ -587,27 +607,27 @@ void printZaxisInfo(int vlistID)
     }
 }
 
-static
-void printSubtypeInfo(int vlistID)
+static void
+printSubtypeInfo(int vlistID)
 {
   int nsubtypes = vlistNsubtypes(vlistID);
-  for ( int index = 0; index < nsubtypes; index++)
+  for (int index = 0; index < nsubtypes; index++)
     {
       int subtypeID = vlistSubtype(vlistID, index);
       int subtypesize = subtypeInqSize(subtypeID);
       // subtypePrint(subtypeID);
-      fprintf(stdout, "  %4d : %-24s :", vlistSubtypeIndex(vlistID, subtypeID)+1, "tiles");
+      fprintf(stdout, "  %4d : %-24s :", vlistSubtypeIndex(vlistID, subtypeID) + 1, "tiles");
       fprintf(stdout, " ntiles=%d", subtypesize);
       fprintf(stdout, "\n");
     }
 }
 
-static
-int printDateTime(int ntimeout, int vdate, int vtime)
+static int
+printDateTime(int ntimeout, int64_t vdate, int vtime)
 {
   char vdatestr[32], vtimestr[32];
 
-  if ( ntimeout == 4 )
+  if (ntimeout == 4)
     {
       ntimeout = 0;
       fprintf(stdout, "\n");
@@ -622,21 +642,21 @@ int printDateTime(int ntimeout, int vdate, int vtime)
 }
 
 #define NUM_TIMESTEP 60
-#define MAX_DOTS     80
+#define MAX_DOTS 80
 
-static
-int printDot(int ndotout, int *nfact, int *ncout)
+static int
+printDot(int ndotout, int *nfact, int *ncout)
 {
-  //printf("ncout %d %d %d\n",*ncout, (*ncout)%(*nfact), *nfact);
-  if ( (*ncout)%(*nfact) == 0 )
+  // printf("ncout %d %d %d\n",*ncout, (*ncout)%(*nfact), *nfact);
+  if ((*ncout) % (*nfact) == 0)
     {
-      if ( ndotout == MAX_DOTS )
-	{
-	  *ncout = 0;
-	  ndotout = 0;
-	  fprintf(stdout, "\n   ");
-	  (*nfact) *= 10;
-	}
+      if (ndotout == MAX_DOTS)
+        {
+          *ncout = 0;
+          ndotout = 0;
+          fprintf(stdout, "\n   ");
+          (*nfact) *= 10;
+        }
 
       fprintf(stdout, ".");
       fflush(stdout);
@@ -648,20 +668,21 @@ int printDot(int ndotout, int *nfact, int *ncout)
   return ndotout;
 }
 
-static
-void printTimesteps(int streamID, int taxisID, int verbose)
+static void
+printTimesteps(int streamID, int taxisID, int verbose)
 {
   int nrecs;
-  struct datetime {
-    int vdate;
+  struct datetime
+  {
+    int64_t vdate;
     int vtime;
     struct datetime *next;
   };
   struct datetime vdatetime[NUM_TIMESTEP];
   struct datetime *next_vdatetime = vdatetime;
 
-  for ( int i = 0; i < NUM_TIMESTEP-1; ++i ) vdatetime[i].next = &vdatetime[i+1];
-  vdatetime[NUM_TIMESTEP-1].next = &vdatetime[0];
+  for (int i = 0; i < NUM_TIMESTEP - 1; ++i) vdatetime[i].next = &vdatetime[i + 1];
+  vdatetime[NUM_TIMESTEP - 1].next = &vdatetime[0];
 
   int ntimeout = 0;
   int ndotout = 0;
@@ -671,67 +692,64 @@ void printTimesteps(int streamID, int taxisID, int verbose)
   int tsID = 0;
 
 #ifdef CDO
-  dtlist_type *dtlist = dtlist_new();
+  DateTimeList dtlist;
 #endif
-  while ( (nrecs = streamInqTimestep(streamID, tsID)) )
+  while ((nrecs = streamInqTimestep(streamID, tsID)))
     {
 #ifdef CDO
-      dtlist_taxisInqTimestep(dtlist, taxisID, 0);
-      int vdate = dtlist_get_vdate(dtlist, 0);
-      int vtime = dtlist_get_vtime(dtlist, 0);
+      dtlist.taxisInqTimestep(taxisID, 0);
+      int64_t vdate = dtlist.getVdate(0);
+      int vtime = dtlist.getVtime(0);
 #else
-      int vdate = taxisInqVdate(taxisID);
+      int64_t vdate = taxisInqVdate(taxisID);
       int vtime = taxisInqVtime(taxisID);
 #endif
 
-      if ( verbose || tsID < NUM_TIMESTEP )
-	{
-	  ntimeout = printDateTime(ntimeout, vdate, vtime);
-	}
+      if (verbose || tsID < NUM_TIMESTEP)
+        {
+          ntimeout = printDateTime(ntimeout, vdate, vtime);
+        }
       else
-	{
-	  if ( tsID == 2*NUM_TIMESTEP ) fprintf(stdout, "\n   ");
-	  if ( tsID >= 2*NUM_TIMESTEP ) ndotout = printDot(ndotout, &nfact, &ncout);
+        {
+          if (tsID == 2 * NUM_TIMESTEP) fprintf(stdout, "\n   ");
+          if (tsID >= 2 * NUM_TIMESTEP) ndotout = printDot(ndotout, &nfact, &ncout);
 
-	  if ( nvdatetime < NUM_TIMESTEP )
-	    {
-	      vdatetime[nvdatetime].vdate = vdate;
-	      vdatetime[nvdatetime].vtime = vtime;
-	      nvdatetime++;
-	    }
-	  else
-	    {
-	      next_vdatetime->vdate = vdate;
-	      next_vdatetime->vtime = vtime;
-	      next_vdatetime = next_vdatetime->next;
-	    }
-	}
+          if (nvdatetime < NUM_TIMESTEP)
+            {
+              vdatetime[nvdatetime].vdate = vdate;
+              vdatetime[nvdatetime].vtime = vtime;
+              nvdatetime++;
+            }
+          else
+            {
+              next_vdatetime->vdate = vdate;
+              next_vdatetime->vtime = vtime;
+              next_vdatetime = next_vdatetime->next;
+            }
+        }
 
       tsID++;
     }
 
-#ifdef CDO
-  dtlist_delete(dtlist);
-#endif
-  if ( nvdatetime )
+  if (nvdatetime)
     {
       fprintf(stdout, "\n");
 
       ntimeout = 0;
       int toff = 0;
-      if ( tsID > 2*NUM_TIMESTEP )
+      if (tsID > 2 * NUM_TIMESTEP)
         {
-          toff = tsID%4;
-          if ( toff > 0 ) toff = 4 - toff;
-          for ( int i = 0; i < toff; ++i ) next_vdatetime = next_vdatetime->next;
+          toff = tsID % 4;
+          if (toff > 0) toff = 4 - toff;
+          for (int i = 0; i < toff; ++i) next_vdatetime = next_vdatetime->next;
+        }
+      for (int i = toff; i < nvdatetime; ++i)
+        {
+          int64_t vdate = next_vdatetime->vdate;
+          int vtime = next_vdatetime->vtime;
+          ntimeout = printDateTime(ntimeout, vdate, vtime);
+          next_vdatetime = next_vdatetime->next;
         }
-      for ( int i = toff; i < nvdatetime; ++i )
-	{
-	  int vdate = next_vdatetime->vdate;
-	  int vtime = next_vdatetime->vtime;
-	  ntimeout = printDateTime(ntimeout, vdate, vtime);
-	  next_vdatetime = next_vdatetime->next;
-	}
     }
 }
 /*
