@@ -17,18 +17,5 @@
 
 #ifndef PSTREAM_WRITE_H
 #define PSTREAM_WRITE_H
-#include "argument.h"
 
-int     pstreamOpenWrite(const argument_t *argument, int filetype);
-void    pstreamClose(int pstreamID);
-
-void    pstreamDefVlist(int pstreamID, int vlistID);
-
-void    pstreamDefTimestep(int pstreamID, int tsID);
-
-void    pstreamDefRecord(int pstreamID, int  varID, int  levelID);
-
-void    pstreamWriteRecord(int pstreamID, double *data, size_t nmiss);
-void    pstreamWriteRecordF(int pstreamID, float *data, size_t nmiss);
-
-#endif  /* PSTREAM_WRITE_H */
+#endif /* PSTREAM_WRITE_H */
