@@ -1,4 +1,5 @@
 #include "cdo_int.h"
+#include "cdo_wtime.h"
 #include "cdoOptions.h"
 #include "remap_vars.h"
 #include "timer.h"
@@ -10,9 +11,141 @@
 
   -----------------------------------------------------------------------
 */
+
+static void
+remapFirstOrder(double *restrict dst_array, const RemapVars &rv, const double *restrict src_array)
+{
+  size_t num_links = rv.num_links;
+  size_t num_wts = rv.num_wts;
+  const double *restrict map_wts = rv.wts.data();
+  const size_t *restrict dst_add = rv.tgt_cell_add.data();
+  const size_t *restrict src_add = rv.src_cell_add.data();
+  remaplink_t links = rv.links;
+  long links_per_value = rv.links_per_value;
+
+  if (links.option)
+    {
+#ifdef HAVE_OPENMP4
+#pragma omp parallel for simd default(none) shared(num_links, dst_array, dst_add)
+#endif
+      for (size_t n = 0; n < num_links; ++n) dst_array[dst_add[n]] = 0.;
+
+      for (size_t j = 0; j < links.num_blks; ++j)
+        {
+          const size_t *restrict dst_addx = links.dst_add[j];
+          const size_t *restrict src_addx = links.src_add[j];
+          const size_t *restrict windex = links.w_index[j];
+          size_t nlinks = links.num_links[j];
+
+#ifdef HAVE_OPENMP4
+#pragma omp parallel for simd default(none) shared(nlinks, dst_array, src_array, dst_addx, src_addx, map_wts, num_wts, windex)
+#endif
+          for (size_t n = 0; n < nlinks; ++n)
+            {
+              dst_array[dst_addx[n]] += src_array[src_addx[n]] * map_wts[num_wts * windex[n]];
+            }
+        }
+    }
+  else
+    {
+      long lpv = links_per_value;
+      if (lpv > 0)
+        {
+          size_t nlinks = num_links / lpv;
+
+          if (lpv == 1)
+            {
+#ifdef _OPENMP
+#pragma omp parallel for default(none) shared(dst_array, src_array, dst_add, src_add, map_wts, nlinks)
+#endif
+              for (size_t n = 0; n < nlinks; ++n)
+                {
+                  dst_array[dst_add[n]] = src_array[src_add[n]] * map_wts[n];
+                }
+            }
+          else if (lpv == 4)
+            {
+#ifdef _OPENMP
+#pragma omp parallel for default(none) shared(dst_array, src_array, dst_add, src_add, map_wts, num_wts, nlinks)
+#endif
+              for (size_t n = 0; n < nlinks; ++n)
+                {
+                  size_t noff = n * 4;
+                  dst_array[dst_add[noff]] = src_array[src_add[noff]] * map_wts[num_wts * (noff)]
+                                             + src_array[src_add[noff + 1]] * map_wts[num_wts * (noff + 1)]
+                                             + src_array[src_add[noff + 2]] * map_wts[num_wts * (noff + 2)]
+                                             + src_array[src_add[noff + 3]] * map_wts[num_wts * (noff + 3)];
+                }
+            }
+          else
+            {
+#ifdef _OPENMP
+#pragma omp parallel for default(none) shared(dst_array, src_array, dst_add, src_add, map_wts, num_wts, nlinks, lpv)
+#endif
+              for (size_t n = 0; n < nlinks; ++n)
+                {
+                  size_t noff = n * lpv;
+                  dst_array[dst_add[noff]] = src_array[src_add[noff]] * map_wts[num_wts * noff];
+                  for (size_t k = 1; k < (size_t) lpv; ++k)
+                    dst_array[dst_add[noff]] += src_array[src_add[noff + k]] * map_wts[num_wts * (noff + k)];
+                }
+            }
+        }
+      else
+        {
+#ifdef SX
+#pragma cdir nodep
+#endif
+          for (size_t n = 0; n < num_links; ++n) dst_array[dst_add[n]] = 0.;
+
+          for (size_t n = 0; n < num_links; ++n)
+            {
+              // printf("%5zu %5zu %5zu %g # dst_add src_add n\n", dst_add[n], src_add[n], n, map_wts[num_wts*n]);
+              dst_array[dst_add[n]] += src_array[src_add[n]] * map_wts[num_wts * n];
+            }
+        }
+    }
+}
+
+static void
+remapSecondOrder(double *restrict dst_array, const RemapVars &rv, const double *restrict src_array, RemapGradients &gradients)
+{
+  const double *restrict src_grad1 = gradients.grad_lat.size() ? gradients.grad_lat.data() : NULL;
+  const double *restrict src_grad2 = gradients.grad_lon.size() ? gradients.grad_lon.data() : NULL;
+  const double *restrict src_grad3 = gradients.grad_latlon.size() ? gradients.grad_latlon.data() : NULL;
+
+  size_t num_links = rv.num_links;
+  size_t num_wts = rv.num_wts;
+  const double *restrict map_wts = rv.wts.data();
+  const size_t *restrict dst_add = rv.tgt_cell_add.data();
+  const size_t *restrict src_add = rv.src_cell_add.data();
+
+#ifdef SX
+#pragma cdir nodep
+#endif
+  for (size_t n = 0; n < num_links; ++n) dst_array[dst_add[n]] = 0.;
+
+  if (num_wts == 3)
+    {
+      for (size_t n = 0; n < num_links; ++n)
+        {
+          dst_array[dst_add[n]] += src_array[src_add[n]] * map_wts[3 * n] + src_grad1[src_add[n]] * map_wts[3 * n + 1]
+                                   + src_grad2[src_add[n]] * map_wts[3 * n + 2];
+        }
+    }
+  else if (num_wts == 4)
+    {
+      for (size_t n = 0; n < num_links; ++n)
+        {
+          dst_array[dst_add[n]] += src_array[src_add[n]] * map_wts[4 * n] + src_grad1[src_add[n]] * map_wts[4 * n + 1]
+                                   + src_grad2[src_add[n]] * map_wts[4 * n + 2] + src_grad3[src_add[n]] * map_wts[4 * n + 3];
+        }
+    }
+}
+
 void
 remap(double *restrict dst_array, double missval, size_t dst_size, const RemapVars &rv, const double *restrict src_array,
-      gradientsType &gradients)
+      RemapGradients &gradients)
 {
   /*
     Input arrays:
@@ -28,31 +161,19 @@ remap(double *restrict dst_array, double missval, size_t dst_size, const RemapVa
 
     optional:
 
-    double *src_grad1    ! gradient arrays on source grid necessary for
-    double *src_grad2    ! higher-order remappings
-    double *src_grad3
+    RemapGradients &gradients  ! gradient arrays on source grid necessary for higher-order remappings
 
     output variables:
 
     double *dst_array    ! array for remapped field on destination grid
   */
-  const double *restrict src_grad1 = gradients.grad_lat.size() ? &gradients.grad_lat[0] : NULL;
-  const double *restrict src_grad2 = gradients.grad_lon.size() ? &gradients.grad_lon[0] : NULL;
-  const double *restrict src_grad3 = gradients.grad_latlon.size() ? &gradients.grad_latlon[0] : NULL;
-
-  size_t num_links = rv.num_links;
-  size_t num_wts = rv.num_wts;
-  const double *restrict map_wts = &rv.wts[0];
-  const size_t *restrict dst_add = &rv.tgt_cell_add[0];
-  const size_t *restrict src_add = &rv.src_cell_add[0];
-  remaplink_t links = rv.links;
-  long links_per_value = rv.links_per_value;
-
   extern int timer_remap;
 
+  double start = cdoVerbose ? cdo_get_wtime() : 0;
+
   // Check the order of the interpolation
 
-  int iorder = (src_grad1 == NULL) ? 1 : 2;
+  bool firstOrder = gradients.grad_lat.size() == 0;
 
 #ifdef HAVE_OPENMP4
 #pragma omp parallel for simd default(none) shared(dst_size, dst_array, missval)
@@ -61,107 +182,17 @@ remap(double *restrict dst_array, double missval, size_t dst_size, const RemapVa
 
   if (cdoTimer) timer_start(timer_remap);
 
-  if (iorder == 1)  // First order remapping
+  if (firstOrder)  // First order remapping
     {
-      if (links.option)
-        {
-#ifdef HAVE_OPENMP4
-#pragma omp parallel for simd default(none) shared(num_links, dst_array, dst_add)
-#endif
-          for (size_t n = 0; n < num_links; ++n) dst_array[dst_add[n]] = 0.;
-
-          for (size_t j = 0; j < links.num_blks; ++j)
-            {
-              const size_t *restrict dst_addx = links.dst_add[j];
-              const size_t *restrict src_addx = links.src_add[j];
-              const size_t *restrict windex = links.w_index[j];
-              size_t nlinks = links.num_links[j];
-
-#ifdef HAVE_OPENMP4
-#pragma omp parallel for simd default(none) shared(nlinks, dst_array, src_array, dst_addx, src_addx, map_wts, num_wts, windex)
-#endif
-              for (size_t n = 0; n < nlinks; ++n)
-                {
-                  dst_array[dst_addx[n]] += src_array[src_addx[n]] * map_wts[num_wts * windex[n]];
-                }
-            }
-        }
-      else
-        {
-          long lpv = links_per_value;
-          if (lpv > 0)
-            {
-              size_t nlinks = num_links / lpv;
-
-              if (lpv == 4)
-                {
-#ifdef _OPENMP
-#pragma omp parallel for default(none) shared(dst_array, src_array, dst_add, src_add, map_wts, num_wts, nlinks, lpv)
-#endif
-                  for (size_t n = 0; n < nlinks; ++n)
-                    {
-                      size_t noff = n * lpv;
-                      dst_array[dst_add[noff]] = src_array[src_add[noff]] * map_wts[num_wts * (noff)]
-                                                 + src_array[src_add[noff + 1]] * map_wts[num_wts * (noff + 1)]
-                                                 + src_array[src_add[noff + 2]] * map_wts[num_wts * (noff + 2)]
-                                                 + src_array[src_add[noff + 3]] * map_wts[num_wts * (noff + 3)];
-                    }
-                }
-              else
-                {
-#ifdef _OPENMP
-#pragma omp parallel for default(none) shared(dst_array, src_array, dst_add, src_add, map_wts, num_wts, nlinks, lpv)
-#endif
-                  for (size_t n = 0; n < nlinks; ++n)
-                    {
-                      size_t noff = n * lpv;
-                      dst_array[dst_add[noff]] = src_array[src_add[noff]] * map_wts[num_wts * noff];
-                      for (size_t k = 1; k < (size_t) lpv; ++k)
-                        dst_array[dst_add[noff]] += src_array[src_add[noff + k]] * map_wts[num_wts * (noff + k)];
-                    }
-                }
-            }
-          else
-            {
-#ifdef SX
-#pragma cdir nodep
-#endif
-              for (size_t n = 0; n < num_links; ++n) dst_array[dst_add[n]] = 0.;
-
-              for (size_t n = 0; n < num_links; ++n)
-                {
-                  // printf("%5zu %5zu %5zu %g # dst_add src_add n\n", dst_add[n], src_add[n], n, map_wts[num_wts*n]);
-                  dst_array[dst_add[n]] += src_array[src_add[n]] * map_wts[num_wts * n];
-                }
-            }
-        }
+      remapFirstOrder(dst_array, rv, src_array);
     }
   else  // Second order remapping
     {
-#ifdef SX
-#pragma cdir nodep
-#endif
-      for (size_t n = 0; n < num_links; ++n) dst_array[dst_add[n]] = 0.;
-
-      if (num_wts == 3)
-        {
-          for (size_t n = 0; n < num_links; ++n)
-            {
-              dst_array[dst_add[n]] += src_array[src_add[n]] * map_wts[3 * n] + src_grad1[src_add[n]] * map_wts[3 * n + 1]
-                                       + src_grad2[src_add[n]] * map_wts[3 * n + 2];
-            }
-        }
-      else if (num_wts == 4)
-        {
-          for (size_t n = 0; n < num_links; ++n)
-            {
-              dst_array[dst_add[n]] += src_array[src_add[n]] * map_wts[4 * n] + src_grad1[src_add[n]] * map_wts[4 * n + 1]
-                                       + src_grad2[src_add[n]] * map_wts[4 * n + 2]
-                                       + src_grad3[src_add[n]] * map_wts[4 * n + 3];
-            }
-        }
+      remapSecondOrder(dst_array, rv, src_array, gradients);
     }
 
+  if (cdoVerbose) cdoPrint("Remap: %.2f seconds", cdo_get_wtime() - start);
+
   if (cdoTimer) timer_stop(timer_remap);
 }
 
@@ -393,7 +424,7 @@ remap_sum(double *restrict dst_array, double missval, size_t dst_size, const Rem
 }
 
 void
-remapVarsInit(RemapMethod mapType, RemapVars &rv)
+remapVarsInit(RemapMethod mapType, int remapOrder, RemapVars &rv)
 {
   // Initialize all pointer
   if (rv.pinit == false) rv.pinit = true;
@@ -402,6 +433,7 @@ remapVarsInit(RemapMethod mapType, RemapVars &rv)
 
   // Determine the number of weights
   rv.num_wts = (mapType == RemapMethod::CONSERV) ? 3 : ((mapType == RemapMethod::BICUBIC) ? 4 : 1);
+  if (mapType == RemapMethod::CONSERV_YAC && remapOrder==2) rv.num_wts = 3;
 
   rv.links_per_value = -1;
   rv.num_links = 0;
